# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: types.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ccdexplorer_fundamentals.GRPCClient.kernel_pb2 as kernel__pb2
import ccdexplorer_fundamentals.GRPCClient.protocol_level_tokens_pb2 as protocol__level__tokens__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x0btypes.proto\x12\rconcordium.v2\x1a\x0ckernel.proto\x1a\x1bprotocol-level-tokens.proto"\x07\n\x05\x45mpty"\x1a\n\tBlockHash\x12\r\n\x05value\x18\x01 \x01(\x0c"\x1b\n\nSha256Hash\x12\r\n\x05value\x18\x01 \x01(\x0c" \n\x0fTransactionHash\x12\r\n\x05value\x18\x01 \x01(\x0c"\x1a\n\tStateHash\x12\r\n\x05value\x18\x01 \x01(\x0c"$\n\x13\x41\x62soluteBlockHeight\x12\r\n\x05value\x18\x01 \x01(\x04"\x1c\n\x0b\x42lockHeight\x12\r\n\x05value\x18\x01 \x01(\x04"\x18\n\x07\x42\x61kerId\x12\r\n\x05value\x18\x01 \x01(\x04"\x1d\n\x0c\x41\x63\x63ountIndex\x12\r\n\x05value\x18\x01 \x01(\x04"\x1a\n\tModuleRef\x12\r\n\x05value\x18\x01 \x01(\x0c"\xe9\x01\n\x15VersionedModuleSource\x12\x41\n\x02v0\x18\x01 \x01(\x0b\x32\x33.concordium.v2.VersionedModuleSource.ModuleSourceV0H\x00\x12\x41\n\x02v1\x18\x02 \x01(\x0b\x32\x33.concordium.v2.VersionedModuleSource.ModuleSourceV1H\x00\x1a\x1f\n\x0eModuleSourceV0\x12\r\n\x05value\x18\x01 \x01(\x0c\x1a\x1f\n\x0eModuleSourceV1\x12\r\n\x05value\x18\x01 \x01(\x0c\x42\x08\n\x06module"\x1a\n\tTimestamp\x12\r\n\x05value\x18\x01 \x01(\x04"\x93\x01\n\x07Release\x12+\n\ttimestamp\x18\x01 \x01(\x0b\x32\x18.concordium.v2.Timestamp\x12%\n\x06\x61mount\x18\x02 \x01(\x0b\x32\x15.concordium.v2.Amount\x12\x34\n\x0ctransactions\x18\x03 \x03(\x0b\x32\x1e.concordium.v2.TransactionHash"`\n\nNewRelease\x12+\n\ttimestamp\x18\x01 \x01(\x0b\x32\x18.concordium.v2.Timestamp\x12%\n\x06\x61mount\x18\x02 \x01(\x0b\x32\x15.concordium.v2.Amount"b\n\x0fReleaseSchedule\x12$\n\x05total\x18\x01 \x01(\x0b\x32\x15.concordium.v2.Amount\x12)\n\tschedules\x18\x02 \x03(\x0b\x32\x16.concordium.v2.Release" \n\x0f\x45ncryptedAmount\x12\r\n\x05value\x18\x01 \x01(\x0c"\x9c\x02\n\x10\x45ncryptedBalance\x12\x33\n\x0bself_amount\x18\x01 \x01(\x0b\x32\x1e.concordium.v2.EncryptedAmount\x12\x13\n\x0bstart_index\x18\x02 \x01(\x04\x12>\n\x11\x61ggregated_amount\x18\x03 \x01(\x0b\x32\x1e.concordium.v2.EncryptedAmountH\x00\x88\x01\x01\x12\x1b\n\x0enum_aggregated\x18\x04 \x01(\rH\x01\x88\x01\x01\x12\x38\n\x10incoming_amounts\x18\x05 \x03(\x0b\x32\x1e.concordium.v2.EncryptedAmountB\x14\n\x12_aggregated_amountB\x11\n\x0f_num_aggregated"n\n\x10\x44\x65legationTarget\x12\'\n\x07passive\x18\x01 \x01(\x0b\x32\x14.concordium.v2.EmptyH\x00\x12\'\n\x05\x62\x61ker\x18\x02 \x01(\x0b\x32\x16.concordium.v2.BakerIdH\x00\x42\x08\n\x06target"\'\n\x16\x42\x61kerElectionVerifyKey\x12\r\n\x05value\x18\x01 \x01(\x0c"(\n\x17\x42\x61kerSignatureVerifyKey\x12\r\n\x05value\x18\x01 \x01(\x0c"*\n\x19\x42\x61kerAggregationVerifyKey\x12\r\n\x05value\x18\x01 \x01(\x0c"\xf4\x01\n\tBakerInfo\x12(\n\x08\x62\x61ker_id\x18\x01 \x01(\x0b\x32\x16.concordium.v2.BakerId\x12;\n\x0c\x65lection_key\x18\x02 \x01(\x0b\x32%.concordium.v2.BakerElectionVerifyKey\x12=\n\rsignature_key\x18\x03 \x01(\x0b\x32&.concordium.v2.BakerSignatureVerifyKey\x12\x41\n\x0f\x61ggregation_key\x18\x04 \x01(\x0b\x32(.concordium.v2.BakerAggregationVerifyKey"\xec\x01\n\x12StakePendingChange\x12:\n\x06reduce\x18\x01 \x01(\x0b\x32(.concordium.v2.StakePendingChange.ReduceH\x00\x12*\n\x06remove\x18\x02 \x01(\x0b\x32\x18.concordium.v2.TimestampH\x00\x1a\x64\n\x06Reduce\x12(\n\tnew_stake\x18\x01 \x01(\x0b\x32\x15.concordium.v2.Amount\x12\x30\n\x0e\x65\x66\x66\x65\x63tive_time\x18\x02 \x01(\x0b\x32\x18.concordium.v2.TimestampB\x08\n\x06\x63hange"4\n\x0e\x41mountFraction\x12"\n\x1aparts_per_hundred_thousand\x18\x01 \x01(\r"\xa9\x01\n\x0f\x43ommissionRates\x12\x33\n\x0c\x66inalization\x18\x01 \x01(\x0b\x32\x1d.concordium.v2.AmountFraction\x12-\n\x06\x62\x61king\x18\x02 \x01(\x0b\x32\x1d.concordium.v2.AmountFraction\x12\x32\n\x0btransaction\x18\x03 \x01(\x0b\x32\x1d.concordium.v2.AmountFraction"\x86\x01\n\rBakerPoolInfo\x12.\n\x0bopen_status\x18\x01 \x01(\x0e\x32\x19.concordium.v2.OpenStatus\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x38\n\x10\x63ommission_rates\x18\x03 \x01(\x0b\x32\x1e.concordium.v2.CommissionRates"\xa7\x05\n\x12\x41\x63\x63ountStakingInfo\x12\x38\n\x05\x62\x61ker\x18\x01 \x01(\x0b\x32\'.concordium.v2.AccountStakingInfo.BakerH\x00\x12@\n\tdelegator\x18\x02 \x01(\x0b\x32+.concordium.v2.AccountStakingInfo.DelegatorH\x00\x1a\xaa\x02\n\x05\x42\x61ker\x12,\n\rstaked_amount\x18\x01 \x01(\x0b\x32\x15.concordium.v2.Amount\x12\x18\n\x10restake_earnings\x18\x02 \x01(\x08\x12,\n\nbaker_info\x18\x03 \x01(\x0b\x32\x18.concordium.v2.BakerInfo\x12>\n\x0epending_change\x18\x04 \x01(\x0b\x32!.concordium.v2.StakePendingChangeH\x00\x88\x01\x01\x12\x34\n\tpool_info\x18\x05 \x01(\x0b\x32\x1c.concordium.v2.BakerPoolInfoH\x01\x88\x01\x01\x12\x14\n\x0cis_suspended\x18\x06 \x01(\x08\x42\x11\n\x0f_pending_changeB\x0c\n\n_pool_info\x1a\xd7\x01\n\tDelegator\x12,\n\rstaked_amount\x18\x01 \x01(\x0b\x32\x15.concordium.v2.Amount\x12\x18\n\x10restake_earnings\x18\x02 \x01(\x08\x12/\n\x06target\x18\x03 \x01(\x0b\x32\x1f.concordium.v2.DelegationTarget\x12>\n\x0epending_change\x18\x04 \x01(\x0b\x32!.concordium.v2.StakePendingChangeH\x00\x88\x01\x01\x42\x11\n\x0f_pending_changeB\x0e\n\x0cstaking_info"\x1f\n\x0eSequenceNumber\x12\r\n\x05value\x18\x01 \x01(\x04"%\n\x14UpdateSequenceNumber\x12\r\n\x05value\x18\x01 \x01(\x04"\x17\n\x06\x41mount\x12\r\n\x05value\x18\x01 \x01(\x04" \n\x0f\x43redentialIndex\x12\r\n\x05value\x18\x01 \x01(\r"#\n\x12SignatureThreshold\x12\r\n\x05value\x18\x01 \x01(\r"!\n\x10\x41\x63\x63ountThreshold\x12\r\n\x05value\x18\x01 \x01(\r"\x1e\n\rEncryptionKey\x12\r\n\x05value\x18\x01 \x01(\x0c"w\n\x07\x41\x64\x64ress\x12\x30\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x1d.concordium.v2.AccountAddressH\x00\x12\x32\n\x08\x63ontract\x18\x02 \x01(\x0b\x32\x1e.concordium.v2.ContractAddressH\x00\x42\x06\n\x04type"0\n\x10\x41\x63\x63ountVerifyKey\x12\x15\n\x0b\x65\x64\x32\x35\x35\x31\x39_key\x18\x01 \x01(\x0cH\x00\x42\x05\n\x03key"\xd7\x01\n\x14\x43redentialPublicKeys\x12;\n\x04keys\x18\x01 \x03(\x0b\x32-.concordium.v2.CredentialPublicKeys.KeysEntry\x12\x34\n\tthreshold\x18\x02 \x01(\x0b\x32!.concordium.v2.SignatureThreshold\x1aL\n\tKeysEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12.\n\x05value\x18\x02 \x01(\x0b\x32\x1f.concordium.v2.AccountVerifyKey:\x02\x38\x01")\n\x18\x43redentialRegistrationId\x12\r\n\x05value\x18\x01 \x01(\x0c")\n\x18IdentityProviderIdentity\x12\r\n\x05value\x18\x01 \x01(\r"(\n\tYearMonth\x12\x0c\n\x04year\x18\x01 \x01(\r\x12\r\n\x05month\x18\x02 \x01(\r"\xd0\x01\n\x06Policy\x12,\n\ncreated_at\x18\x01 \x01(\x0b\x32\x18.concordium.v2.YearMonth\x12*\n\x08valid_to\x18\x02 \x01(\x0b\x32\x18.concordium.v2.YearMonth\x12\x39\n\nattributes\x18\x03 \x03(\x0b\x32%.concordium.v2.Policy.AttributesEntry\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01"\xe5\x01\n\x17InitialCredentialValues\x12\x31\n\x04keys\x18\x01 \x01(\x0b\x32#.concordium.v2.CredentialPublicKeys\x12\x38\n\x07\x63red_id\x18\x02 \x01(\x0b\x32\'.concordium.v2.CredentialRegistrationId\x12\x36\n\x05ip_id\x18\x03 \x01(\x0b\x32\'.concordium.v2.IdentityProviderIdentity\x12%\n\x06policy\x18\x04 \x01(\x0b\x32\x15.concordium.v2.Policy",\n\x0b\x43hainArData\x12\x1d\n\x15\x65nc_id_cred_pub_share\x18\x01 \x01(\x0c"\x1c\n\x0b\x41rThreshold\x12\r\n\x05value\x18\x01 \x01(\r"\x1b\n\nCommitment\x12\r\n\x05value\x18\x01 \x01(\x0c"\xf7\x02\n\x15\x43redentialCommitments\x12&\n\x03prf\x18\x01 \x01(\x0b\x32\x19.concordium.v2.Commitment\x12/\n\x0c\x63red_counter\x18\x02 \x01(\x0b\x32\x19.concordium.v2.Commitment\x12/\n\x0cmax_accounts\x18\x03 \x01(\x0b\x32\x19.concordium.v2.Commitment\x12H\n\nattributes\x18\x04 \x03(\x0b\x32\x34.concordium.v2.CredentialCommitments.AttributesEntry\x12<\n\x19id_cred_sec_sharing_coeff\x18\x05 \x03(\x0b\x32\x19.concordium.v2.Commitment\x1aL\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12(\n\x05value\x18\x02 \x01(\x0b\x32\x19.concordium.v2.Commitment:\x02\x38\x01"\xe0\x03\n\x16NormalCredentialValues\x12\x31\n\x04keys\x18\x01 \x01(\x0b\x32#.concordium.v2.CredentialPublicKeys\x12\x38\n\x07\x63red_id\x18\x02 \x01(\x0b\x32\'.concordium.v2.CredentialRegistrationId\x12\x36\n\x05ip_id\x18\x03 \x01(\x0b\x32\'.concordium.v2.IdentityProviderIdentity\x12%\n\x06policy\x18\x04 \x01(\x0b\x32\x15.concordium.v2.Policy\x12\x30\n\x0c\x61r_threshold\x18\x05 \x01(\x0b\x32\x1a.concordium.v2.ArThreshold\x12\x42\n\x07\x61r_data\x18\x06 \x03(\x0b\x32\x31.concordium.v2.NormalCredentialValues.ArDataEntry\x12\x39\n\x0b\x63ommitments\x18\x07 \x01(\x0b\x32$.concordium.v2.CredentialCommitments\x1aI\n\x0b\x41rDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.concordium.v2.ChainArData:\x02\x38\x01"\x9c\x01\n\x11\x41\x63\x63ountCredential\x12\x39\n\x07initial\x18\x01 \x01(\x0b\x32&.concordium.v2.InitialCredentialValuesH\x00\x12\x37\n\x06normal\x18\x02 \x01(\x0b\x32%.concordium.v2.NormalCredentialValuesH\x00\x42\x13\n\x11\x63redential_values"\xdd\x01\n\x08\x43ooldown\x12*\n\x08\x65nd_time\x18\x01 \x01(\x0b\x32\x18.concordium.v2.Timestamp\x12%\n\x06\x61mount\x18\x02 \x01(\x0b\x32\x15.concordium.v2.Amount\x12\x36\n\x06status\x18\x03 \x01(\x0e\x32&.concordium.v2.Cooldown.CooldownStatus"F\n\x0e\x43ooldownStatus\x12\x0c\n\x08\x43OOLDOWN\x10\x00\x12\x10\n\x0cPRE_COOLDOWN\x10\x01\x12\x14\n\x10PRE_PRE_COOLDOWN\x10\x02"m\n\tTokenInfo\x12,\n\x08token_id\x18\x01 \x01(\x0b\x32\x1a.concordium.v2.plt.TokenId\x12\x32\n\x0btoken_state\x18\x02 \x01(\x0b\x32\x1d.concordium.v2.plt.TokenState"\xf1\x06\n\x0b\x41\x63\x63ountInfo\x12\x36\n\x0fsequence_number\x18\x01 \x01(\x0b\x32\x1d.concordium.v2.SequenceNumber\x12%\n\x06\x61mount\x18\x02 \x01(\x0b\x32\x15.concordium.v2.Amount\x12\x30\n\x08schedule\x18\x03 \x01(\x0b\x32\x1e.concordium.v2.ReleaseSchedule\x12\x34\n\x05\x63reds\x18\x04 \x03(\x0b\x32%.concordium.v2.AccountInfo.CredsEntry\x12\x32\n\tthreshold\x18\x05 \x01(\x0b\x32\x1f.concordium.v2.AccountThreshold\x12:\n\x11\x65ncrypted_balance\x18\x06 \x01(\x0b\x32\x1f.concordium.v2.EncryptedBalance\x12\x34\n\x0e\x65ncryption_key\x18\x07 \x01(\x0b\x32\x1c.concordium.v2.EncryptionKey\x12*\n\x05index\x18\x08 \x01(\x0b\x32\x1b.concordium.v2.AccountIndex\x12\x35\n\x05stake\x18\t \x01(\x0b\x32!.concordium.v2.AccountStakingInfoH\x00\x88\x01\x01\x12.\n\x07\x61\x64\x64ress\x18\n \x01(\x0b\x32\x1d.concordium.v2.AccountAddress\x12*\n\tcooldowns\x18\x0b \x03(\x0b\x32\x17.concordium.v2.Cooldown\x12\x30\n\x11\x61vailable_balance\x18\x0c \x01(\x0b\x32\x15.concordium.v2.Amount\x12\x30\n\x06tokens\x18\r \x03(\x0b\x32 .concordium.v2.AccountInfo.Token\x1ax\n\x05Token\x12,\n\x08token_id\x18\x01 \x01(\x0b\x32\x1a.concordium.v2.plt.TokenId\x12\x41\n\x13token_account_state\x18\x02 \x01(\x0b\x32$.concordium.v2.plt.TokenAccountState\x1aN\n\nCredsEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12/\n\x05value\x18\x02 \x01(\x0b\x32 .concordium.v2.AccountCredential:\x02\x38\x01\x42\x08\n\x06_stake"\xae\x03\n\x0e\x42lockHashInput\x12$\n\x04\x62\x65st\x18\x01 \x01(\x0b\x32\x14.concordium.v2.EmptyH\x00\x12*\n\nlast_final\x18\x02 \x01(\x0b\x32\x14.concordium.v2.EmptyH\x00\x12)\n\x05given\x18\x03 \x01(\x0b\x32\x18.concordium.v2.BlockHashH\x00\x12=\n\x0f\x61\x62solute_height\x18\x04 \x01(\x0b\x32".concordium.v2.AbsoluteBlockHeightH\x00\x12G\n\x0frelative_height\x18\x05 \x01(\x0b\x32,.concordium.v2.BlockHashInput.RelativeHeightH\x00\x1a\x82\x01\n\x0eRelativeHeight\x12\x32\n\rgenesis_index\x18\x01 \x01(\x0b\x32\x1b.concordium.v2.GenesisIndex\x12*\n\x06height\x18\x02 \x01(\x0b\x32\x1a.concordium.v2.BlockHeight\x12\x10\n\x08restrict\x18\x03 \x01(\x08\x42\x12\n\x10\x62lock_hash_input"\x89\x02\n\x0c\x45pochRequest\x12\x43\n\x0erelative_epoch\x18\x01 \x01(\x0b\x32).concordium.v2.EpochRequest.RelativeEpochH\x00\x12\x33\n\nblock_hash\x18\x02 \x01(\x0b\x32\x1d.concordium.v2.BlockHashInputH\x00\x1ah\n\rRelativeEpoch\x12\x32\n\rgenesis_index\x18\x01 \x01(\x0b\x32\x1b.concordium.v2.GenesisIndex\x12#\n\x05\x65poch\x18\x02 \x01(\x0b\x32\x14.concordium.v2.EpochB\x15\n\x13\x65poch_request_input"\xd8\x01\n\x16\x41\x63\x63ountIdentifierInput\x12\x30\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x1d.concordium.v2.AccountAddressH\x00\x12:\n\x07\x63red_id\x18\x02 \x01(\x0b\x32\'.concordium.v2.CredentialRegistrationIdH\x00\x12\x34\n\raccount_index\x18\x03 \x01(\x0b\x32\x1b.concordium.v2.AccountIndexH\x00\x42\x1a\n\x18\x61\x63\x63ount_identifier_input"\x8a\x01\n\x12\x41\x63\x63ountInfoRequest\x12\x31\n\nblock_hash\x18\x01 \x01(\x0b\x32\x1d.concordium.v2.BlockHashInput\x12\x41\n\x12\x61\x63\x63ount_identifier\x18\x02 \x01(\x0b\x32%.concordium.v2.AccountIdentifierInput"s\n\x10TokenInfoRequest\x12\x31\n\nblock_hash\x18\x01 \x01(\x0b\x32\x1d.concordium.v2.BlockHashInput\x12,\n\x08token_id\x18\x02 \x01(\x0b\x32\x1a.concordium.v2.plt.TokenId"p\n\x12\x46inalizedBlockInfo\x12&\n\x04hash\x18\x01 \x01(\x0b\x32\x18.concordium.v2.BlockHash\x12\x32\n\x06height\x18\x02 \x01(\x0b\x32".concordium.v2.AbsoluteBlockHeight"U\n\x10\x41ncestorsRequest\x12\x31\n\nblock_hash\x18\x01 \x01(\x0b\x32\x1d.concordium.v2.BlockHashInput\x12\x0e\n\x06\x61mount\x18\x02 \x01(\x04"v\n\x13ModuleSourceRequest\x12\x31\n\nblock_hash\x18\x01 \x01(\x0b\x32\x1d.concordium.v2.BlockHashInput\x12,\n\nmodule_ref\x18\x02 \x01(\x0b\x32\x18.concordium.v2.ModuleRef"2\n\x0f\x43ontractAddress\x12\r\n\x05index\x18\x01 \x01(\x04\x12\x10\n\x08subindex\x18\x02 \x01(\x04"y\n\x13InstanceInfoRequest\x12\x31\n\nblock_hash\x18\x01 \x01(\x0b\x32\x1d.concordium.v2.BlockHashInput\x12/\n\x07\x61\x64\x64ress\x18\x02 \x01(\x0b\x32\x1e.concordium.v2.ContractAddress"\xe6\x04\n\x0cInstanceInfo\x12,\n\x02v0\x18\x01 \x01(\x0b\x32\x1e.concordium.v2.InstanceInfo.V0H\x00\x12,\n\x02v1\x18\x02 \x01(\x0b\x32\x1e.concordium.v2.InstanceInfo.V1H\x00\x1a\x8d\x02\n\x02V0\x12-\n\x05model\x18\x01 \x01(\x0b\x32\x1e.concordium.v2.ContractStateV0\x12,\n\x05owner\x18\x02 \x01(\x0b\x32\x1d.concordium.v2.AccountAddress\x12%\n\x06\x61mount\x18\x03 \x01(\x0b\x32\x15.concordium.v2.Amount\x12+\n\x07methods\x18\x04 \x03(\x0b\x32\x1a.concordium.v2.ReceiveName\x12%\n\x04name\x18\x05 \x01(\x0b\x32\x17.concordium.v2.InitName\x12/\n\rsource_module\x18\x06 \x01(\x0b\x32\x18.concordium.v2.ModuleRef\x1a\xde\x01\n\x02V1\x12,\n\x05owner\x18\x02 \x01(\x0b\x32\x1d.concordium.v2.AccountAddress\x12%\n\x06\x61mount\x18\x03 \x01(\x0b\x32\x15.concordium.v2.Amount\x12+\n\x07methods\x18\x04 \x03(\x0b\x32\x1a.concordium.v2.ReceiveName\x12%\n\x04name\x18\x05 \x01(\x0b\x32\x17.concordium.v2.InitName\x12/\n\rsource_module\x18\x06 \x01(\x0b\x32\x18.concordium.v2.ModuleRefB\t\n\x07version"1\n\x13InstanceStateKVPair\x12\x0b\n\x03key\x18\x01 \x01(\x0c\x12\r\n\x05value\x18\x02 \x01(\x0c"\x8d\x01\n\x1aInstanceStateLookupRequest\x12\x31\n\nblock_hash\x18\x01 \x01(\x0b\x32\x1d.concordium.v2.BlockHashInput\x12/\n\x07\x61\x64\x64ress\x18\x02 \x01(\x0b\x32\x1e.concordium.v2.ContractAddress\x12\x0b\n\x03key\x18\x03 \x01(\x0c"(\n\x17InstanceStateValueAtKey\x12\r\n\x05value\x18\x01 \x01(\x0c"\x1c\n\x0bReceiveName\x12\r\n\x05value\x18\x01 \x01(\t"\x19\n\x08InitName\x12\r\n\x05value\x18\x01 \x01(\t"\x1a\n\tParameter\x12\r\n\x05value\x18\x01 \x01(\x0c" \n\x0f\x43ontractStateV0\x12\r\n\x05value\x18\x01 \x01(\x0c"\xd0\x02\n\x0f\x42lockItemStatus\x12(\n\x08received\x18\x01 \x01(\x0b\x32\x14.concordium.v2.EmptyH\x00\x12=\n\tcommitted\x18\x02 \x01(\x0b\x32(.concordium.v2.BlockItemStatus.CommittedH\x00\x12=\n\tfinalized\x18\x03 \x01(\x0b\x32(.concordium.v2.BlockItemStatus.FinalizedH\x00\x1a\x45\n\tCommitted\x12\x38\n\x08outcomes\x18\x01 \x03(\x0b\x32&.concordium.v2.BlockItemSummaryInBlock\x1a\x44\n\tFinalized\x12\x37\n\x07outcome\x18\x01 \x01(\x0b\x32&.concordium.v2.BlockItemSummaryInBlockB\x08\n\x06status"y\n\x17\x42lockItemSummaryInBlock\x12,\n\nblock_hash\x18\x01 \x01(\x0b\x32\x18.concordium.v2.BlockHash\x12\x30\n\x07outcome\x18\x02 \x01(\x0b\x32\x1f.concordium.v2.BlockItemSummary"\x17\n\x06\x45nergy\x12\r\n\x05value\x18\x01 \x01(\x04"\x15\n\x04Slot\x12\r\n\x05value\x18\x01 \x01(\x04"f\n\x19NextAccountSequenceNumber\x12\x36\n\x0fsequence_number\x18\x01 \x01(\x0b\x32\x1d.concordium.v2.SequenceNumber\x12\x11\n\tall_final\x18\x02 \x01(\x08"\x19\n\x08\x44uration\x12\r\n\x05value\x18\x01 \x01(\x04"\xfa!\n\x0cRejectReason\x12-\n\rmodule_not_wf\x18\x01 \x01(\x0b\x32\x14.concordium.v2.EmptyH\x00\x12>\n\x1amodule_hash_already_exists\x18\x02 \x01(\x0b\x32\x18.concordium.v2.ModuleRefH\x00\x12\x42\n\x19invalid_account_reference\x18\x03 \x01(\x0b\x32\x1d.concordium.v2.AccountAddressH\x00\x12L\n\x13invalid_init_method\x18\x04 \x01(\x0b\x32-.concordium.v2.RejectReason.InvalidInitMethodH\x00\x12R\n\x16invalid_receive_method\x18\x05 \x01(\x0b\x32\x30.concordium.v2.RejectReason.InvalidReceiveMethodH\x00\x12<\n\x18invalid_module_reference\x18\x06 \x01(\x0b\x32\x18.concordium.v2.ModuleRefH\x00\x12\x42\n\x18invalid_contract_address\x18\x07 \x01(\x0b\x32\x1e.concordium.v2.ContractAddressH\x00\x12/\n\x0fruntime_failure\x18\x08 \x01(\x0b\x32\x14.concordium.v2.EmptyH\x00\x12\x46\n\x10\x61mount_too_large\x18\t \x01(\x0b\x32*.concordium.v2.RejectReason.AmountTooLargeH\x00\x12\x35\n\x15serialization_failure\x18\n \x01(\x0b\x32\x14.concordium.v2.EmptyH\x00\x12-\n\rout_of_energy\x18\x0b \x01(\x0b\x32\x14.concordium.v2.EmptyH\x00\x12\x41\n\rrejected_init\x18\x0c \x01(\x0b\x32(.concordium.v2.RejectReason.RejectedInitH\x00\x12G\n\x10rejected_receive\x18\r \x01(\x0b\x32+.concordium.v2.RejectReason.RejectedReceiveH\x00\x12-\n\rinvalid_proof\x18\x0e \x01(\x0b\x32\x14.concordium.v2.EmptyH\x00\x12\x31\n\x0f\x61lready_a_baker\x18\x0f \x01(\x0b\x32\x16.concordium.v2.BakerIdH\x00\x12\x34\n\x0bnot_a_baker\x18\x10 \x01(\x0b\x32\x1d.concordium.v2.AccountAddressH\x00\x12\x44\n$insufficient_balance_for_baker_stake\x18\x11 \x01(\x0b\x32\x14.concordium.v2.EmptyH\x00\x12H\n(stake_under_minimum_threshold_for_baking\x18\x12 \x01(\x0b\x32\x14.concordium.v2.EmptyH\x00\x12\x31\n\x11\x62\x61ker_in_cooldown\x18\x13 \x01(\x0b\x32\x14.concordium.v2.EmptyH\x00\x12M\n\x19\x64uplicate_aggregation_key\x18\x14 \x01(\x0b\x32(.concordium.v2.BakerAggregationVerifyKeyH\x00\x12:\n\x1anon_existent_credential_id\x18\x15 \x01(\x0b\x32\x14.concordium.v2.EmptyH\x00\x12\x38\n\x18key_index_already_in_use\x18\x16 \x01(\x0b\x32\x14.concordium.v2.EmptyH\x00\x12\x39\n\x19invalid_account_threshold\x18\x17 \x01(\x0b\x32\x14.concordium.v2.EmptyH\x00\x12\x45\n%invalid_credential_key_sign_threshold\x18\x18 \x01(\x0b\x32\x14.concordium.v2.EmptyH\x00\x12G\n\'invalid_encrypted_amount_transfer_proof\x18\x19 \x01(\x0b\x32\x14.concordium.v2.EmptyH\x00\x12@\n invalid_transfer_to_public_proof\x18\x1a \x01(\x0b\x32\x14.concordium.v2.EmptyH\x00\x12G\n\x1e\x65ncrypted_amount_self_transfer\x18\x1b \x01(\x0b\x32\x1d.concordium.v2.AccountAddressH\x00\x12\x43\n#invalid_index_on_encrypted_transfer\x18\x1c \x01(\x0b\x32\x14.concordium.v2.EmptyH\x00\x12\x34\n\x14zero_scheduledAmount\x18\x1d \x01(\x0b\x32\x14.concordium.v2.EmptyH\x00\x12\x37\n\x17non_increasing_schedule\x18\x1e \x01(\x0b\x32\x14.concordium.v2.EmptyH\x00\x12?\n\x1f\x66irst_scheduled_release_expired\x18\x1f \x01(\x0b\x32\x14.concordium.v2.EmptyH\x00\x12@\n\x17scheduled_self_transfer\x18  \x01(\x0b\x32\x1d.concordium.v2.AccountAddressH\x00\x12\x33\n\x13invalid_credentials\x18! \x01(\x0b\x32\x14.concordium.v2.EmptyH\x00\x12J\n\x12\x64uplicate_cred_ids\x18" \x01(\x0b\x32,.concordium.v2.RejectReason.DuplicateCredIdsH\x00\x12O\n\x15non_existent_cred_ids\x18# \x01(\x0b\x32..concordium.v2.RejectReason.NonExistentCredIdsH\x00\x12\x37\n\x17remove_first_credential\x18$ \x01(\x0b\x32\x14.concordium.v2.EmptyH\x00\x12>\n\x1e\x63redential_holder_did_not_sign\x18% \x01(\x0b\x32\x14.concordium.v2.EmptyH\x00\x12@\n not_allowed_multiple_credentials\x18& \x01(\x0b\x32\x14.concordium.v2.EmptyH\x00\x12@\n not_allowed_to_receive_encrypted\x18\' \x01(\x0b\x32\x14.concordium.v2.EmptyH\x00\x12?\n\x1fnot_allowed_to_handle_encrypted\x18( \x01(\x0b\x32\x14.concordium.v2.EmptyH\x00\x12<\n\x1cmissing_baker_add_parameters\x18) \x01(\x0b\x32\x14.concordium.v2.EmptyH\x00\x12K\n+finalization_reward_commission_not_in_range\x18* \x01(\x0b\x32\x14.concordium.v2.EmptyH\x00\x12\x45\n%baking_reward_commission_not_in_range\x18+ \x01(\x0b\x32\x14.concordium.v2.EmptyH\x00\x12G\n\'transaction_fee_commission_not_in_range\x18, \x01(\x0b\x32\x14.concordium.v2.EmptyH\x00\x12\x33\n\x13\x61lready_a_delegator\x18- \x01(\x0b\x32\x14.concordium.v2.EmptyH\x00\x12I\n)insufficient_balance_for_delegation_stake\x18. \x01(\x0b\x32\x14.concordium.v2.EmptyH\x00\x12\x41\n!missing_delegation_add_parameters\x18/ \x01(\x0b\x32\x14.concordium.v2.EmptyH\x00\x12=\n\x1dinsufficient_delegation_stake\x18\x30 \x01(\x0b\x32\x14.concordium.v2.EmptyH\x00\x12\x35\n\x15\x64\x65legator_in_cooldown\x18\x31 \x01(\x0b\x32\x14.concordium.v2.EmptyH\x00\x12\x38\n\x0fnot_a_delegator\x18\x32 \x01(\x0b\x32\x1d.concordium.v2.AccountAddressH\x00\x12?\n\x1d\x64\x65legation_target_not_a_baker\x18\x33 \x01(\x0b\x32\x16.concordium.v2.BakerIdH\x00\x12\x45\n%stake_over_maximum_threshold_for_pool\x18\x34 \x01(\x0b\x32\x14.concordium.v2.EmptyH\x00\x12@\n pool_would_become_over_delegated\x18\x35 \x01(\x0b\x32\x14.concordium.v2.EmptyH\x00\x12+\n\x0bpool_closed\x18\x36 \x01(\x0b\x32\x14.concordium.v2.EmptyH\x00\x12;\n\x15non_existent_token_id\x18\x37 \x01(\x0b\x32\x1a.concordium.v2.plt.TokenIdH\x00\x12U\n\x1ftoken_update_transaction_failed\x18\x38 \x01(\x0b\x32*.concordium.v2.plt.TokenModuleRejectReasonH\x00\x1am\n\x11InvalidInitMethod\x12,\n\nmodule_ref\x18\x01 \x01(\x0b\x32\x18.concordium.v2.ModuleRef\x12*\n\tinit_name\x18\x02 \x01(\x0b\x32\x17.concordium.v2.InitName\x1av\n\x14InvalidReceiveMethod\x12,\n\nmodule_ref\x18\x01 \x01(\x0b\x32\x18.concordium.v2.ModuleRef\x12\x30\n\x0creceive_name\x18\x02 \x01(\x0b\x32\x1a.concordium.v2.ReceiveName\x1a`\n\x0e\x41mountTooLarge\x12\'\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x16.concordium.v2.Address\x12%\n\x06\x61mount\x18\x02 \x01(\x0b\x32\x15.concordium.v2.Amount\x1a%\n\x0cRejectedInit\x12\x15\n\rreject_reason\x18\x01 \x01(\x05\x1a\xc1\x01\n\x0fRejectedReceive\x12\x15\n\rreject_reason\x18\x01 \x01(\x05\x12\x38\n\x10\x63ontract_address\x18\x02 \x01(\x0b\x32\x1e.concordium.v2.ContractAddress\x12\x30\n\x0creceive_name\x18\x03 \x01(\x0b\x32\x1a.concordium.v2.ReceiveName\x12+\n\tparameter\x18\x04 \x01(\x0b\x32\x18.concordium.v2.Parameter\x1aH\n\x10\x44uplicateCredIds\x12\x34\n\x03ids\x18\x01 \x03(\x0b\x32\'.concordium.v2.CredentialRegistrationId\x1aJ\n\x12NonExistentCredIds\x12\x34\n\x03ids\x18\x01 \x03(\x0b\x32\'.concordium.v2.CredentialRegistrationIdB\x08\n\x06reason"\xe1\x02\n\x18\x43ontractInitializedEvent\x12\x38\n\x10\x63ontract_version\x18\x01 \x01(\x0e\x32\x1e.concordium.v2.ContractVersion\x12,\n\norigin_ref\x18\x02 \x01(\x0b\x32\x18.concordium.v2.ModuleRef\x12/\n\x07\x61\x64\x64ress\x18\x03 \x01(\x0b\x32\x1e.concordium.v2.ContractAddress\x12%\n\x06\x61mount\x18\x04 \x01(\x0b\x32\x15.concordium.v2.Amount\x12*\n\tinit_name\x18\x05 \x01(\x0b\x32\x17.concordium.v2.InitName\x12,\n\x06\x65vents\x18\x06 \x03(\x0b\x32\x1c.concordium.v2.ContractEvent\x12+\n\tparameter\x18\x07 \x01(\x0b\x32\x18.concordium.v2.Parameter"\x1e\n\rContractEvent\x12\r\n\x05value\x18\x01 \x01(\x0c"\xe1\x02\n\x14InstanceUpdatedEvent\x12\x38\n\x10\x63ontract_version\x18\x01 \x01(\x0e\x32\x1e.concordium.v2.ContractVersion\x12/\n\x07\x61\x64\x64ress\x18\x02 \x01(\x0b\x32\x1e.concordium.v2.ContractAddress\x12*\n\ninstigator\x18\x03 \x01(\x0b\x32\x16.concordium.v2.Address\x12%\n\x06\x61mount\x18\x04 \x01(\x0b\x32\x15.concordium.v2.Amount\x12+\n\tparameter\x18\x05 \x01(\x0b\x32\x18.concordium.v2.Parameter\x12\x30\n\x0creceive_name\x18\x06 \x01(\x0b\x32\x1a.concordium.v2.ReceiveName\x12,\n\x06\x65vents\x18\x07 \x03(\x0b\x32\x1c.concordium.v2.ContractEvent"\xca\x06\n\x14\x43ontractTraceElement\x12\x36\n\x07updated\x18\x01 \x01(\x0b\x32#.concordium.v2.InstanceUpdatedEventH\x00\x12\x46\n\x0btransferred\x18\x02 \x01(\x0b\x32/.concordium.v2.ContractTraceElement.TransferredH\x00\x12\x46\n\x0binterrupted\x18\x03 \x01(\x0b\x32/.concordium.v2.ContractTraceElement.InterruptedH\x00\x12>\n\x07resumed\x18\x04 \x01(\x0b\x32+.concordium.v2.ContractTraceElement.ResumedH\x00\x12@\n\x08upgraded\x18\x05 \x01(\x0b\x32,.concordium.v2.ContractTraceElement.UpgradedH\x00\x1a\x95\x01\n\x0bTransferred\x12.\n\x06sender\x18\x01 \x01(\x0b\x32\x1e.concordium.v2.ContractAddress\x12%\n\x06\x61mount\x18\x02 \x01(\x0b\x32\x15.concordium.v2.Amount\x12/\n\x08receiver\x18\x03 \x01(\x0b\x32\x1d.concordium.v2.AccountAddress\x1al\n\x0bInterrupted\x12/\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x1e.concordium.v2.ContractAddress\x12,\n\x06\x65vents\x18\x02 \x03(\x0b\x32\x1c.concordium.v2.ContractEvent\x1aK\n\x07Resumed\x12/\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x1e.concordium.v2.ContractAddress\x12\x0f\n\x07success\x18\x02 \x01(\x08\x1a\x89\x01\n\x08Upgraded\x12/\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x1e.concordium.v2.ContractAddress\x12&\n\x04\x66rom\x18\x02 \x01(\x0b\x32\x18.concordium.v2.ModuleRef\x12$\n\x02to\x18\x03 \x01(\x0b\x32\x18.concordium.v2.ModuleRefB\t\n\x07\x65lement"\xa4\x02\n\x0e\x42\x61kerKeysEvent\x12(\n\x08\x62\x61ker_id\x18\x01 \x01(\x0b\x32\x16.concordium.v2.BakerId\x12.\n\x07\x61\x63\x63ount\x18\x02 \x01(\x0b\x32\x1d.concordium.v2.AccountAddress\x12\x38\n\x08sign_key\x18\x03 \x01(\x0b\x32&.concordium.v2.BakerSignatureVerifyKey\x12;\n\x0c\x65lection_key\x18\x04 \x01(\x0b\x32%.concordium.v2.BakerElectionVerifyKey\x12\x41\n\x0f\x61ggregation_key\x18\x05 \x01(\x0b\x32(.concordium.v2.BakerAggregationVerifyKey"~\n\x15\x42\x61kerStakeUpdatedData\x12(\n\x08\x62\x61ker_id\x18\x01 \x01(\x0b\x32\x16.concordium.v2.BakerId\x12(\n\tnew_stake\x18\x02 \x01(\x0b\x32\x15.concordium.v2.Amount\x12\x11\n\tincreased\x18\x03 \x01(\x08"\xcc\x01\n\x1b\x45ncryptedAmountRemovedEvent\x12.\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x1d.concordium.v2.AccountAddress\x12\x32\n\nnew_amount\x18\x02 \x01(\x0b\x32\x1e.concordium.v2.EncryptedAmount\x12\x34\n\x0cinput_amount\x18\x03 \x01(\x0b\x32\x1e.concordium.v2.EncryptedAmount\x12\x13\n\x0bup_to_index\x18\x04 \x01(\x04"\x97\x01\n\x17NewEncryptedAmountEvent\x12/\n\x08receiver\x18\x01 \x01(\x0b\x32\x1d.concordium.v2.AccountAddress\x12\x11\n\tnew_index\x18\x02 \x01(\x04\x12\x38\n\x10\x65ncrypted_amount\x18\x03 \x01(\x0b\x32\x1e.concordium.v2.EncryptedAmount"\xaa\x01\n\x1d\x45ncryptedSelfAmountAddedEvent\x12.\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x1d.concordium.v2.AccountAddress\x12\x32\n\nnew_amount\x18\x02 \x01(\x0b\x32\x1e.concordium.v2.EncryptedAmount\x12%\n\x06\x61mount\x18\x03 \x01(\x0b\x32\x15.concordium.v2.Amount"\x1f\n\x0eRegisteredData\x12\r\n\x05value\x18\x01 \x01(\x0c"\xe9\x12\n\nBakerEvent\x12;\n\x0b\x62\x61ker_added\x18\x01 \x01(\x0b\x32$.concordium.v2.BakerEvent.BakerAddedH\x00\x12/\n\rbaker_removed\x18\x02 \x01(\x0b\x32\x16.concordium.v2.BakerIdH\x00\x12N\n\x15\x62\x61ker_stake_increased\x18\x03 \x01(\x0b\x32-.concordium.v2.BakerEvent.BakerStakeIncreasedH\x00\x12N\n\x15\x62\x61ker_stake_decreased\x18\x04 \x01(\x0b\x32-.concordium.v2.BakerEvent.BakerStakeDecreasedH\x00\x12_\n\x1e\x62\x61ker_restake_earnings_updated\x18\x05 \x01(\x0b\x32\x35.concordium.v2.BakerEvent.BakerRestakeEarningsUpdatedH\x00\x12;\n\x12\x62\x61ker_keys_updated\x18\x06 \x01(\x0b\x32\x1d.concordium.v2.BakerKeysEventH\x00\x12M\n\x15\x62\x61ker_set_open_status\x18\x07 \x01(\x0b\x32,.concordium.v2.BakerEvent.BakerSetOpenStatusH\x00\x12O\n\x16\x62\x61ker_set_metadata_url\x18\x08 \x01(\x0b\x32-.concordium.v2.BakerEvent.BakerSetMetadataUrlH\x00\x12j\n$baker_set_transaction_fee_commission\x18\t \x01(\x0b\x32:.concordium.v2.BakerEvent.BakerSetTransactionFeeCommissionH\x00\x12\x66\n"baker_set_baking_reward_commission\x18\n \x01(\x0b\x32\x38.concordium.v2.BakerEvent.BakerSetBakingRewardCommissionH\x00\x12r\n(baker_set_finalization_reward_commission\x18\x0b \x01(\x0b\x32>.concordium.v2.BakerEvent.BakerSetFinalizationRewardCommissionH\x00\x12I\n\x12\x64\x65legation_removed\x18\x0c \x01(\x0b\x32+.concordium.v2.BakerEvent.DelegationRemovedH\x00\x12\x43\n\x0f\x62\x61ker_suspended\x18\r \x01(\x0b\x32(.concordium.v2.BakerEvent.BakerSuspendedH\x00\x12?\n\rbaker_resumed\x18\x0e \x01(\x0b\x32&.concordium.v2.BakerEvent.BakerResumedH\x00\x1a\x7f\n\nBakerAdded\x12\x31\n\nkeys_event\x18\x01 \x01(\x0b\x32\x1d.concordium.v2.BakerKeysEvent\x12$\n\x05stake\x18\x02 \x01(\x0b\x32\x15.concordium.v2.Amount\x12\x18\n\x10restake_earnings\x18\x03 \x01(\x08\x1ai\n\x13\x42\x61kerStakeIncreased\x12(\n\x08\x62\x61ker_id\x18\x01 \x01(\x0b\x32\x16.concordium.v2.BakerId\x12(\n\tnew_stake\x18\x02 \x01(\x0b\x32\x15.concordium.v2.Amount\x1ai\n\x13\x42\x61kerStakeDecreased\x12(\n\x08\x62\x61ker_id\x18\x01 \x01(\x0b\x32\x16.concordium.v2.BakerId\x12(\n\tnew_stake\x18\x02 \x01(\x0b\x32\x15.concordium.v2.Amount\x1a\x61\n\x1b\x42\x61kerRestakeEarningsUpdated\x12(\n\x08\x62\x61ker_id\x18\x01 \x01(\x0b\x32\x16.concordium.v2.BakerId\x12\x18\n\x10restake_earnings\x18\x02 \x01(\x08\x1an\n\x12\x42\x61kerSetOpenStatus\x12(\n\x08\x62\x61ker_id\x18\x01 \x01(\x0b\x32\x16.concordium.v2.BakerId\x12.\n\x0bopen_status\x18\x02 \x01(\x0e\x32\x19.concordium.v2.OpenStatus\x1aL\n\x13\x42\x61kerSetMetadataUrl\x12(\n\x08\x62\x61ker_id\x18\x01 \x01(\x0b\x32\x16.concordium.v2.BakerId\x12\x0b\n\x03url\x18\x02 \x01(\t\x1a\x8f\x01\n BakerSetTransactionFeeCommission\x12(\n\x08\x62\x61ker_id\x18\x01 \x01(\x0b\x32\x16.concordium.v2.BakerId\x12\x41\n\x1atransaction_fee_commission\x18\x02 \x01(\x0b\x32\x1d.concordium.v2.AmountFraction\x1a\x8b\x01\n\x1e\x42\x61kerSetBakingRewardCommission\x12(\n\x08\x62\x61ker_id\x18\x01 \x01(\x0b\x32\x16.concordium.v2.BakerId\x12?\n\x18\x62\x61king_reward_commission\x18\x02 \x01(\x0b\x32\x1d.concordium.v2.AmountFraction\x1a\x97\x01\n$BakerSetFinalizationRewardCommission\x12(\n\x08\x62\x61ker_id\x18\x01 \x01(\x0b\x32\x16.concordium.v2.BakerId\x12\x45\n\x1e\x66inalization_reward_commission\x18\x02 \x01(\x0b\x32\x1d.concordium.v2.AmountFraction\x1a\x45\n\x11\x44\x65legationRemoved\x12\x30\n\x0c\x64\x65legator_id\x18\x01 \x01(\x0b\x32\x1a.concordium.v2.DelegatorId\x1a:\n\x0e\x42\x61kerSuspended\x12(\n\x08\x62\x61ker_id\x18\x01 \x01(\x0b\x32\x16.concordium.v2.BakerId\x1a\x38\n\x0c\x42\x61kerResumed\x12(\n\x08\x62\x61ker_id\x18\x01 \x01(\x0b\x32\x16.concordium.v2.BakerIdB\x07\n\x05\x65vent"6\n\x0b\x44\x65legatorId\x12\'\n\x02id\x18\x01 \x01(\x0b\x32\x1b.concordium.v2.AccountIndex"\x88\t\n\x0f\x44\x65legationEvent\x12]\n\x1a\x64\x65legation_stake_increased\x18\x01 \x01(\x0b\x32\x37.concordium.v2.DelegationEvent.DelegationStakeIncreasedH\x00\x12]\n\x1a\x64\x65legation_stake_decreased\x18\x02 \x01(\x0b\x32\x37.concordium.v2.DelegationEvent.DelegationStakeDecreasedH\x00\x12\x66\n\x1f\x64\x65legation_set_restake_earnings\x18\x03 \x01(\x0b\x32;.concordium.v2.DelegationEvent.DelegationSetRestakeEarningsH\x00\x12h\n delegation_set_delegation_target\x18\x04 \x01(\x0b\x32<.concordium.v2.DelegationEvent.DelegationSetDelegationTargetH\x00\x12\x36\n\x10\x64\x65legation_added\x18\x05 \x01(\x0b\x32\x1a.concordium.v2.DelegatorIdH\x00\x12\x38\n\x12\x64\x65legation_removed\x18\x06 \x01(\x0b\x32\x1a.concordium.v2.DelegatorIdH\x00\x12\x44\n\rbaker_removed\x18\x07 \x01(\x0b\x32+.concordium.v2.DelegationEvent.BakerRemovedH\x00\x1av\n\x18\x44\x65legationStakeIncreased\x12\x30\n\x0c\x64\x65legator_id\x18\x01 \x01(\x0b\x32\x1a.concordium.v2.DelegatorId\x12(\n\tnew_stake\x18\x02 \x01(\x0b\x32\x15.concordium.v2.Amount\x1av\n\x18\x44\x65legationStakeDecreased\x12\x30\n\x0c\x64\x65legator_id\x18\x01 \x01(\x0b\x32\x1a.concordium.v2.DelegatorId\x12(\n\tnew_stake\x18\x02 \x01(\x0b\x32\x15.concordium.v2.Amount\x1aj\n\x1c\x44\x65legationSetRestakeEarnings\x12\x30\n\x0c\x64\x65legator_id\x18\x01 \x01(\x0b\x32\x1a.concordium.v2.DelegatorId\x12\x18\n\x10restake_earnings\x18\x02 \x01(\x08\x1a\x8d\x01\n\x1d\x44\x65legationSetDelegationTarget\x12\x30\n\x0c\x64\x65legator_id\x18\x01 \x01(\x0b\x32\x1a.concordium.v2.DelegatorId\x12:\n\x11\x64\x65legation_target\x18\x02 \x01(\x0b\x32\x1f.concordium.v2.DelegationTarget\x1a\x38\n\x0c\x42\x61kerRemoved\x12(\n\x08\x62\x61ker_id\x18\x01 \x01(\x0b\x32\x16.concordium.v2.BakerIdB\x07\n\x05\x65vent"\xf2\x16\n\x19\x41\x63\x63ountTransactionEffects\x12=\n\x04none\x18\x01 \x01(\x0b\x32-.concordium.v2.AccountTransactionEffects.NoneH\x00\x12\x33\n\x0fmodule_deployed\x18\x02 \x01(\x0b\x32\x18.concordium.v2.ModuleRefH\x00\x12G\n\x14\x63ontract_initialized\x18\x03 \x01(\x0b\x32\'.concordium.v2.ContractInitializedEventH\x00\x12_\n\x16\x63ontract_update_issued\x18\x04 \x01(\x0b\x32=.concordium.v2.AccountTransactionEffects.ContractUpdateIssuedH\x00\x12T\n\x10\x61\x63\x63ount_transfer\x18\x05 \x01(\x0b\x32\x38.concordium.v2.AccountTransactionEffects.AccountTransferH\x00\x12;\n\x0b\x62\x61ker_added\x18\x06 \x01(\x0b\x32$.concordium.v2.BakerEvent.BakerAddedH\x00\x12/\n\rbaker_removed\x18\x07 \x01(\x0b\x32\x16.concordium.v2.BakerIdH\x00\x12Y\n\x13\x62\x61ker_stake_updated\x18\x08 \x01(\x0b\x32:.concordium.v2.AccountTransactionEffects.BakerStakeUpdatedH\x00\x12_\n\x1e\x62\x61ker_restake_earnings_updated\x18\t \x01(\x0b\x32\x35.concordium.v2.BakerEvent.BakerRestakeEarningsUpdatedH\x00\x12;\n\x12\x62\x61ker_keys_updated\x18\n \x01(\x0b\x32\x1d.concordium.v2.BakerKeysEventH\x00\x12k\n\x1c\x65ncrypted_amount_transferred\x18\x0b \x01(\x0b\x32\x43.concordium.v2.AccountTransactionEffects.EncryptedAmountTransferredH\x00\x12P\n\x18transferred_to_encrypted\x18\x0c \x01(\x0b\x32,.concordium.v2.EncryptedSelfAmountAddedEventH\x00\x12]\n\x15transferred_to_public\x18\r \x01(\x0b\x32<.concordium.v2.AccountTransactionEffects.TransferredToPublicH\x00\x12\x65\n\x19transferred_with_schedule\x18\x0e \x01(\x0b\x32@.concordium.v2.AccountTransactionEffects.TransferredWithScheduleH\x00\x12J\n\x17\x63redential_keys_updated\x18\x0f \x01(\x0b\x32\'.concordium.v2.CredentialRegistrationIdH\x00\x12Z\n\x13\x63redentials_updated\x18\x10 \x01(\x0b\x32;.concordium.v2.AccountTransactionEffects.CredentialsUpdatedH\x00\x12\x38\n\x0f\x64\x61ta_registered\x18\x11 \x01(\x0b\x32\x1d.concordium.v2.RegisteredDataH\x00\x12T\n\x10\x62\x61ker_configured\x18\x12 \x01(\x0b\x32\x38.concordium.v2.AccountTransactionEffects.BakerConfiguredH\x00\x12^\n\x15\x64\x65legation_configured\x18\x13 \x01(\x0b\x32=.concordium.v2.AccountTransactionEffects.DelegationConfiguredH\x00\x12=\n\x13token_update_effect\x18\x14 \x01(\x0b\x32\x1e.concordium.v2.plt.TokenEffectH\x00\x1a\x8e\x01\n\x04None\x12=\n\x10transaction_type\x18\x01 \x01(\x0e\x32\x1e.concordium.v2.TransactionTypeH\x00\x88\x01\x01\x12\x32\n\rreject_reason\x18\x02 \x01(\x0b\x32\x1b.concordium.v2.RejectReasonB\x13\n\x11_transaction_type\x1aL\n\x14\x43ontractUpdateIssued\x12\x34\n\x07\x65\x66\x66\x65\x63ts\x18\x01 \x03(\x0b\x32#.concordium.v2.ContractTraceElement\x1a\x9a\x01\n\x0f\x41\x63\x63ountTransfer\x12%\n\x06\x61mount\x18\x01 \x01(\x0b\x32\x15.concordium.v2.Amount\x12/\n\x08receiver\x18\x02 \x01(\x0b\x32\x1d.concordium.v2.AccountAddress\x12&\n\x04memo\x18\x03 \x01(\x0b\x32\x13.concordium.v2.MemoH\x00\x88\x01\x01\x42\x07\n\x05_memo\x1aY\n\x11\x42\x61kerStakeUpdated\x12\x39\n\x06update\x18\x01 \x01(\x0b\x32$.concordium.v2.BakerStakeUpdatedDataH\x00\x88\x01\x01\x42\t\n\x07_update\x1a\xc1\x01\n\x1a\x45ncryptedAmountTransferred\x12;\n\x07removed\x18\x01 \x01(\x0b\x32*.concordium.v2.EncryptedAmountRemovedEvent\x12\x35\n\x05\x61\x64\x64\x65\x64\x18\x02 \x01(\x0b\x32&.concordium.v2.NewEncryptedAmountEvent\x12&\n\x04memo\x18\x03 \x01(\x0b\x32\x13.concordium.v2.MemoH\x00\x88\x01\x01\x42\x07\n\x05_memo\x1ay\n\x13TransferredToPublic\x12;\n\x07removed\x18\x01 \x01(\x0b\x32*.concordium.v2.EncryptedAmountRemovedEvent\x12%\n\x06\x61mount\x18\x02 \x01(\x0b\x32\x15.concordium.v2.Amount\x1a\xa6\x01\n\x17TransferredWithSchedule\x12/\n\x08receiver\x18\x01 \x01(\x0b\x32\x1d.concordium.v2.AccountAddress\x12)\n\x06\x61mount\x18\x02 \x03(\x0b\x32\x19.concordium.v2.NewRelease\x12&\n\x04memo\x18\x03 \x01(\x0b\x32\x13.concordium.v2.MemoH\x00\x88\x01\x01\x42\x07\n\x05_memo\x1a\xce\x01\n\x12\x43redentialsUpdated\x12=\n\x0cnew_cred_ids\x18\x01 \x03(\x0b\x32\'.concordium.v2.CredentialRegistrationId\x12\x41\n\x10removed_cred_ids\x18\x02 \x03(\x0b\x32\'.concordium.v2.CredentialRegistrationId\x12\x36\n\rnew_threshold\x18\x03 \x01(\x0b\x32\x1f.concordium.v2.AccountThreshold\x1a<\n\x0f\x42\x61kerConfigured\x12)\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x19.concordium.v2.BakerEvent\x1a\x46\n\x14\x44\x65legationConfigured\x12.\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x1e.concordium.v2.DelegationEventB\x08\n\x06\x65\x66\x66\x65\x63t"B\n\x12\x45lectionDifficulty\x12,\n\x05value\x18\x01 \x01(\x0b\x32\x1d.concordium.v2.AmountFraction"\xa2\x01\n\x11TimeoutParameters\x12-\n\x0ctimeout_base\x18\x01 \x01(\x0b\x32\x17.concordium.v2.Duration\x12.\n\x10timeout_increase\x18\x02 \x01(\x0b\x32\x14.concordium.v2.Ratio\x12.\n\x10timeout_decrease\x18\x03 \x01(\x0b\x32\x14.concordium.v2.Ratio"\xa4\x01\n\x1f\x46inalizationCommitteeParameters\x12\x1a\n\x12minimum_finalizers\x18\x01 \x01(\r\x12\x1a\n\x12maximum_finalizers\x18\x02 \x01(\r\x12I\n"finalizer_relative_stake_threshold\x18\x03 \x01(\x0b\x32\x1d.concordium.v2.AmountFraction"9\n\x18ValidatorScoreParameters\x12\x1d\n\x15maximum_missed_rounds\x18\x01 \x01(\x04"\xb9\x01\n\x15\x43onsensusParametersV1\x12<\n\x12timeout_parameters\x18\x01 \x01(\x0b\x32 .concordium.v2.TimeoutParameters\x12/\n\x0emin_block_time\x18\x02 \x01(\x0b\x32\x17.concordium.v2.Duration\x12\x31\n\x12\x62lock_energy_limit\x18\x03 \x01(\x0b\x32\x15.concordium.v2.Energy"3\n\x0c\x45xchangeRate\x12#\n\x05value\x18\x01 \x01(\x0b\x32\x14.concordium.v2.Ratio"/\n\x05Ratio\x12\x11\n\tnumerator\x18\x01 \x01(\x04\x12\x13\n\x0b\x64\x65nominator\x18\x02 \x01(\x04" \n\x0fUpdatePublicKey\x12\r\n\x05value\x18\x01 \x01(\x0c"$\n\x13UpdateKeysThreshold\x12\r\n\x05value\x18\x01 \x01(\r" \n\x0fUpdateKeysIndex\x12\r\n\x05value\x18\x01 \x01(\r"v\n\x0fHigherLevelKeys\x12,\n\x04keys\x18\x01 \x03(\x0b\x32\x1e.concordium.v2.UpdatePublicKey\x12\x35\n\tthreshold\x18\x02 \x01(\x0b\x32".concordium.v2.UpdateKeysThreshold"\x8b\x01\n\x0f\x41\x63\x63\x65ssStructure\x12:\n\x12\x61\x63\x63\x65ss_public_keys\x18\x01 \x03(\x0b\x32\x1e.concordium.v2.UpdateKeysIndex\x12<\n\x10\x61\x63\x63\x65ss_threshold\x18\x02 \x01(\x0b\x32".concordium.v2.UpdateKeysThreshold"\xbc\x06\n\x10\x41uthorizationsV0\x12,\n\x04keys\x18\x01 \x03(\x0b\x32\x1e.concordium.v2.UpdatePublicKey\x12\x31\n\temergency\x18\x02 \x01(\x0b\x32\x1e.concordium.v2.AccessStructure\x12\x30\n\x08protocol\x18\x03 \x01(\x0b\x32\x1e.concordium.v2.AccessStructure\x12;\n\x13parameter_consensus\x18\x04 \x01(\x0b\x32\x1e.concordium.v2.AccessStructure\x12\x41\n\x19parameter_euro_per_energy\x18\x05 \x01(\x0b\x32\x1e.concordium.v2.AccessStructure\x12\x44\n\x1cparameter_micro_CCD_per_euro\x18\x06 \x01(\x0b\x32\x1e.concordium.v2.AccessStructure\x12\x44\n\x1cparameter_foundation_account\x18\x07 \x01(\x0b\x32\x1e.concordium.v2.AccessStructure\x12\x43\n\x1bparameter_mint_distribution\x18\x08 \x01(\x0b\x32\x1e.concordium.v2.AccessStructure\x12N\n&parameter_transaction_fee_distribution\x18\t \x01(\x0b\x32\x1e.concordium.v2.AccessStructure\x12=\n\x15parameter_gas_rewards\x18\n \x01(\x0b\x32\x1e.concordium.v2.AccessStructure\x12\x37\n\x0fpool_parameters\x18\x0b \x01(\x0b\x32\x1e.concordium.v2.AccessStructure\x12=\n\x15\x61\x64\x64_anonymity_revoker\x18\x0c \x01(\x0b\x32\x1e.concordium.v2.AccessStructure\x12=\n\x15\x61\x64\x64_identity_provider\x18\r \x01(\x0b\x32\x1e.concordium.v2.AccessStructure"\xfb\x01\n\x10\x41uthorizationsV1\x12+\n\x02v0\x18\x01 \x01(\x0b\x32\x1f.concordium.v2.AuthorizationsV0\x12:\n\x12parameter_cooldown\x18\x02 \x01(\x0b\x32\x1e.concordium.v2.AccessStructure\x12\x36\n\x0eparameter_time\x18\x03 \x01(\x0b\x32\x1e.concordium.v2.AccessStructure\x12\x37\n\ncreate_plt\x18\x04 \x01(\x0b\x32\x1e.concordium.v2.AccessStructureH\x00\x88\x01\x01\x42\r\n\x0b_create_plt"=\n\x0b\x44\x65scription\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t"\xdf\x01\n\x06\x41rInfo\x12\x32\n\x08identity\x18\x01 \x01(\x0b\x32 .concordium.v2.ArInfo.ArIdentity\x12/\n\x0b\x64\x65scription\x18\x02 \x01(\x0b\x32\x1a.concordium.v2.Description\x12\x35\n\npublic_key\x18\x03 \x01(\x0b\x32!.concordium.v2.ArInfo.ArPublicKey\x1a\x1b\n\nArIdentity\x12\r\n\x05value\x18\x01 \x01(\r\x1a\x1c\n\x0b\x41rPublicKey\x12\r\n\x05value\x18\x01 \x01(\x0c"\x1b\n\nIpIdentity\x12\r\n\x05value\x18\x01 \x01(\r"\x9a\x02\n\x06IpInfo\x12+\n\x08identity\x18\x01 \x01(\x0b\x32\x19.concordium.v2.IpIdentity\x12/\n\x0b\x64\x65scription\x18\x02 \x01(\x0b\x32\x1a.concordium.v2.Description\x12\x35\n\nverify_key\x18\x03 \x01(\x0b\x32!.concordium.v2.IpInfo.IpVerifyKey\x12<\n\x0e\x63\x64i_verify_key\x18\x04 \x01(\x0b\x32$.concordium.v2.IpInfo.IpCdiVerifyKey\x1a\x1c\n\x0bIpVerifyKey\x12\r\n\x05value\x18\x01 \x01(\x0c\x1a\x1f\n\x0eIpCdiVerifyKey\x12\r\n\x05value\x18\x01 \x01(\x0c" \n\x0f\x44urationSeconds\x12\r\n\x05value\x18\x01 \x01(\x04"w\n\x1cInclusiveRangeAmountFraction\x12*\n\x03min\x18\x01 \x01(\x0b\x32\x1d.concordium.v2.AmountFraction\x12+\n\x04max_\x18\x02 \x01(\x0b\x32\x1d.concordium.v2.AmountFraction"\xd4\x01\n\x10\x43ommissionRanges\x12\x41\n\x0c\x66inalization\x18\x01 \x01(\x0b\x32+.concordium.v2.InclusiveRangeAmountFraction\x12;\n\x06\x62\x61king\x18\x02 \x01(\x0b\x32+.concordium.v2.InclusiveRangeAmountFraction\x12@\n\x0btransaction\x18\x03 \x01(\x0b\x32+.concordium.v2.InclusiveRangeAmountFraction"<\n\x0c\x43\x61pitalBound\x12,\n\x05value\x18\x01 \x01(\x0b\x32\x1d.concordium.v2.AmountFraction"5\n\x0eLeverageFactor\x12#\n\x05value\x18\x01 \x01(\x0b\x32\x14.concordium.v2.Ratio"\x16\n\x05\x45poch\x12\r\n\x05value\x18\x01 \x01(\x04"\x16\n\x05Round\x12\r\n\x05value\x18\x01 \x01(\x04"9\n\x12RewardPeriodLength\x12#\n\x05value\x18\x01 \x01(\x0b\x32\x14.concordium.v2.Epoch".\n\x08MintRate\x12\x10\n\x08mantissa\x18\x01 \x01(\r\x12\x10\n\x08\x65xponent\x18\x02 \x01(\r"\x91\x01\n\x16\x43ooldownParametersCpv1\x12;\n\x13pool_owner_cooldown\x18\x01 \x01(\x0b\x32\x1e.concordium.v2.DurationSeconds\x12:\n\x12\x64\x65legator_cooldown\x18\x02 \x01(\x0b\x32\x1e.concordium.v2.DurationSeconds"\xc3\x03\n\x12PoolParametersCpv1\x12\x46\n\x1fpassive_finalization_commission\x18\x01 \x01(\x0b\x32\x1d.concordium.v2.AmountFraction\x12@\n\x19passive_baking_commission\x18\x02 \x01(\x0b\x32\x1d.concordium.v2.AmountFraction\x12\x45\n\x1epassive_transaction_commission\x18\x03 \x01(\x0b\x32\x1d.concordium.v2.AmountFraction\x12:\n\x11\x63ommission_bounds\x18\x04 \x01(\x0b\x32\x1f.concordium.v2.CommissionRanges\x12\x35\n\x16minimum_equity_capital\x18\x05 \x01(\x0b\x32\x15.concordium.v2.Amount\x12\x32\n\rcapital_bound\x18\x06 \x01(\x0b\x32\x1b.concordium.v2.CapitalBound\x12\x35\n\x0eleverage_bound\x18\x07 \x01(\x0b\x32\x1d.concordium.v2.LeverageFactor"\x87\x01\n\x12TimeParametersCpv1\x12?\n\x14reward_period_length\x18\x01 \x01(\x0b\x32!.concordium.v2.RewardPeriodLength\x12\x30\n\x0fmint_per_payday\x18\x02 \x01(\x0b\x32\x17.concordium.v2.MintRate"\x88\x01\n\x14MintDistributionCpv1\x12\x34\n\rbaking_reward\x18\x01 \x01(\x0b\x32\x1d.concordium.v2.AmountFraction\x12:\n\x13\x66inalization_reward\x18\x02 \x01(\x0b\x32\x1d.concordium.v2.AmountFraction"\x99\x01\n\x0eProtocolUpdate\x12\x10\n\x08message_\x18\x01 \x01(\t\x12\x19\n\x11specification_url\x18\x02 \x01(\t\x12\x34\n\x11specificationHash\x18\x03 \x01(\x0b\x32\x19.concordium.v2.Sha256Hash\x12$\n\x1cspecification_auxiliary_data\x18\x04 \x01(\x0c"\xb8\x01\n\x14MintDistributionCpv0\x12.\n\rmint_per_slot\x18\x01 \x01(\x0b\x32\x17.concordium.v2.MintRate\x12\x34\n\rbaking_reward\x18\x02 \x01(\x0b\x32\x1d.concordium.v2.AmountFraction\x12:\n\x13\x66inalization_reward\x18\x03 \x01(\x0b\x32\x1d.concordium.v2.AmountFraction"~\n\x1aTransactionFeeDistribution\x12,\n\x05\x62\x61ker\x18\x01 \x01(\x0b\x32\x1d.concordium.v2.AmountFraction\x12\x32\n\x0bgas_account\x18\x02 \x01(\x0b\x32\x1d.concordium.v2.AmountFraction"\xe3\x01\n\nGasRewards\x12,\n\x05\x62\x61ker\x18\x01 \x01(\x0b\x32\x1d.concordium.v2.AmountFraction\x12\x39\n\x12\x66inalization_proof\x18\x02 \x01(\x0b\x32\x1d.concordium.v2.AmountFraction\x12\x37\n\x10\x61\x63\x63ount_creation\x18\x03 \x01(\x0b\x32\x1d.concordium.v2.AmountFraction\x12\x33\n\x0c\x63hain_update\x18\x04 \x01(\x0b\x32\x1d.concordium.v2.AmountFraction"\xac\x01\n\x0eGasRewardsCpv2\x12,\n\x05\x62\x61ker\x18\x01 \x01(\x0b\x32\x1d.concordium.v2.AmountFraction\x12\x37\n\x10\x61\x63\x63ount_creation\x18\x03 \x01(\x0b\x32\x1d.concordium.v2.AmountFraction\x12\x33\n\x0c\x63hain_update\x18\x04 \x01(\x0b\x32\x1d.concordium.v2.AmountFraction"K\n\x13\x42\x61kerStakeThreshold\x12\x34\n\x15\x62\x61ker_stake_threshold\x18\x01 \x01(\x0b\x32\x15.concordium.v2.Amount"\x9c\x02\n\nRootUpdate\x12:\n\x10root_keys_update\x18\x01 \x01(\x0b\x32\x1e.concordium.v2.HigherLevelKeysH\x00\x12=\n\x13level_1_keys_update\x18\x02 \x01(\x0b\x32\x1e.concordium.v2.HigherLevelKeysH\x00\x12\x41\n\x16level_2_keys_update_v0\x18\x03 \x01(\x0b\x32\x1f.concordium.v2.AuthorizationsV0H\x00\x12\x41\n\x16level_2_keys_update_v1\x18\x04 \x01(\x0b\x32\x1f.concordium.v2.AuthorizationsV1H\x00\x42\r\n\x0bupdate_type"\xe2\x01\n\x0cLevel1Update\x12=\n\x13level_1_keys_update\x18\x01 \x01(\x0b\x32\x1e.concordium.v2.HigherLevelKeysH\x00\x12\x41\n\x16level_2_keys_update_v0\x18\x02 \x01(\x0b\x32\x1f.concordium.v2.AuthorizationsV0H\x00\x12\x41\n\x16level_2_keys_update_v1\x18\x03 \x01(\x0b\x32\x1f.concordium.v2.AuthorizationsV1H\x00\x42\r\n\x0bupdate_type"\x9e\r\n\rUpdatePayload\x12\x38\n\x0fprotocol_update\x18\x01 \x01(\x0b\x32\x1d.concordium.v2.ProtocolUpdateH\x00\x12G\n\x1a\x65lection_difficulty_update\x18\x02 \x01(\x0b\x32!.concordium.v2.ElectionDifficultyH\x00\x12=\n\x16\x65uro_per_energy_update\x18\x03 \x01(\x0b\x32\x1b.concordium.v2.ExchangeRateH\x00\x12@\n\x19micro_ccd_per_euro_update\x18\x04 \x01(\x0b\x32\x1b.concordium.v2.ExchangeRateH\x00\x12\x42\n\x19\x66oundation_account_update\x18\x05 \x01(\x0b\x32\x1d.concordium.v2.AccountAddressH\x00\x12G\n\x18mint_distribution_update\x18\x06 \x01(\x0b\x32#.concordium.v2.MintDistributionCpv0H\x00\x12X\n#transaction_fee_distribution_update\x18\x07 \x01(\x0b\x32).concordium.v2.TransactionFeeDistributionH\x00\x12\x37\n\x12gas_rewards_update\x18\x08 \x01(\x0b\x32\x19.concordium.v2.GasRewardsH\x00\x12J\n\x1c\x62\x61ker_stake_threshold_update\x18\t \x01(\x0b\x32".concordium.v2.BakerStakeThresholdH\x00\x12\x30\n\x0broot_update\x18\n \x01(\x0b\x32\x19.concordium.v2.RootUpdateH\x00\x12\x35\n\x0elevel_1_update\x18\x0b \x01(\x0b\x32\x1b.concordium.v2.Level1UpdateH\x00\x12=\n\x1c\x61\x64\x64_anonymity_revoker_update\x18\x0c \x01(\x0b\x32\x15.concordium.v2.ArInfoH\x00\x12=\n\x1c\x61\x64\x64_identity_provider_update\x18\r \x01(\x0b\x32\x15.concordium.v2.IpInfoH\x00\x12Q\n cooldown_parameters_cpv_1_update\x18\x0e \x01(\x0b\x32%.concordium.v2.CooldownParametersCpv1H\x00\x12I\n\x1cpool_parameters_cpv_1_update\x18\x0f \x01(\x0b\x32!.concordium.v2.PoolParametersCpv1H\x00\x12I\n\x1ctime_parameters_cpv_1_update\x18\x10 \x01(\x0b\x32!.concordium.v2.TimeParametersCpv1H\x00\x12M\n\x1emint_distribution_cpv_1_update\x18\x11 \x01(\x0b\x32#.concordium.v2.MintDistributionCpv1H\x00\x12\x41\n\x18gas_rewards_cpv_2_update\x18\x12 \x01(\x0b\x32\x1d.concordium.v2.GasRewardsCpv2H\x00\x12\x45\n\x19timeout_parameters_update\x18\x13 \x01(\x0b\x32 .concordium.v2.TimeoutParametersH\x00\x12\x38\n\x15min_block_time_update\x18\x14 \x01(\x0b\x32\x17.concordium.v2.DurationH\x00\x12:\n\x19\x62lock_energy_limit_update\x18\x15 \x01(\x0b\x32\x15.concordium.v2.EnergyH\x00\x12\x62\n(finalization_committee_parameters_update\x18\x16 \x01(\x0b\x32..concordium.v2.FinalizationCommitteeParametersH\x00\x12T\n!validator_score_parameters_update\x18\x17 \x01(\x0b\x32\'.concordium.v2.ValidatorScoreParametersH\x00\x12\x39\n\x11\x63reate_plt_update\x18\x18 \x01(\x0b\x32\x1c.concordium.v2.plt.CreatePLTH\x00\x42\t\n\x07payload"\xaa\x01\n\x19\x41\x63\x63ountTransactionDetails\x12#\n\x04\x63ost\x18\x01 \x01(\x0b\x32\x15.concordium.v2.Amount\x12-\n\x06sender\x18\x02 \x01(\x0b\x32\x1d.concordium.v2.AccountAddress\x12\x39\n\x07\x65\x66\x66\x65\x63ts\x18\x03 \x01(\x0b\x32(.concordium.v2.AccountTransactionEffects"\xb9\x01\n\x16\x41\x63\x63ountCreationDetails\x12\x36\n\x0f\x63redential_type\x18\x01 \x01(\x0e\x32\x1d.concordium.v2.CredentialType\x12.\n\x07\x61\x64\x64ress\x18\x02 \x01(\x0b\x32\x1d.concordium.v2.AccountAddress\x12\x37\n\x06reg_id\x18\x03 \x01(\x0b\x32\'.concordium.v2.CredentialRegistrationId" \n\x0fTransactionTime\x12\r\n\x05value\x18\x01 \x01(\x04"v\n\rUpdateDetails\x12\x36\n\x0e\x65\x66\x66\x65\x63tive_time\x18\x01 \x01(\x0b\x32\x1e.concordium.v2.TransactionTime\x12-\n\x07payload\x18\x02 \x01(\x0b\x32\x1c.concordium.v2.UpdatePayload"\xda\x03\n\x10\x42lockItemSummary\x12?\n\x05index\x18\x01 \x01(\x0b\x32\x30.concordium.v2.BlockItemSummary.TransactionIndex\x12*\n\x0b\x65nergy_cost\x18\x02 \x01(\x0b\x32\x15.concordium.v2.Energy\x12,\n\x04hash\x18\x03 \x01(\x0b\x32\x1e.concordium.v2.TransactionHash\x12G\n\x13\x61\x63\x63ount_transaction\x18\x04 \x01(\x0b\x32(.concordium.v2.AccountTransactionDetailsH\x00\x12\x41\n\x10\x61\x63\x63ount_creation\x18\x05 \x01(\x0b\x32%.concordium.v2.AccountCreationDetailsH\x00\x12.\n\x06update\x18\x06 \x01(\x0b\x32\x1c.concordium.v2.UpdateDetailsH\x00\x12\x41\n\x0etoken_creation\x18\x07 \x01(\x0b\x32\'.concordium.v2.plt.TokenCreationDetailsH\x00\x1a!\n\x10TransactionIndex\x12\r\n\x05value\x18\x01 \x01(\x04\x42\t\n\x07\x64\x65tails"\x1d\n\x0cGenesisIndex\x12\r\n\x05value\x18\x01 \x01(\r"\xc7\x0f\n\rConsensusInfo\x12,\n\nbest_block\x18\x01 \x01(\x0b\x32\x18.concordium.v2.BlockHash\x12/\n\rgenesis_block\x18\x02 \x01(\x0b\x32\x18.concordium.v2.BlockHash\x12.\n\x0cgenesis_time\x18\x03 \x01(\x0b\x32\x18.concordium.v2.Timestamp\x12\x33\n\rslot_duration\x18\x04 \x01(\x0b\x32\x17.concordium.v2.DurationH\x00\x88\x01\x01\x12/\n\x0e\x65poch_duration\x18\x05 \x01(\x0b\x32\x17.concordium.v2.Duration\x12\x36\n\x14last_finalized_block\x18\x06 \x01(\x0b\x32\x18.concordium.v2.BlockHash\x12=\n\x11\x62\x65st_block_height\x18\x07 \x01(\x0b\x32".concordium.v2.AbsoluteBlockHeight\x12G\n\x1blast_finalized_block_height\x18\x08 \x01(\x0b\x32".concordium.v2.AbsoluteBlockHeight\x12\x1d\n\x15\x62locks_received_count\x18\t \x01(\r\x12?\n\x18\x62lock_last_received_time\x18\n \x01(\x0b\x32\x18.concordium.v2.TimestampH\x01\x88\x01\x01\x12!\n\x19\x62lock_receive_latency_ema\x18\x0b \x01(\x01\x12"\n\x1a\x62lock_receive_latency_emsd\x18\x0c \x01(\x01\x12%\n\x18\x62lock_receive_period_ema\x18\r \x01(\x01H\x02\x88\x01\x01\x12&\n\x19\x62lock_receive_period_emsd\x18\x0e \x01(\x01H\x03\x88\x01\x01\x12\x1d\n\x15\x62locks_verified_count\x18\x0f \x01(\r\x12>\n\x17\x62lock_last_arrived_time\x18\x10 \x01(\x0b\x32\x18.concordium.v2.TimestampH\x04\x88\x01\x01\x12 \n\x18\x62lock_arrive_latency_ema\x18\x11 \x01(\x01\x12!\n\x19\x62lock_arrive_latency_emsd\x18\x12 \x01(\x01\x12$\n\x17\x62lock_arrive_period_ema\x18\x13 \x01(\x01H\x05\x88\x01\x01\x12%\n\x18\x62lock_arrive_period_emsd\x18\x14 \x01(\x01H\x06\x88\x01\x01\x12"\n\x1atransactions_per_block_ema\x18\x15 \x01(\x01\x12#\n\x1btransactions_per_block_emsd\x18\x16 \x01(\x01\x12\x1a\n\x12\x66inalization_count\x18\x17 \x01(\r\x12:\n\x13last_finalized_time\x18\x18 \x01(\x0b\x32\x18.concordium.v2.TimestampH\x07\x88\x01\x01\x12$\n\x17\x66inalization_period_ema\x18\x19 \x01(\x01H\x08\x88\x01\x01\x12%\n\x18\x66inalization_period_emsd\x18\x1a \x01(\x01H\t\x88\x01\x01\x12\x38\n\x10protocol_version\x18\x1b \x01(\x0e\x32\x1e.concordium.v2.ProtocolVersion\x12\x32\n\rgenesis_index\x18\x1c \x01(\x0b\x32\x1b.concordium.v2.GenesisIndex\x12;\n\x19\x63urrent_era_genesis_block\x18\x1d \x01(\x0b\x32\x18.concordium.v2.BlockHash\x12:\n\x18\x63urrent_era_genesis_time\x18\x1e \x01(\x0b\x32\x18.concordium.v2.Timestamp\x12>\n\x18\x63urrent_timeout_duration\x18\x1f \x01(\x0b\x32\x17.concordium.v2.DurationH\n\x88\x01\x01\x12\x30\n\rcurrent_round\x18  \x01(\x0b\x32\x14.concordium.v2.RoundH\x0b\x88\x01\x01\x12\x30\n\rcurrent_epoch\x18! \x01(\x0b\x32\x14.concordium.v2.EpochH\x0c\x88\x01\x01\x12\x39\n\x12trigger_block_time\x18" \x01(\x0b\x32\x18.concordium.v2.TimestampH\r\x88\x01\x01\x42\x10\n\x0e_slot_durationB\x1b\n\x19_block_last_received_timeB\x1b\n\x19_block_receive_period_emaB\x1c\n\x1a_block_receive_period_emsdB\x1a\n\x18_block_last_arrived_timeB\x1a\n\x18_block_arrive_period_emaB\x1b\n\x19_block_arrive_period_emsdB\x16\n\x14_last_finalized_timeB\x1a\n\x18_finalization_period_emaB\x1b\n\x19_finalization_period_emsdB\x1b\n\x19_current_timeout_durationB\x10\n\x0e_current_roundB\x10\n\x0e_current_epochB\x15\n\x13_trigger_block_time"n\n\x10\x41rrivedBlockInfo\x12&\n\x04hash\x18\x01 \x01(\x0b\x32\x18.concordium.v2.BlockHash\x12\x32\n\x06height\x18\x02 \x01(\x0b\x32".concordium.v2.AbsoluteBlockHeight"r\n\x17\x43ryptographicParameters\x12\x16\n\x0egenesis_string\x18\x01 \x01(\t\x12\x1e\n\x16\x62ulletproof_generators\x18\x02 \x01(\x0c\x12\x1f\n\x17on_chain_commitment_key\x18\x03 \x01(\x0c"\x8c\x07\n\tBlockInfo\x12&\n\x04hash\x18\x01 \x01(\x0b\x32\x18.concordium.v2.BlockHash\x12\x32\n\x06height\x18\x02 \x01(\x0b\x32".concordium.v2.AbsoluteBlockHeight\x12.\n\x0cparent_block\x18\x03 \x01(\x0b\x32\x18.concordium.v2.BlockHash\x12\x36\n\x14last_finalized_block\x18\x04 \x01(\x0b\x32\x18.concordium.v2.BlockHash\x12\x32\n\rgenesis_index\x18\x05 \x01(\x0b\x32\x1b.concordium.v2.GenesisIndex\x12\x34\n\x10\x65ra_block_height\x18\x06 \x01(\x0b\x32\x1a.concordium.v2.BlockHeight\x12.\n\x0creceive_time\x18\x07 \x01(\x0b\x32\x18.concordium.v2.Timestamp\x12-\n\x0b\x61rrive_time\x18\x08 \x01(\x0b\x32\x18.concordium.v2.Timestamp\x12-\n\x0bslot_number\x18\t \x01(\x0b\x32\x13.concordium.v2.SlotH\x00\x88\x01\x01\x12+\n\tslot_time\x18\n \x01(\x0b\x32\x18.concordium.v2.Timestamp\x12*\n\x05\x62\x61ker\x18\x0b \x01(\x0b\x32\x16.concordium.v2.BakerIdH\x01\x88\x01\x01\x12\x11\n\tfinalized\x18\x0c \x01(\x08\x12\x19\n\x11transaction_count\x18\r \x01(\r\x12\x37\n\x18transactions_energy_cost\x18\x0e \x01(\x0b\x32\x15.concordium.v2.Energy\x12\x19\n\x11transactions_size\x18\x0f \x01(\r\x12,\n\nstate_hash\x18\x10 \x01(\x0b\x32\x18.concordium.v2.StateHash\x12\x38\n\x10protocol_version\x18\x11 \x01(\x0e\x32\x1e.concordium.v2.ProtocolVersion\x12(\n\x05round\x18\x12 \x01(\x0b\x32\x14.concordium.v2.RoundH\x02\x88\x01\x01\x12(\n\x05\x65poch\x18\x13 \x01(\x0b\x32\x14.concordium.v2.EpochH\x03\x88\x01\x01\x42\x0e\n\x0c_slot_numberB\x08\n\x06_bakerB\x08\n\x06_roundB\x08\n\x06_epoch"k\n\x0fPoolInfoRequest\x12\x31\n\nblock_hash\x18\x01 \x01(\x0b\x32\x1d.concordium.v2.BlockHashInput\x12%\n\x05\x62\x61ker\x18\x02 \x01(\x0b\x32\x16.concordium.v2.BakerId"\xc2\x02\n\x11PoolPendingChange\x12\x39\n\x06reduce\x18\x01 \x01(\x0b\x32\'.concordium.v2.PoolPendingChange.ReduceH\x00\x12\x39\n\x06remove\x18\x02 \x01(\x0b\x32\'.concordium.v2.PoolPendingChange.RemoveH\x00\x1aq\n\x06Reduce\x12\x35\n\x16reduced_equity_capital\x18\x01 \x01(\x0b\x32\x15.concordium.v2.Amount\x12\x30\n\x0e\x65\x66\x66\x65\x63tive_time\x18\x02 \x01(\x0b\x32\x18.concordium.v2.Timestamp\x1a:\n\x06Remove\x12\x30\n\x0e\x65\x66\x66\x65\x63tive_time\x18\x01 \x01(\x0b\x32\x18.concordium.v2.TimestampB\x08\n\x06\x63hange"\xda\x03\n\x15PoolCurrentPaydayInfo\x12\x14\n\x0c\x62locks_baked\x18\x01 \x01(\x04\x12\x19\n\x11\x66inalization_live\x18\x02 \x01(\x08\x12\x36\n\x17transaction_fees_earned\x18\x03 \x01(\x0b\x32\x15.concordium.v2.Amount\x12.\n\x0f\x65\x66\x66\x65\x63tive_stake\x18\x04 \x01(\x0b\x32\x15.concordium.v2.Amount\x12\x15\n\rlottery_power\x18\x05 \x01(\x01\x12\x33\n\x14\x62\x61ker_equity_capital\x18\x06 \x01(\x0b\x32\x15.concordium.v2.Amount\x12\x30\n\x11\x64\x65legated_capital\x18\x07 \x01(\x0b\x32\x15.concordium.v2.Amount\x12\x38\n\x10\x63ommission_rates\x18\x08 \x01(\x0b\x32\x1e.concordium.v2.CommissionRates\x12%\n\x18is_primed_for_suspension\x18\t \x01(\x08H\x00\x88\x01\x01\x12\x1a\n\rmissed_rounds\x18\n \x01(\x04H\x01\x88\x01\x01\x42\x1b\n\x19_is_primed_for_suspensionB\x10\n\x0e_missed_rounds"\xb9\x05\n\x10PoolInfoResponse\x12%\n\x05\x62\x61ker\x18\x01 \x01(\x0b\x32\x16.concordium.v2.BakerId\x12.\n\x07\x61\x64\x64ress\x18\x02 \x01(\x0b\x32\x1d.concordium.v2.AccountAddress\x12\x32\n\x0e\x65quity_capital\x18\x03 \x01(\x0b\x32\x15.concordium.v2.AmountH\x00\x88\x01\x01\x12\x35\n\x11\x64\x65legated_capital\x18\x04 \x01(\x0b\x32\x15.concordium.v2.AmountH\x01\x88\x01\x01\x12\x39\n\x15\x64\x65legated_capital_cap\x18\x05 \x01(\x0b\x32\x15.concordium.v2.AmountH\x02\x88\x01\x01\x12\x34\n\tpool_info\x18\x06 \x01(\x0b\x32\x1c.concordium.v2.BakerPoolInfoH\x03\x88\x01\x01\x12\x44\n\x15\x65quity_pending_change\x18\x07 \x01(\x0b\x32 .concordium.v2.PoolPendingChangeH\x04\x88\x01\x01\x12\x46\n\x13\x63urrent_payday_info\x18\x08 \x01(\x0b\x32$.concordium.v2.PoolCurrentPaydayInfoH\x05\x88\x01\x01\x12\x35\n\x16\x61ll_pool_total_capital\x18\t \x01(\x0b\x32\x15.concordium.v2.Amount\x12\x19\n\x0cis_suspended\x18\n \x01(\x08H\x06\x88\x01\x01\x42\x11\n\x0f_equity_capitalB\x14\n\x12_delegated_capitalB\x18\n\x16_delegated_capital_capB\x0c\n\n_pool_infoB\x18\n\x16_equity_pending_changeB\x16\n\x14_current_payday_infoB\x0f\n\r_is_suspended"\xc2\x02\n\x15PassiveDelegationInfo\x12\x30\n\x11\x64\x65legated_capital\x18\x01 \x01(\x0b\x32\x15.concordium.v2.Amount\x12\x38\n\x10\x63ommission_rates\x18\x02 \x01(\x0b\x32\x1e.concordium.v2.CommissionRates\x12\x45\n&current_payday_transaction_fees_earned\x18\x03 \x01(\x0b\x32\x15.concordium.v2.Amount\x12?\n current_payday_delegated_capital\x18\x04 \x01(\x0b\x32\x15.concordium.v2.Amount\x12\x35\n\x16\x61ll_pool_total_capital\x18\x05 \x01(\x0b\x32\x15.concordium.v2.Amount"\xef\x02\n\x15\x42locksAtHeightRequest\x12\x41\n\x08\x61\x62solute\x18\x01 \x01(\x0b\x32-.concordium.v2.BlocksAtHeightRequest.AbsoluteH\x00\x12\x41\n\x08relative\x18\x02 \x01(\x0b\x32-.concordium.v2.BlocksAtHeightRequest.RelativeH\x00\x1a>\n\x08\x41\x62solute\x12\x32\n\x06height\x18\x01 \x01(\x0b\x32".concordium.v2.AbsoluteBlockHeight\x1a|\n\x08Relative\x12\x32\n\rgenesis_index\x18\x01 \x01(\x0b\x32\x1b.concordium.v2.GenesisIndex\x12*\n\x06height\x18\x02 \x01(\x0b\x32\x1a.concordium.v2.BlockHeight\x12\x10\n\x08restrict\x18\x03 \x01(\x08\x42\x12\n\x10\x62locks_at_height"B\n\x16\x42locksAtHeightResponse\x12(\n\x06\x62locks\x18\x01 \x03(\x0b\x32\x18.concordium.v2.BlockHash"\xe4\x07\n\x0eTokenomicsInfo\x12.\n\x02v0\x18\x01 \x01(\x0b\x32 .concordium.v2.TokenomicsInfo.V0H\x00\x12.\n\x02v1\x18\x02 \x01(\x0b\x32 .concordium.v2.TokenomicsInfo.V1H\x00\x1a\xc0\x02\n\x02V0\x12+\n\x0ctotal_amount\x18\x01 \x01(\x0b\x32\x15.concordium.v2.Amount\x12\x35\n\x16total_encrypted_amount\x18\x02 \x01(\x0b\x32\x15.concordium.v2.Amount\x12\x34\n\x15\x62\x61king_reward_account\x18\x03 \x01(\x0b\x32\x15.concordium.v2.Amount\x12:\n\x1b\x66inalization_reward_account\x18\x04 \x01(\x0b\x32\x15.concordium.v2.Amount\x12*\n\x0bgas_account\x18\x05 \x01(\x0b\x32\x15.concordium.v2.Amount\x12\x38\n\x10protocol_version\x18\x06 \x01(\x0e\x32\x1e.concordium.v2.ProtocolVersion\x1a\xa0\x04\n\x02V1\x12+\n\x0ctotal_amount\x18\x01 \x01(\x0b\x32\x15.concordium.v2.Amount\x12\x35\n\x16total_encrypted_amount\x18\x02 \x01(\x0b\x32\x15.concordium.v2.Amount\x12\x34\n\x15\x62\x61king_reward_account\x18\x03 \x01(\x0b\x32\x15.concordium.v2.Amount\x12:\n\x1b\x66inalization_reward_account\x18\x04 \x01(\x0b\x32\x15.concordium.v2.Amount\x12*\n\x0bgas_account\x18\x05 \x01(\x0b\x32\x15.concordium.v2.Amount\x12=\n\x1e\x66oundation_transaction_rewards\x18\x06 \x01(\x0b\x32\x15.concordium.v2.Amount\x12\x32\n\x10next_payday_time\x18\x07 \x01(\x0b\x32\x18.concordium.v2.Timestamp\x12\x36\n\x15next_payday_mint_rate\x18\x08 \x01(\x0b\x32\x17.concordium.v2.MintRate\x12\x33\n\x14total_staked_capital\x18\t \x01(\x0b\x32\x15.concordium.v2.Amount\x12\x38\n\x10protocol_version\x18\n \x01(\x0e\x32\x1e.concordium.v2.ProtocolVersionB\x0c\n\ntokenomics"\xe1\x02\n\x15InvokeInstanceRequest\x12\x31\n\nblock_hash\x18\x01 \x01(\x0b\x32\x1d.concordium.v2.BlockHashInput\x12,\n\x07invoker\x18\x02 \x01(\x0b\x32\x16.concordium.v2.AddressH\x00\x88\x01\x01\x12\x30\n\x08instance\x18\x03 \x01(\x0b\x32\x1e.concordium.v2.ContractAddress\x12%\n\x06\x61mount\x18\x04 \x01(\x0b\x32\x15.concordium.v2.Amount\x12.\n\nentrypoint\x18\x05 \x01(\x0b\x32\x1a.concordium.v2.ReceiveName\x12+\n\tparameter\x18\x06 \x01(\x0b\x32\x18.concordium.v2.Parameter\x12%\n\x06\x65nergy\x18\x07 \x01(\x0b\x32\x15.concordium.v2.EnergyB\n\n\x08_invoker"\xd1\x03\n\x16InvokeInstanceResponse\x12@\n\x07success\x18\x01 \x01(\x0b\x32-.concordium.v2.InvokeInstanceResponse.SuccessH\x00\x12@\n\x07\x66\x61ilure\x18\x02 \x01(\x0b\x32-.concordium.v2.InvokeInstanceResponse.FailureH\x00\x1a\x8e\x01\n\x07\x46\x61ilure\x12\x19\n\x0creturn_value\x18\x01 \x01(\x0cH\x00\x88\x01\x01\x12*\n\x0bused_energy\x18\x02 \x01(\x0b\x32\x15.concordium.v2.Energy\x12+\n\x06reason\x18\x03 \x01(\x0b\x32\x1b.concordium.v2.RejectReasonB\x0f\n\r_return_value\x1a\x97\x01\n\x07Success\x12\x19\n\x0creturn_value\x18\x01 \x01(\x0cH\x00\x88\x01\x01\x12*\n\x0bused_energy\x18\x02 \x01(\x0b\x32\x15.concordium.v2.Energy\x12\x34\n\x07\x65\x66\x66\x65\x63ts\x18\x03 \x03(\x0b\x32#.concordium.v2.ContractTraceElementB\x0f\n\r_return_valueB\x08\n\x06result"t\n\x18GetPoolDelegatorsRequest\x12\x31\n\nblock_hash\x18\x01 \x01(\x0b\x32\x1d.concordium.v2.BlockHashInput\x12%\n\x05\x62\x61ker\x18\x02 \x01(\x0b\x32\x16.concordium.v2.BakerId"\xb8\x01\n\rDelegatorInfo\x12.\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x1d.concordium.v2.AccountAddress\x12$\n\x05stake\x18\x02 \x01(\x0b\x32\x15.concordium.v2.Amount\x12>\n\x0epending_change\x18\x03 \x01(\x0b\x32!.concordium.v2.StakePendingChangeH\x00\x88\x01\x01\x42\x11\n\x0f_pending_change"q\n\x19\x44\x65legatorRewardPeriodInfo\x12.\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x1d.concordium.v2.AccountAddress\x12$\n\x05stake\x18\x02 \x01(\x0b\x32\x15.concordium.v2.Amount"_\n\x06\x42ranch\x12,\n\nblock_hash\x18\x01 \x01(\x0b\x32\x18.concordium.v2.BlockHash\x12\'\n\x08\x63hildren\x18\x02 \x03(\x0b\x32\x15.concordium.v2.Branch"(\n\x17LeadershipElectionNonce\x12\r\n\x05value\x18\x01 \x01(\x0c"\xe2\x02\n\x0c\x45lectionInfo\x12\x43\n\x13\x65lection_difficulty\x18\x01 \x01(\x0b\x32!.concordium.v2.ElectionDifficultyH\x00\x88\x01\x01\x12>\n\x0e\x65lection_nonce\x18\x02 \x01(\x0b\x32&.concordium.v2.LeadershipElectionNonce\x12>\n\x13\x62\x61ker_election_info\x18\x03 \x03(\x0b\x32!.concordium.v2.ElectionInfo.Baker\x1au\n\x05\x42\x61ker\x12%\n\x05\x62\x61ker\x18\x01 \x01(\x0b\x32\x16.concordium.v2.BakerId\x12.\n\x07\x61\x63\x63ount\x18\x02 \x01(\x0b\x32\x1d.concordium.v2.AccountAddress\x12\x15\n\rlottery_power\x18\x03 \x01(\x01\x42\x16\n\x14_election_difficulty"\x89\x18\n\x11\x42lockSpecialEvent\x12H\n\x0e\x62\x61king_rewards\x18\x01 \x01(\x0b\x32..concordium.v2.BlockSpecialEvent.BakingRewardsH\x00\x12\x35\n\x04mint\x18\x02 \x01(\x0b\x32%.concordium.v2.BlockSpecialEvent.MintH\x00\x12T\n\x14\x66inalization_rewards\x18\x03 \x01(\x0b\x32\x34.concordium.v2.BlockSpecialEvent.FinalizationRewardsH\x00\x12\x44\n\x0c\x62lock_reward\x18\x04 \x01(\x0b\x32,.concordium.v2.BlockSpecialEvent.BlockRewardH\x00\x12[\n\x18payday_foundation_reward\x18\x05 \x01(\x0b\x32\x37.concordium.v2.BlockSpecialEvent.PaydayFoundationRewardH\x00\x12U\n\x15payday_account_reward\x18\x06 \x01(\x0b\x32\x34.concordium.v2.BlockSpecialEvent.PaydayAccountRewardH\x00\x12Q\n\x13\x62lock_accrue_reward\x18\x07 \x01(\x0b\x32\x32.concordium.v2.BlockSpecialEvent.BlockAccrueRewardH\x00\x12O\n\x12payday_pool_reward\x18\x08 \x01(\x0b\x32\x31.concordium.v2.BlockSpecialEvent.PaydayPoolRewardH\x00\x12R\n\x13validator_suspended\x18\t \x01(\x0b\x32\x33.concordium.v2.BlockSpecialEvent.ValidatorSuspendedH\x00\x12h\n\x1fvalidator_primed_for_suspension\x18\n \x01(\x0b\x32=.concordium.v2.BlockSpecialEvent.ValidatorPrimedForSuspensionH\x00\x1a\xb8\x01\n\x0e\x41\x63\x63ountAmounts\x12\x46\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x35.concordium.v2.BlockSpecialEvent.AccountAmounts.Entry\x1a^\n\x05\x45ntry\x12.\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x1d.concordium.v2.AccountAddress\x12%\n\x06\x61mount\x18\x02 \x01(\x0b\x32\x15.concordium.v2.Amount\x1a\x81\x01\n\rBakingRewards\x12\x46\n\rbaker_rewards\x18\x01 \x01(\x0b\x32/.concordium.v2.BlockSpecialEvent.AccountAmounts\x12(\n\tremainder\x18\x02 \x01(\x0b\x32\x15.concordium.v2.Amount\x1a\xee\x01\n\x04Mint\x12\x31\n\x12mint_baking_reward\x18\x01 \x01(\x0b\x32\x15.concordium.v2.Amount\x12\x37\n\x18mint_finalization_reward\x18\x02 \x01(\x0b\x32\x15.concordium.v2.Amount\x12?\n mint_platform_development_charge\x18\x03 \x01(\x0b\x32\x15.concordium.v2.Amount\x12\x39\n\x12\x66oundation_account\x18\x04 \x01(\x0b\x32\x1d.concordium.v2.AccountAddress\x1a\x8e\x01\n\x13\x46inalizationRewards\x12M\n\x14\x66inalization_rewards\x18\x01 \x01(\x0b\x32/.concordium.v2.BlockSpecialEvent.AccountAmounts\x12(\n\tremainder\x18\x02 \x01(\x0b\x32\x15.concordium.v2.Amount\x1a\xe6\x02\n\x0b\x42lockReward\x12/\n\x10transaction_fees\x18\x01 \x01(\x0b\x32\x15.concordium.v2.Amount\x12.\n\x0fold_gas_account\x18\x02 \x01(\x0b\x32\x15.concordium.v2.Amount\x12.\n\x0fnew_gas_account\x18\x03 \x01(\x0b\x32\x15.concordium.v2.Amount\x12+\n\x0c\x62\x61ker_reward\x18\x04 \x01(\x0b\x32\x15.concordium.v2.Amount\x12\x30\n\x11\x66oundation_charge\x18\x05 \x01(\x0b\x32\x15.concordium.v2.Amount\x12,\n\x05\x62\x61ker\x18\x06 \x01(\x0b\x32\x1d.concordium.v2.AccountAddress\x12\x39\n\x12\x66oundation_account\x18\x07 \x01(\x0b\x32\x1d.concordium.v2.AccountAddress\x1a\x86\x01\n\x16PaydayFoundationReward\x12\x39\n\x12\x66oundation_account\x18\x01 \x01(\x0b\x32\x1d.concordium.v2.AccountAddress\x12\x31\n\x12\x64\x65velopment_charge\x18\x02 \x01(\x0b\x32\x15.concordium.v2.Amount\x1a\xd7\x01\n\x13PaydayAccountReward\x12.\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x1d.concordium.v2.AccountAddress\x12/\n\x10transaction_fees\x18\x02 \x01(\x0b\x32\x15.concordium.v2.Amount\x12+\n\x0c\x62\x61ker_reward\x18\x03 \x01(\x0b\x32\x15.concordium.v2.Amount\x12\x32\n\x13\x66inalization_reward\x18\x04 \x01(\x0b\x32\x15.concordium.v2.Amount\x1a\xd9\x02\n\x11\x42lockAccrueReward\x12/\n\x10transaction_fees\x18\x01 \x01(\x0b\x32\x15.concordium.v2.Amount\x12.\n\x0fold_gas_account\x18\x02 \x01(\x0b\x32\x15.concordium.v2.Amount\x12.\n\x0fnew_gas_account\x18\x03 \x01(\x0b\x32\x15.concordium.v2.Amount\x12+\n\x0c\x62\x61ker_reward\x18\x04 \x01(\x0b\x32\x15.concordium.v2.Amount\x12-\n\x0epassive_reward\x18\x05 \x01(\x0b\x32\x15.concordium.v2.Amount\x12\x30\n\x11\x66oundation_charge\x18\x06 \x01(\x0b\x32\x15.concordium.v2.Amount\x12%\n\x05\x62\x61ker\x18\x07 \x01(\x0b\x32\x16.concordium.v2.BakerId\x1a\xe4\x01\n\x10PaydayPoolReward\x12/\n\npool_owner\x18\x01 \x01(\x0b\x32\x16.concordium.v2.BakerIdH\x00\x88\x01\x01\x12/\n\x10transaction_fees\x18\x02 \x01(\x0b\x32\x15.concordium.v2.Amount\x12+\n\x0c\x62\x61ker_reward\x18\x03 \x01(\x0b\x32\x15.concordium.v2.Amount\x12\x32\n\x13\x66inalization_reward\x18\x04 \x01(\x0b\x32\x15.concordium.v2.AmountB\r\n\x0b_pool_owner\x1an\n\x12ValidatorSuspended\x12(\n\x08\x62\x61ker_id\x18\x01 \x01(\x0b\x32\x16.concordium.v2.BakerId\x12.\n\x07\x61\x63\x63ount\x18\x02 \x01(\x0b\x32\x1d.concordium.v2.AccountAddress\x1ax\n\x1cValidatorPrimedForSuspension\x12(\n\x08\x62\x61ker_id\x18\x01 \x01(\x0b\x32\x16.concordium.v2.BakerId\x12.\n\x07\x61\x63\x63ount\x18\x02 \x01(\x0b\x32\x1d.concordium.v2.AccountAddressB\x07\n\x05\x65vent"\x80\r\n\rPendingUpdate\x12\x36\n\x0e\x65\x66\x66\x65\x63tive_time\x18\x01 \x01(\x0b\x32\x1e.concordium.v2.TransactionTime\x12\x33\n\troot_keys\x18\x02 \x01(\x0b\x32\x1e.concordium.v2.HigherLevelKeysH\x00\x12\x35\n\x0blevel1_keys\x18\x03 \x01(\x0b\x32\x1e.concordium.v2.HigherLevelKeysH\x00\x12<\n\x11level2_keys_cpv_0\x18\x04 \x01(\x0b\x32\x1f.concordium.v2.AuthorizationsV0H\x00\x12<\n\x11level2_keys_cpv_1\x18\x05 \x01(\x0b\x32\x1f.concordium.v2.AuthorizationsV1H\x00\x12\x31\n\x08protocol\x18\x06 \x01(\x0b\x32\x1d.concordium.v2.ProtocolUpdateH\x00\x12@\n\x13\x65lection_difficulty\x18\x07 \x01(\x0b\x32!.concordium.v2.ElectionDifficultyH\x00\x12\x36\n\x0f\x65uro_per_energy\x18\x08 \x01(\x0b\x32\x1b.concordium.v2.ExchangeRateH\x00\x12\x39\n\x12micro_ccd_per_euro\x18\t \x01(\x0b\x32\x1b.concordium.v2.ExchangeRateH\x00\x12;\n\x12\x66oundation_account\x18\n \x01(\x0b\x32\x1d.concordium.v2.AccountAddressH\x00\x12\x46\n\x17mint_distribution_cpv_0\x18\x0b \x01(\x0b\x32#.concordium.v2.MintDistributionCpv0H\x00\x12\x46\n\x17mint_distribution_cpv_1\x18\x0c \x01(\x0b\x32#.concordium.v2.MintDistributionCpv1H\x00\x12Q\n\x1ctransaction_fee_distribution\x18\r \x01(\x0b\x32).concordium.v2.TransactionFeeDistributionH\x00\x12\x30\n\x0bgas_rewards\x18\x0e \x01(\x0b\x32\x19.concordium.v2.GasRewardsH\x00\x12\x43\n\x15pool_parameters_cpv_0\x18\x0f \x01(\x0b\x32".concordium.v2.BakerStakeThresholdH\x00\x12\x42\n\x15pool_parameters_cpv_1\x18\x10 \x01(\x0b\x32!.concordium.v2.PoolParametersCpv1H\x00\x12\x36\n\x15\x61\x64\x64_anonymity_revoker\x18\x11 \x01(\x0b\x32\x15.concordium.v2.ArInfoH\x00\x12\x36\n\x15\x61\x64\x64_identity_provider\x18\x12 \x01(\x0b\x32\x15.concordium.v2.IpInfoH\x00\x12\x44\n\x13\x63ooldown_parameters\x18\x13 \x01(\x0b\x32%.concordium.v2.CooldownParametersCpv1H\x00\x12<\n\x0ftime_parameters\x18\x14 \x01(\x0b\x32!.concordium.v2.TimeParametersCpv1H\x00\x12:\n\x11gas_rewards_cpv_2\x18\x15 \x01(\x0b\x32\x1d.concordium.v2.GasRewardsCpv2H\x00\x12>\n\x12timeout_parameters\x18\x16 \x01(\x0b\x32 .concordium.v2.TimeoutParametersH\x00\x12\x31\n\x0emin_block_time\x18\x17 \x01(\x0b\x32\x17.concordium.v2.DurationH\x00\x12\x33\n\x12\x62lock_energy_limit\x18\x18 \x01(\x0b\x32\x15.concordium.v2.EnergyH\x00\x12[\n!finalization_committee_parameters\x18\x19 \x01(\x0b\x32..concordium.v2.FinalizationCommitteeParametersH\x00\x12M\n\x1avalidator_score_parameters\x18\x1a \x01(\x0b\x32\'.concordium.v2.ValidatorScoreParametersH\x00\x42\x08\n\x06\x65\x66\x66\x65\x63t"\xa3\n\n\x19NextUpdateSequenceNumbers\x12\x30\n\troot_keys\x18\x01 \x01(\x0b\x32\x1d.concordium.v2.SequenceNumber\x12\x32\n\x0blevel1_keys\x18\x02 \x01(\x0b\x32\x1d.concordium.v2.SequenceNumber\x12\x32\n\x0blevel2_keys\x18\x03 \x01(\x0b\x32\x1d.concordium.v2.SequenceNumber\x12/\n\x08protocol\x18\x04 \x01(\x0b\x32\x1d.concordium.v2.SequenceNumber\x12:\n\x13\x65lection_difficulty\x18\x05 \x01(\x0b\x32\x1d.concordium.v2.SequenceNumber\x12\x36\n\x0f\x65uro_per_energy\x18\x06 \x01(\x0b\x32\x1d.concordium.v2.SequenceNumber\x12\x39\n\x12micro_ccd_per_euro\x18\x07 \x01(\x0b\x32\x1d.concordium.v2.SequenceNumber\x12\x39\n\x12\x66oundation_account\x18\x08 \x01(\x0b\x32\x1d.concordium.v2.SequenceNumber\x12\x38\n\x11mint_distribution\x18\t \x01(\x0b\x32\x1d.concordium.v2.SequenceNumber\x12\x43\n\x1ctransaction_fee_distribution\x18\n \x01(\x0b\x32\x1d.concordium.v2.SequenceNumber\x12\x32\n\x0bgas_rewards\x18\x0b \x01(\x0b\x32\x1d.concordium.v2.SequenceNumber\x12\x36\n\x0fpool_parameters\x18\x0c \x01(\x0b\x32\x1d.concordium.v2.SequenceNumber\x12<\n\x15\x61\x64\x64_anonymity_revoker\x18\r \x01(\x0b\x32\x1d.concordium.v2.SequenceNumber\x12<\n\x15\x61\x64\x64_identity_provider\x18\x0e \x01(\x0b\x32\x1d.concordium.v2.SequenceNumber\x12:\n\x13\x63ooldown_parameters\x18\x0f \x01(\x0b\x32\x1d.concordium.v2.SequenceNumber\x12\x36\n\x0ftime_parameters\x18\x10 \x01(\x0b\x32\x1d.concordium.v2.SequenceNumber\x12\x39\n\x12timeout_parameters\x18\x11 \x01(\x0b\x32\x1d.concordium.v2.SequenceNumber\x12\x35\n\x0emin_block_time\x18\x12 \x01(\x0b\x32\x1d.concordium.v2.SequenceNumber\x12\x39\n\x12\x62lock_energy_limit\x18\x13 \x01(\x0b\x32\x1d.concordium.v2.SequenceNumber\x12H\n!finalization_committee_parameters\x18\x14 \x01(\x0b\x32\x1d.concordium.v2.SequenceNumber\x12\x41\n\x1avalidator_score_parameters\x18\x15 \x01(\x0b\x32\x1d.concordium.v2.SequenceNumber\x12<\n\x15protocol_level_tokens\x18\x16 \x01(\x0b\x32\x1d.concordium.v2.SequenceNumber"\x1a\n\tIpAddress\x12\r\n\x05value\x18\x01 \x01(\t"\x15\n\x04Port\x12\r\n\x05value\x18\x01 \x01(\r"Z\n\x0fIpSocketAddress\x12$\n\x02ip\x18\x01 \x01(\x0b\x32\x18.concordium.v2.IpAddress\x12!\n\x04port\x18\x02 \x01(\x0b\x32\x13.concordium.v2.Port"\x17\n\x06PeerId\x12\r\n\x05value\x18\x01 \x01(\t":\n\nBannedPeer\x12,\n\nip_address\x18\x01 \x01(\x0b\x32\x18.concordium.v2.IpAddress"7\n\x0b\x42\x61nnedPeers\x12(\n\x05peers\x18\x01 \x03(\x0b\x32\x19.concordium.v2.BannedPeer"9\n\tPeerToBan\x12,\n\nip_address\x18\x01 \x01(\x0b\x32\x18.concordium.v2.IpAddress"(\n\x0b\x44umpRequest\x12\x0c\n\x04\x66ile\x18\x01 \x01(\t\x12\x0b\n\x03raw\x18\x02 \x01(\x08"\xfe\x03\n\tPeersInfo\x12,\n\x05peers\x18\x01 \x03(\x0b\x32\x1d.concordium.v2.PeersInfo.Peer\x1a\xc2\x03\n\x04Peer\x12&\n\x07peer_id\x18\x01 \x01(\x0b\x32\x15.concordium.v2.PeerId\x12\x36\n\x0esocket_address\x18\x02 \x01(\x0b\x32\x1e.concordium.v2.IpSocketAddress\x12\x41\n\rnetwork_stats\x18\x03 \x01(\x0b\x32*.concordium.v2.PeersInfo.Peer.NetworkStats\x12,\n\x0c\x62ootstrapper\x18\x04 \x01(\x0b\x32\x14.concordium.v2.EmptyH\x00\x12J\n\x13node_catchup_status\x18\x05 \x01(\x0e\x32+.concordium.v2.PeersInfo.Peer.CatchupStatusH\x00\x1aO\n\x0cNetworkStats\x12\x14\n\x0cpackets_sent\x18\x02 \x01(\x04\x12\x18\n\x10packets_received\x18\x03 \x01(\x04\x12\x0f\n\x07latency\x18\x04 \x01(\x04":\n\rCatchupStatus\x12\x0c\n\x08UPTODATE\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\x0e\n\nCATCHINGUP\x10\x02\x42\x10\n\x0e\x63onsensus_info"\x9f\t\n\x08NodeInfo\x12\x14\n\x0cpeer_version\x18\x01 \x01(\t\x12,\n\nlocal_time\x18\x03 \x01(\x0b\x32\x18.concordium.v2.Timestamp\x12,\n\x0bpeer_uptime\x18\x04 \x01(\x0b\x32\x17.concordium.v2.Duration\x12\x39\n\x0cnetwork_info\x18\x05 \x01(\x0b\x32#.concordium.v2.NodeInfo.NetworkInfo\x12,\n\x0c\x62ootstrapper\x18\x06 \x01(\x0b\x32\x14.concordium.v2.EmptyH\x00\x12,\n\x04node\x18\x07 \x01(\x0b\x32\x1c.concordium.v2.NodeInfo.NodeH\x00\x1a\x94\x01\n\x0bNetworkInfo\x12&\n\x07node_id\x18\x01 \x01(\x0b\x32\x15.concordium.v2.PeerId\x12\x17\n\x0fpeer_total_sent\x18\x02 \x01(\x04\x12\x1b\n\x13peer_total_received\x18\x03 \x01(\x04\x12\x12\n\navg_bps_in\x18\x04 \x01(\x04\x12\x13\n\x0b\x61vg_bps_out\x18\x05 \x01(\x04\x1a\xb6\x04\n\x12\x42\x61kerConsensusInfo\x12(\n\x08\x62\x61ker_id\x18\x01 \x01(\x0b\x32\x16.concordium.v2.BakerId\x12\x61\n\x16passive_committee_info\x18\x02 \x01(\x0e\x32?.concordium.v2.NodeInfo.BakerConsensusInfo.PassiveCommitteeInfoH\x00\x12j\n\x1b\x61\x63tive_baker_committee_info\x18\x03 \x01(\x0b\x32\x43.concordium.v2.NodeInfo.BakerConsensusInfo.ActiveBakerCommitteeInfoH\x00\x12r\n\x1f\x61\x63tive_finalizer_committee_info\x18\x04 \x01(\x0b\x32G.concordium.v2.NodeInfo.BakerConsensusInfo.ActiveFinalizerCommitteeInfoH\x00\x1a\x1a\n\x18\x41\x63tiveBakerCommitteeInfo\x1a\x1e\n\x1c\x41\x63tiveFinalizerCommitteeInfo"m\n\x14PassiveCommitteeInfo\x12\x14\n\x10NOT_IN_COMMITTEE\x10\x00\x12%\n!ADDED_BUT_NOT_ACTIVE_IN_COMMITTEE\x10\x01\x12\x18\n\x14\x41\x44\x44\x45\x44_BUT_WRONG_KEYS\x10\x02\x42\x08\n\x06status\x1a\xae\x01\n\x04Node\x12+\n\x0bnot_running\x18\x01 \x01(\x0b\x32\x14.concordium.v2.EmptyH\x00\x12\'\n\x07passive\x18\x02 \x01(\x0b\x32\x14.concordium.v2.EmptyH\x00\x12<\n\x06\x61\x63tive\x18\x03 \x01(\x0b\x32*.concordium.v2.NodeInfo.BakerConsensusInfoH\x00\x42\x12\n\x10\x63onsensus_statusB\t\n\x07\x64\x65tails"\xec\x01\n\x14SendBlockItemRequest\x12@\n\x13\x61\x63\x63ount_transaction\x18\x01 \x01(\x0b\x32!.concordium.v2.AccountTransactionH\x00\x12\x44\n\x15\x63redential_deployment\x18\x02 \x01(\x0b\x32#.concordium.v2.CredentialDeploymentH\x00\x12>\n\x12update_instruction\x18\x03 \x01(\x0b\x32 .concordium.v2.UpdateInstructionH\x00\x42\x0c\n\nblock_item"p\n\x14\x43redentialDeployment\x12\x36\n\x0emessage_expiry\x18\x01 \x01(\x0b\x32\x1e.concordium.v2.TransactionTime\x12\x15\n\x0braw_payload\x18\x02 \x01(\x0cH\x00\x42\t\n\x07payload"\x1a\n\tSignature\x12\r\n\x05value\x18\x01 \x01(\x0c"\x9c\x01\n\x0cSignatureMap\x12?\n\nsignatures\x18\x01 \x03(\x0b\x32+.concordium.v2.SignatureMap.SignaturesEntry\x1aK\n\x0fSignaturesEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12\'\n\x05value\x18\x02 \x01(\x0b\x32\x18.concordium.v2.Signature:\x02\x38\x01"\xaa\x01\n\x13\x41\x63\x63ountSignatureMap\x12\x46\n\nsignatures\x18\x01 \x03(\x0b\x32\x32.concordium.v2.AccountSignatureMap.SignaturesEntry\x1aK\n\x0fSignaturesEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12\'\n\x05value\x18\x02 \x01(\x0b\x32\x18.concordium.v2.Signature:\x02\x38\x01"\xc4\x01\n\x1b\x41\x63\x63ountTransactionSignature\x12N\n\nsignatures\x18\x01 \x03(\x0b\x32:.concordium.v2.AccountTransactionSignature.SignaturesEntry\x1aU\n\x0fSignaturesEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12\x31\n\x05value\x18\x02 \x01(\x0b\x32".concordium.v2.AccountSignatureMap:\x02\x38\x01"\xdf\x01\n\x18\x41\x63\x63ountTransactionHeader\x12-\n\x06sender\x18\x01 \x01(\x0b\x32\x1d.concordium.v2.AccountAddress\x12\x36\n\x0fsequence_number\x18\x02 \x01(\x0b\x32\x1d.concordium.v2.SequenceNumber\x12,\n\renergy_amount\x18\x03 \x01(\x0b\x32\x15.concordium.v2.Energy\x12.\n\x06\x65xpiry\x18\x05 \x01(\x0b\x32\x1e.concordium.v2.TransactionTime"\xc3\x01\n\x13InitContractPayload\x12%\n\x06\x61mount\x18\x01 \x01(\x0b\x32\x15.concordium.v2.Amount\x12,\n\nmodule_ref\x18\x02 \x01(\x0b\x32\x18.concordium.v2.ModuleRef\x12*\n\tinit_name\x18\x03 \x01(\x0b\x32\x17.concordium.v2.InitName\x12+\n\tparameter\x18\x04 \x01(\x0b\x32\x18.concordium.v2.Parameter"\xce\x01\n\x15UpdateContractPayload\x12%\n\x06\x61mount\x18\x01 \x01(\x0b\x32\x15.concordium.v2.Amount\x12/\n\x07\x61\x64\x64ress\x18\x02 \x01(\x0b\x32\x1e.concordium.v2.ContractAddress\x12\x30\n\x0creceive_name\x18\x03 \x01(\x0b\x32\x1a.concordium.v2.ReceiveName\x12+\n\tparameter\x18\x04 \x01(\x0b\x32\x18.concordium.v2.Parameter"i\n\x0fTransferPayload\x12%\n\x06\x61mount\x18\x01 \x01(\x0b\x32\x15.concordium.v2.Amount\x12/\n\x08receiver\x18\x02 \x01(\x0b\x32\x1d.concordium.v2.AccountAddress"\x94\x01\n\x17TransferWithMemoPayload\x12%\n\x06\x61mount\x18\x01 \x01(\x0b\x32\x15.concordium.v2.Amount\x12/\n\x08receiver\x18\x02 \x01(\x0b\x32\x1d.concordium.v2.AccountAddress\x12!\n\x04memo\x18\x03 \x01(\x0b\x32\x13.concordium.v2.Memo"\xac\x03\n\x19\x41\x63\x63ountTransactionPayload\x12\x15\n\x0braw_payload\x18\x01 \x01(\x0cH\x00\x12=\n\rdeploy_module\x18\x02 \x01(\x0b\x32$.concordium.v2.VersionedModuleSourceH\x00\x12;\n\rinit_contract\x18\x03 \x01(\x0b\x32".concordium.v2.InitContractPayloadH\x00\x12?\n\x0fupdate_contract\x18\x04 \x01(\x0b\x32$.concordium.v2.UpdateContractPayloadH\x00\x12\x32\n\x08transfer\x18\x05 \x01(\x0b\x32\x1e.concordium.v2.TransferPayloadH\x00\x12\x44\n\x12transfer_with_memo\x18\x06 \x01(\x0b\x32&.concordium.v2.TransferWithMemoPayloadH\x00\x12\x36\n\rregister_data\x18\x07 \x01(\x0b\x32\x1d.concordium.v2.RegisteredDataH\x00\x42\t\n\x07payload"\x8b\x01\n\x15PreAccountTransaction\x12\x37\n\x06header\x18\x01 \x01(\x0b\x32\'.concordium.v2.AccountTransactionHeader\x12\x39\n\x07payload\x18\x02 \x01(\x0b\x32(.concordium.v2.AccountTransactionPayload"\xc7\x01\n\x12\x41\x63\x63ountTransaction\x12=\n\tsignature\x18\x01 \x01(\x0b\x32*.concordium.v2.AccountTransactionSignature\x12\x37\n\x06header\x18\x02 \x01(\x0b\x32\'.concordium.v2.AccountTransactionHeader\x12\x39\n\x07payload\x18\x03 \x01(\x0b\x32(.concordium.v2.AccountTransactionPayload"\xc0\x01\n\x17UpdateInstructionHeader\x12<\n\x0fsequence_number\x18\x01 \x01(\x0b\x32#.concordium.v2.UpdateSequenceNumber\x12\x36\n\x0e\x65\x66\x66\x65\x63tive_time\x18\x02 \x01(\x0b\x32\x1e.concordium.v2.TransactionTime\x12/\n\x07timeout\x18\x03 \x01(\x0b\x32\x1e.concordium.v2.TransactionTime"<\n\x18UpdateInstructionPayload\x12\x15\n\x0braw_payload\x18\x03 \x01(\x0cH\x00\x42\t\n\x07payload"\xb6\x01\n\x11UpdateInstruction\x12/\n\nsignatures\x18\x01 \x01(\x0b\x32\x1b.concordium.v2.SignatureMap\x12\x36\n\x06header\x18\x02 \x01(\x0b\x32&.concordium.v2.UpdateInstructionHeader\x12\x38\n\x07payload\x18\x03 \x01(\x0b\x32\'.concordium.v2.UpdateInstructionPayload"+\n\x1a\x41\x63\x63ountTransactionSignHash\x12\r\n\x05value\x18\x01 \x01(\x0c")\n\x18\x43redentialsPerBlockLimit\x12\r\n\x05value\x18\x01 \x01(\r"\x97\x06\n\x11\x43hainParametersV0\x12>\n\x13\x65lection_difficulty\x18\x01 \x01(\x0b\x32!.concordium.v2.ElectionDifficulty\x12\x34\n\x0f\x65uro_per_energy\x18\x02 \x01(\x0b\x32\x1b.concordium.v2.ExchangeRate\x12\x37\n\x12micro_ccd_per_euro\x18\x03 \x01(\x0b\x32\x1b.concordium.v2.ExchangeRate\x12\x33\n\x15\x62\x61ker_cooldown_epochs\x18\x04 \x01(\x0b\x32\x14.concordium.v2.Epoch\x12G\n\x16\x61\x63\x63ount_creation_limit\x18\x05 \x01(\x0b\x32\'.concordium.v2.CredentialsPerBlockLimit\x12>\n\x11mint_distribution\x18\x06 \x01(\x0b\x32#.concordium.v2.MintDistributionCpv0\x12O\n\x1ctransaction_fee_distribution\x18\x07 \x01(\x0b\x32).concordium.v2.TransactionFeeDistribution\x12.\n\x0bgas_rewards\x18\x08 \x01(\x0b\x32\x19.concordium.v2.GasRewards\x12\x39\n\x12\x66oundation_account\x18\t \x01(\x0b\x32\x1d.concordium.v2.AccountAddress\x12;\n\x1cminimum_threshold_for_baking\x18\n \x01(\x0b\x32\x15.concordium.v2.Amount\x12\x31\n\troot_keys\x18\x0b \x01(\x0b\x32\x1e.concordium.v2.HigherLevelKeys\x12\x33\n\x0blevel1_keys\x18\x0c \x01(\x0b\x32\x1e.concordium.v2.HigherLevelKeys\x12\x34\n\x0blevel2_keys\x18\r \x01(\x0b\x32\x1f.concordium.v2.AuthorizationsV0"\xe1\x06\n\x11\x43hainParametersV1\x12>\n\x13\x65lection_difficulty\x18\x01 \x01(\x0b\x32!.concordium.v2.ElectionDifficulty\x12\x34\n\x0f\x65uro_per_energy\x18\x02 \x01(\x0b\x32\x1b.concordium.v2.ExchangeRate\x12\x37\n\x12micro_ccd_per_euro\x18\x03 \x01(\x0b\x32\x1b.concordium.v2.ExchangeRate\x12\x42\n\x13\x63ooldown_parameters\x18\x04 \x01(\x0b\x32%.concordium.v2.CooldownParametersCpv1\x12:\n\x0ftime_parameters\x18\x05 \x01(\x0b\x32!.concordium.v2.TimeParametersCpv1\x12G\n\x16\x61\x63\x63ount_creation_limit\x18\x06 \x01(\x0b\x32\'.concordium.v2.CredentialsPerBlockLimit\x12>\n\x11mint_distribution\x18\x07 \x01(\x0b\x32#.concordium.v2.MintDistributionCpv1\x12O\n\x1ctransaction_fee_distribution\x18\x08 \x01(\x0b\x32).concordium.v2.TransactionFeeDistribution\x12.\n\x0bgas_rewards\x18\t \x01(\x0b\x32\x19.concordium.v2.GasRewards\x12\x39\n\x12\x66oundation_account\x18\n \x01(\x0b\x32\x1d.concordium.v2.AccountAddress\x12:\n\x0fpool_parameters\x18\x0b \x01(\x0b\x32!.concordium.v2.PoolParametersCpv1\x12\x31\n\troot_keys\x18\x0c \x01(\x0b\x32\x1e.concordium.v2.HigherLevelKeys\x12\x33\n\x0blevel1_keys\x18\r \x01(\x0b\x32\x1e.concordium.v2.HigherLevelKeys\x12\x34\n\x0blevel2_keys\x18\x0e \x01(\x0b\x32\x1f.concordium.v2.AuthorizationsV1"\xc4\x07\n\x11\x43hainParametersV2\x12\x42\n\x14\x63onsensus_parameters\x18\x01 \x01(\x0b\x32$.concordium.v2.ConsensusParametersV1\x12\x34\n\x0f\x65uro_per_energy\x18\x02 \x01(\x0b\x32\x1b.concordium.v2.ExchangeRate\x12\x37\n\x12micro_ccd_per_euro\x18\x03 \x01(\x0b\x32\x1b.concordium.v2.ExchangeRate\x12\x42\n\x13\x63ooldown_parameters\x18\x04 \x01(\x0b\x32%.concordium.v2.CooldownParametersCpv1\x12:\n\x0ftime_parameters\x18\x05 \x01(\x0b\x32!.concordium.v2.TimeParametersCpv1\x12G\n\x16\x61\x63\x63ount_creation_limit\x18\x06 \x01(\x0b\x32\'.concordium.v2.CredentialsPerBlockLimit\x12>\n\x11mint_distribution\x18\x07 \x01(\x0b\x32#.concordium.v2.MintDistributionCpv1\x12O\n\x1ctransaction_fee_distribution\x18\x08 \x01(\x0b\x32).concordium.v2.TransactionFeeDistribution\x12\x32\n\x0bgas_rewards\x18\t \x01(\x0b\x32\x1d.concordium.v2.GasRewardsCpv2\x12\x39\n\x12\x66oundation_account\x18\n \x01(\x0b\x32\x1d.concordium.v2.AccountAddress\x12:\n\x0fpool_parameters\x18\x0b \x01(\x0b\x32!.concordium.v2.PoolParametersCpv1\x12\x31\n\troot_keys\x18\x0c \x01(\x0b\x32\x1e.concordium.v2.HigherLevelKeys\x12\x33\n\x0blevel1_keys\x18\r \x01(\x0b\x32\x1e.concordium.v2.HigherLevelKeys\x12\x34\n\x0blevel2_keys\x18\x0e \x01(\x0b\x32\x1f.concordium.v2.AuthorizationsV1\x12Y\n!finalization_committee_parameters\x18\x0f \x01(\x0b\x32..concordium.v2.FinalizationCommitteeParameters"\x91\x08\n\x11\x43hainParametersV3\x12\x42\n\x14\x63onsensus_parameters\x18\x01 \x01(\x0b\x32$.concordium.v2.ConsensusParametersV1\x12\x34\n\x0f\x65uro_per_energy\x18\x02 \x01(\x0b\x32\x1b.concordium.v2.ExchangeRate\x12\x37\n\x12micro_ccd_per_euro\x18\x03 \x01(\x0b\x32\x1b.concordium.v2.ExchangeRate\x12\x42\n\x13\x63ooldown_parameters\x18\x04 \x01(\x0b\x32%.concordium.v2.CooldownParametersCpv1\x12:\n\x0ftime_parameters\x18\x05 \x01(\x0b\x32!.concordium.v2.TimeParametersCpv1\x12G\n\x16\x61\x63\x63ount_creation_limit\x18\x06 \x01(\x0b\x32\'.concordium.v2.CredentialsPerBlockLimit\x12>\n\x11mint_distribution\x18\x07 \x01(\x0b\x32#.concordium.v2.MintDistributionCpv1\x12O\n\x1ctransaction_fee_distribution\x18\x08 \x01(\x0b\x32).concordium.v2.TransactionFeeDistribution\x12\x32\n\x0bgas_rewards\x18\t \x01(\x0b\x32\x1d.concordium.v2.GasRewardsCpv2\x12\x39\n\x12\x66oundation_account\x18\n \x01(\x0b\x32\x1d.concordium.v2.AccountAddress\x12:\n\x0fpool_parameters\x18\x0b \x01(\x0b\x32!.concordium.v2.PoolParametersCpv1\x12\x31\n\troot_keys\x18\x0c \x01(\x0b\x32\x1e.concordium.v2.HigherLevelKeys\x12\x33\n\x0blevel1_keys\x18\r \x01(\x0b\x32\x1e.concordium.v2.HigherLevelKeys\x12\x34\n\x0blevel2_keys\x18\x0e \x01(\x0b\x32\x1f.concordium.v2.AuthorizationsV1\x12Y\n!finalization_committee_parameters\x18\x0f \x01(\x0b\x32..concordium.v2.FinalizationCommitteeParameters\x12K\n\x1avalidator_score_parameters\x18\x10 \x01(\x0b\x32\'.concordium.v2.ValidatorScoreParameters"\xdf\x01\n\x0f\x43hainParameters\x12.\n\x02v0\x18\x01 \x01(\x0b\x32 .concordium.v2.ChainParametersV0H\x00\x12.\n\x02v1\x18\x02 \x01(\x0b\x32 .concordium.v2.ChainParametersV1H\x00\x12.\n\x02v2\x18\x03 \x01(\x0b\x32 .concordium.v2.ChainParametersV2H\x00\x12.\n\x02v3\x18\x04 \x01(\x0b\x32 .concordium.v2.ChainParametersV3H\x00\x42\x0c\n\nparameters"a\n\x18\x46inalizationSummaryParty\x12%\n\x05\x62\x61ker\x18\x01 \x01(\x0b\x32\x16.concordium.v2.BakerId\x12\x0e\n\x06weight\x18\x02 \x01(\x04\x12\x0e\n\x06signed\x18\x03 \x01(\x08""\n\x11\x46inalizationIndex\x12\r\n\x05value\x18\x01 \x01(\x04"\xd7\x01\n\x13\x46inalizationSummary\x12\'\n\x05\x62lock\x18\x01 \x01(\x0b\x32\x18.concordium.v2.BlockHash\x12/\n\x05index\x18\x02 \x01(\x0b\x32 .concordium.v2.FinalizationIndex\x12)\n\x05\x64\x65lay\x18\x03 \x01(\x0b\x32\x1a.concordium.v2.BlockHeight\x12;\n\nfinalizers\x18\x04 \x03(\x0b\x32\'.concordium.v2.FinalizationSummaryParty"\x81\x01\n\x18\x42lockFinalizationSummary\x12$\n\x04none\x18\x01 \x01(\x0b\x32\x14.concordium.v2.EmptyH\x00\x12\x34\n\x06record\x18\x02 \x01(\x0b\x32".concordium.v2.FinalizationSummaryH\x00\x42\t\n\x07summary"\x8f\x02\n\tBlockItem\x12,\n\x04hash\x18\x01 \x01(\x0b\x32\x1e.concordium.v2.TransactionHash\x12@\n\x13\x61\x63\x63ount_transaction\x18\x02 \x01(\x0b\x32!.concordium.v2.AccountTransactionH\x00\x12\x44\n\x15\x63redential_deployment\x18\x03 \x01(\x0b\x32#.concordium.v2.CredentialDeploymentH\x00\x12>\n\x12update_instruction\x18\x04 \x01(\x0b\x32 .concordium.v2.UpdateInstructionH\x00\x42\x0c\n\nblock_item"\xa1\x02\n\x15\x42\x61kerRewardPeriodInfo\x12\'\n\x05\x62\x61ker\x18\x01 \x01(\x0b\x32\x18.concordium.v2.BakerInfo\x12.\n\x0f\x65\x66\x66\x65\x63tive_stake\x18\x02 \x01(\x0b\x32\x15.concordium.v2.Amount\x12\x38\n\x10\x63ommission_rates\x18\x03 \x01(\x0b\x32\x1e.concordium.v2.CommissionRates\x12-\n\x0e\x65quity_capital\x18\x04 \x01(\x0b\x32\x15.concordium.v2.Amount\x12\x30\n\x11\x64\x65legated_capital\x18\x05 \x01(\x0b\x32\x15.concordium.v2.Amount\x12\x14\n\x0cis_finalizer\x18\x06 \x01(\x08" \n\x0fQuorumSignature\x12\r\n\x05value\x18\x01 \x01(\x0c"\xf5\x01\n\x11QuorumCertificate\x12,\n\nblock_hash\x18\x01 \x01(\x0b\x32\x18.concordium.v2.BlockHash\x12#\n\x05round\x18\x02 \x01(\x0b\x32\x14.concordium.v2.Round\x12#\n\x05\x65poch\x18\x03 \x01(\x0b\x32\x14.concordium.v2.Epoch\x12;\n\x13\x61ggregate_signature\x18\x04 \x01(\x0b\x32\x1e.concordium.v2.QuorumSignature\x12+\n\x0bsignatories\x18\x05 \x03(\x0b\x32\x16.concordium.v2.BakerId"a\n\x0e\x46inalizerRound\x12#\n\x05round\x18\x01 \x01(\x0b\x32\x14.concordium.v2.Round\x12*\n\nfinalizers\x18\x02 \x03(\x0b\x32\x16.concordium.v2.BakerId"!\n\x10TimeoutSignature\x12\r\n\x05value\x18\x01 \x01(\x0c"\x9d\x02\n\x12TimeoutCertificate\x12#\n\x05round\x18\x01 \x01(\x0b\x32\x14.concordium.v2.Round\x12\'\n\tmin_epoch\x18\x02 \x01(\x0b\x32\x14.concordium.v2.Epoch\x12<\n\x15qc_rounds_first_epoch\x18\x03 \x03(\x0b\x32\x1d.concordium.v2.FinalizerRound\x12=\n\x16qc_rounds_second_epoch\x18\x04 \x03(\x0b\x32\x1d.concordium.v2.FinalizerRound\x12<\n\x13\x61ggregate_signature\x18\x05 \x01(\x0b\x32\x1f.concordium.v2.TimeoutSignature"\x1f\n\x0eSuccessorProof\x12\r\n\x05value\x18\x01 \x01(\x0c"\xc0\x01\n\x16\x45pochFinalizationEntry\x12\x36\n\x0c\x66inalized_qc\x18\x01 \x01(\x0b\x32 .concordium.v2.QuorumCertificate\x12\x36\n\x0csuccessor_qc\x18\x02 \x01(\x0b\x32 .concordium.v2.QuorumCertificate\x12\x36\n\x0fsuccessor_proof\x18\x03 \x01(\x0b\x32\x1d.concordium.v2.SuccessorProof"\xb5\x02\n\x11\x42lockCertificates\x12\x41\n\x12quorum_certificate\x18\x01 \x01(\x0b\x32 .concordium.v2.QuorumCertificateH\x00\x88\x01\x01\x12\x43\n\x13timeout_certificate\x18\x02 \x01(\x0b\x32!.concordium.v2.TimeoutCertificateH\x01\x88\x01\x01\x12L\n\x18\x65poch_finalization_entry\x18\x03 \x01(\x0b\x32%.concordium.v2.EpochFinalizationEntryH\x02\x88\x01\x01\x42\x15\n\x13_quorum_certificateB\x16\n\x14_timeout_certificateB\x1b\n\x19_epoch_finalization_entry"l\n\x0cWinningBaker\x12#\n\x05round\x18\x01 \x01(\x0b\x32\x14.concordium.v2.Round\x12&\n\x06winner\x18\x02 \x01(\x0b\x32\x16.concordium.v2.BakerId\x12\x0f\n\x07present\x18\x03 \x01(\x08"\xcd\x01\n\rDryRunRequest\x12\x39\n\x10load_block_state\x18\x01 \x01(\x0b\x32\x1d.concordium.v2.BlockHashInputH\x00\x12\x36\n\x0bstate_query\x18\x02 \x01(\x0b\x32\x1f.concordium.v2.DryRunStateQueryH\x00\x12>\n\x0fstate_operation\x18\x03 \x01(\x0b\x32#.concordium.v2.DryRunStateOperationH\x00\x42\t\n\x07request"\xdb\x01\n\x10\x44ryRunStateQuery\x12\x41\n\x10get_account_info\x18\x01 \x01(\x0b\x32%.concordium.v2.AccountIdentifierInputH\x00\x12;\n\x11get_instance_info\x18\x02 \x01(\x0b\x32\x1e.concordium.v2.ContractAddressH\x00\x12>\n\x0finvoke_instance\x18\x03 \x01(\x0b\x32#.concordium.v2.DryRunInvokeInstanceH\x00\x42\x07\n\x05query"\xad\x02\n\x14\x44ryRunInvokeInstance\x12,\n\x07invoker\x18\x01 \x01(\x0b\x32\x16.concordium.v2.AddressH\x00\x88\x01\x01\x12\x30\n\x08instance\x18\x02 \x01(\x0b\x32\x1e.concordium.v2.ContractAddress\x12%\n\x06\x61mount\x18\x03 \x01(\x0b\x32\x15.concordium.v2.Amount\x12.\n\nentrypoint\x18\x04 \x01(\x0b\x32\x1a.concordium.v2.ReceiveName\x12+\n\tparameter\x18\x05 \x01(\x0b\x32\x18.concordium.v2.Parameter\x12%\n\x06\x65nergy\x18\x06 \x01(\x0b\x32\x15.concordium.v2.EnergyB\n\n\x08_invoker"\xd2\x01\n\x14\x44ryRunStateOperation\x12\x31\n\rset_timestamp\x18\x01 \x01(\x0b\x32\x18.concordium.v2.TimestampH\x00\x12=\n\x0fmint_to_account\x18\x02 \x01(\x0b\x32".concordium.v2.DryRunMintToAccountH\x00\x12;\n\x0frun_transaction\x18\x03 \x01(\x0b\x32 .concordium.v2.DryRunTransactionH\x00\x42\x0b\n\toperation"l\n\x13\x44ryRunMintToAccount\x12.\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x1d.concordium.v2.AccountAddress\x12%\n\x06\x61mount\x18\x02 \x01(\x0b\x32\x15.concordium.v2.Amount"\xdf\x01\n\x11\x44ryRunTransaction\x12-\n\x06sender\x18\x01 \x01(\x0b\x32\x1d.concordium.v2.AccountAddress\x12,\n\renergy_amount\x18\x02 \x01(\x0b\x32\x15.concordium.v2.Energy\x12\x39\n\x07payload\x18\x03 \x01(\x0b\x32(.concordium.v2.AccountTransactionPayload\x12\x32\n\nsignatures\x18\x04 \x03(\x0b\x32\x1e.concordium.v2.DryRunSignature"2\n\x0f\x44ryRunSignature\x12\x12\n\ncredential\x18\x01 \x01(\r\x12\x0b\n\x03key\x18\x02 \x01(\r"\xba\x01\n\x0e\x44ryRunResponse\x12\x33\n\x05\x65rror\x18\x01 \x01(\x0b\x32".concordium.v2.DryRunErrorResponseH\x00\x12\x37\n\x07success\x18\x02 \x01(\x0b\x32$.concordium.v2.DryRunSuccessResponseH\x00\x12.\n\x0fquota_remaining\x18\x03 \x01(\x0b\x32\x15.concordium.v2.EnergyB\n\n\x08response"\xf1\x08\n\x13\x44ryRunErrorResponse\x12>\n\x08no_state\x18\x01 \x01(\x0b\x32*.concordium.v2.DryRunErrorResponse.NoStateH\x00\x12K\n\x0f\x62lock_not_found\x18\x02 \x01(\x0b\x32\x30.concordium.v2.DryRunErrorResponse.BlockNotFoundH\x00\x12O\n\x11\x61\x63\x63ount_not_found\x18\x03 \x01(\x0b\x32\x32.concordium.v2.DryRunErrorResponse.AccountNotFoundH\x00\x12Q\n\x12instance_not_found\x18\x04 \x01(\x0b\x32\x33.concordium.v2.DryRunErrorResponse.InstanceNotFoundH\x00\x12O\n\x11\x61mount_over_limit\x18\x05 \x01(\x0b\x32\x32.concordium.v2.DryRunErrorResponse.AmountOverLimitH\x00\x12V\n\x14\x62\x61lance_insufficient\x18\x06 \x01(\x0b\x32\x36.concordium.v2.DryRunErrorResponse.BalanceInsufficientH\x00\x12T\n\x13\x65nergy_insufficient\x18\x08 \x01(\x0b\x32\x35.concordium.v2.DryRunErrorResponse.EnergyInsufficientH\x00\x12I\n\rinvoke_failed\x18\t \x01(\x0b\x32\x30.concordium.v2.DryRunErrorResponse.InvokeFailureH\x00\x1a\t\n\x07NoState\x1a\x0f\n\rBlockNotFound\x1a\x11\n\x0f\x41\x63\x63ountNotFound\x1a\x12\n\x10InstanceNotFound\x1a>\n\x0f\x41mountOverLimit\x12+\n\x0c\x61mount_limit\x18\x01 \x01(\x0b\x32\x15.concordium.v2.Amount\x1av\n\x13\x42\x61lanceInsufficient\x12.\n\x0frequired_amount\x18\x01 \x01(\x0b\x32\x15.concordium.v2.Amount\x12/\n\x10\x61vailable_amount\x18\x02 \x01(\x0b\x32\x15.concordium.v2.Amount\x1a\x44\n\x12\x45nergyInsufficient\x12.\n\x0f\x65nergy_required\x18\x01 \x01(\x0b\x32\x15.concordium.v2.Energy\x1a\x94\x01\n\rInvokeFailure\x12\x19\n\x0creturn_value\x18\x01 \x01(\x0cH\x00\x88\x01\x01\x12*\n\x0bused_energy\x18\x02 \x01(\x0b\x32\x15.concordium.v2.Energy\x12+\n\x06reason\x18\x03 \x01(\x0b\x32\x1b.concordium.v2.RejectReasonB\x0f\n\r_return_valueB\x07\n\x05\x65rror"\xcb\x08\n\x15\x44ryRunSuccessResponse\x12S\n\x12\x62lock_state_loaded\x18\x01 \x01(\x0b\x32\x35.concordium.v2.DryRunSuccessResponse.BlockStateLoadedH\x00\x12\x32\n\x0c\x61\x63\x63ount_info\x18\x02 \x01(\x0b\x32\x1a.concordium.v2.AccountInfoH\x00\x12\x34\n\rinstance_info\x18\x03 \x01(\x0b\x32\x1b.concordium.v2.InstanceInfoH\x00\x12N\n\x10invoke_succeeded\x18\x04 \x01(\x0b\x32\x32.concordium.v2.DryRunSuccessResponse.InvokeSuccessH\x00\x12J\n\rtimestamp_set\x18\x05 \x01(\x0b\x32\x31.concordium.v2.DryRunSuccessResponse.TimestampSetH\x00\x12Q\n\x11minted_to_account\x18\x06 \x01(\x0b\x32\x34.concordium.v2.DryRunSuccessResponse.MintedToAccountH\x00\x12X\n\x14transaction_executed\x18\x07 \x01(\x0b\x32\x38.concordium.v2.DryRunSuccessResponse.TransactionExecutedH\x00\x1a\xaf\x01\n\x10\x42lockStateLoaded\x12\x33\n\x11\x63urrent_timestamp\x18\x01 \x01(\x0b\x32\x18.concordium.v2.Timestamp\x12,\n\nblock_hash\x18\x02 \x01(\x0b\x32\x18.concordium.v2.BlockHash\x12\x38\n\x10protocol_version\x18\x03 \x01(\x0e\x32\x1e.concordium.v2.ProtocolVersion\x1a\x0e\n\x0cTimestampSet\x1a\x11\n\x0fMintedToAccount\x1a\xa8\x01\n\x13TransactionExecuted\x12*\n\x0b\x65nergy_cost\x18\x01 \x01(\x0b\x32\x15.concordium.v2.Energy\x12\x39\n\x07\x64\x65tails\x18\x02 \x01(\x0b\x32(.concordium.v2.AccountTransactionDetails\x12\x19\n\x0creturn_value\x18\x03 \x01(\x0cH\x00\x88\x01\x01\x42\x0f\n\r_return_value\x1a\x9d\x01\n\rInvokeSuccess\x12\x19\n\x0creturn_value\x18\x01 \x01(\x0cH\x00\x88\x01\x01\x12*\n\x0bused_energy\x18\x02 \x01(\x0b\x32\x15.concordium.v2.Energy\x12\x34\n\x07\x65\x66\x66\x65\x63ts\x18\x03 \x03(\x0b\x32#.concordium.v2.ContractTraceElementB\x0f\n\r_return_valueB\n\n\x08response"\x1f\n\x0e\x46inalizerIndex\x12\r\n\x05value\x18\x01 \x01(\r"\xe7\x01\n\rQuorumMessage\x12\x31\n\tsignature\x18\x01 \x01(\x0b\x32\x1e.concordium.v2.QuorumSignature\x12\'\n\x05\x62lock\x18\x02 \x01(\x0b\x32\x18.concordium.v2.BlockHash\x12\x30\n\tfinalizer\x18\x03 \x01(\x0b\x32\x1d.concordium.v2.FinalizerIndex\x12#\n\x05round\x18\x04 \x01(\x0b\x32\x14.concordium.v2.Round\x12#\n\x05\x65poch\x18\x05 \x01(\x0b\x32\x14.concordium.v2.Epoch"\xff\x01\n\x14RawQuorumCertificate\x12,\n\nblock_hash\x18\x01 \x01(\x0b\x32\x18.concordium.v2.BlockHash\x12#\n\x05round\x18\x02 \x01(\x0b\x32\x14.concordium.v2.Round\x12#\n\x05\x65poch\x18\x03 \x01(\x0b\x32\x14.concordium.v2.Epoch\x12;\n\x13\x61ggregate_signature\x18\x04 \x01(\x0b\x32\x1e.concordium.v2.QuorumSignature\x12\x32\n\x0bsignatories\x18\x05 \x03(\x0b\x32\x1d.concordium.v2.FinalizerIndex"\x1f\n\x0e\x42lockSignature\x12\r\n\x05value\x18\x01 \x01(\x0c"\xbb\x02\n\x0eTimeoutMessage\x12\x30\n\tfinalizer\x18\x01 \x01(\x0b\x32\x1d.concordium.v2.FinalizerIndex\x12#\n\x05round\x18\x02 \x01(\x0b\x32\x14.concordium.v2.Round\x12#\n\x05\x65poch\x18\x03 \x01(\x0b\x32\x14.concordium.v2.Epoch\x12?\n\x12quorum_certificate\x18\x04 \x01(\x0b\x32#.concordium.v2.RawQuorumCertificate\x12\x32\n\tsignature\x18\x05 \x01(\x0b\x32\x1f.concordium.v2.TimeoutSignature\x12\x38\n\x11message_signature\x18\x06 \x01(\x0b\x32\x1d.concordium.v2.BlockSignature"k\n\x11RawFinalizerRound\x12#\n\x05round\x18\x01 \x01(\x0b\x32\x14.concordium.v2.Round\x12\x31\n\nfinalizers\x18\x02 \x03(\x0b\x32\x1d.concordium.v2.FinalizerIndex"\xa6\x02\n\x15RawTimeoutCertificate\x12#\n\x05round\x18\x01 \x01(\x0b\x32\x14.concordium.v2.Round\x12\'\n\tmin_epoch\x18\x02 \x01(\x0b\x32\x14.concordium.v2.Epoch\x12?\n\x15qc_rounds_first_epoch\x18\x03 \x03(\x0b\x32 .concordium.v2.RawFinalizerRound\x12@\n\x16qc_rounds_second_epoch\x18\x04 \x03(\x0b\x32 .concordium.v2.RawFinalizerRound\x12<\n\x13\x61ggregate_signature\x18\x05 \x01(\x0b\x32\x1f.concordium.v2.TimeoutSignature"\xec\x02\n\x15PersistentRoundStatus\x12\x45\n\x1alast_signed_quorum_message\x18\x01 \x01(\x0b\x32\x1c.concordium.v2.QuorumMessageH\x00\x88\x01\x01\x12G\n\x1blast_signed_timeout_message\x18\x02 \x01(\x0b\x32\x1d.concordium.v2.TimeoutMessageH\x01\x88\x01\x01\x12.\n\x10last_baked_round\x18\x03 \x01(\x0b\x32\x14.concordium.v2.Round\x12\x41\n\x0elatest_timeout\x18\x04 \x01(\x0b\x32$.concordium.v2.RawTimeoutCertificateH\x02\x88\x01\x01\x42\x1d\n\x1b_last_signed_quorum_messageB\x1e\n\x1c_last_signed_timeout_messageB\x11\n\x0f_latest_timeout"\x92\x01\n\x0cRoundTimeout\x12\x41\n\x13timeout_certificate\x18\x01 \x01(\x0b\x32$.concordium.v2.RawTimeoutCertificate\x12?\n\x12quorum_certificate\x18\x02 \x01(\x0b\x32#.concordium.v2.RawQuorumCertificate"\xc4\x01\n\x14RawFinalizationEntry\x12\x39\n\x0c\x66inalized_qc\x18\x01 \x01(\x0b\x32#.concordium.v2.RawQuorumCertificate\x12\x39\n\x0csuccessor_qc\x18\x02 \x01(\x0b\x32#.concordium.v2.RawQuorumCertificate\x12\x36\n\x0fsuccessor_proof\x18\x03 \x01(\x0b\x32\x1d.concordium.v2.SuccessorProof"\xcf\x03\n\x0bRoundStatus\x12+\n\rcurrent_round\x18\x01 \x01(\x0b\x32\x14.concordium.v2.Round\x12\x44\n\x17highest_certified_block\x18\x02 \x01(\x0b\x32#.concordium.v2.RawQuorumCertificate\x12@\n\x16previous_round_timeout\x18\x03 \x01(\x0b\x32\x1b.concordium.v2.RoundTimeoutH\x00\x88\x01\x01\x12\x1e\n\x16round_eligible_to_bake\x18\x04 \x01(\x08\x12+\n\rcurrent_epoch\x18\x05 \x01(\x0b\x32\x14.concordium.v2.Epoch\x12O\n\x1dlast_epoch_finalization_entry\x18\x06 \x01(\x0b\x32#.concordium.v2.RawFinalizationEntryH\x01\x88\x01\x01\x12\x30\n\x0f\x63urrent_timeout\x18\x07 \x01(\x0b\x32\x17.concordium.v2.DurationB\x19\n\x17_previous_round_timeoutB \n\x1e_last_epoch_finalization_entry"a\n\x11\x42lockTableSummary\x12\x1d\n\x15\x64\x65\x61\x64_block_cache_size\x18\x01 \x01(\x04\x12-\n\x0blive_blocks\x18\x02 \x03(\x0b\x32\x18.concordium.v2.BlockHash"I\n\x0c\x42ranchBlocks\x12\x39\n\x17\x62locks_at_branch_height\x18\x01 \x03(\x0b\x32\x18.concordium.v2.BlockHash"\x89\x01\n\x12RoundExistingBlock\x12#\n\x05round\x18\x01 \x01(\x0b\x32\x14.concordium.v2.Round\x12%\n\x05\x62\x61ker\x18\x02 \x01(\x0b\x32\x16.concordium.v2.BakerId\x12\'\n\x05\x62lock\x18\x03 \x01(\x0b\x32\x18.concordium.v2.BlockHash"[\n\x0fRoundExistingQC\x12#\n\x05round\x18\x01 \x01(\x0b\x32\x14.concordium.v2.Round\x12#\n\x05\x65poch\x18\x02 \x01(\x0b\x32\x14.concordium.v2.Epoch"\xb9\x02\n\rFullBakerInfo\x12.\n\x0e\x62\x61ker_identity\x18\x01 \x01(\x0b\x32\x16.concordium.v2.BakerId\x12\x42\n\x13\x65lection_verify_key\x18\x02 \x01(\x0b\x32%.concordium.v2.BakerElectionVerifyKey\x12\x44\n\x14signature_verify_key\x18\x03 \x01(\x0b\x32&.concordium.v2.BakerSignatureVerifyKey\x12H\n\x16\x61ggregation_verify_key\x18\x04 \x01(\x0b\x32(.concordium.v2.BakerAggregationVerifyKey\x12$\n\x05stake\x18\x05 \x01(\x0b\x32\x15.concordium.v2.Amount"*\n\x19\x46inalizationCommitteeHash\x12\r\n\x05value\x18\x01 \x01(\x0c"\xa6\x02\n\x13\x42\x61kersAndFinalizers\x12,\n\x06\x62\x61kers\x18\x01 \x03(\x0b\x32\x1c.concordium.v2.FullBakerInfo\x12*\n\nfinalizers\x18\x02 \x03(\x0b\x32\x16.concordium.v2.BakerId\x12\x30\n\x11\x62\x61ker_total_stake\x18\x03 \x01(\x0b\x32\x15.concordium.v2.Amount\x12\x34\n\x15\x66inalizer_total_stake\x18\x04 \x01(\x0b\x32\x15.concordium.v2.Amount\x12M\n\x1b\x66inalization_committee_hash\x18\x05 \x01(\x0b\x32(.concordium.v2.FinalizationCommitteeHash"\xb5\x02\n\x0b\x45pochBakers\x12\x41\n\x15previous_epoch_bakers\x18\x01 \x01(\x0b\x32".concordium.v2.BakersAndFinalizers\x12\x45\n\x14\x63urrent_epoch_bakers\x18\x02 \x01(\x0b\x32".concordium.v2.BakersAndFinalizersH\x00\x88\x01\x01\x12\x42\n\x11next_epoch_bakers\x18\x03 \x01(\x0b\x32".concordium.v2.BakersAndFinalizersH\x01\x88\x01\x01\x12)\n\x0bnext_payday\x18\x04 \x01(\x0b\x32\x14.concordium.v2.EpochB\x17\n\x15_current_epoch_bakersB\x14\n\x12_next_epoch_bakers"\xb7\x01\n\x0fTimeoutMessages\x12)\n\x0b\x66irst_epoch\x18\x01 \x01(\x0b\x32\x14.concordium.v2.Epoch\x12;\n\x14\x66irst_epoch_timeouts\x18\x02 \x03(\x0b\x32\x1d.concordium.v2.TimeoutMessage\x12<\n\x15second_epoch_timeouts\x18\x03 \x03(\x0b\x32\x1d.concordium.v2.TimeoutMessage"\xe8\x01\n\x14\x41ggregatedSignatures\x12.\n\x0csigned_block\x18\x01 \x01(\x0b\x32\x18.concordium.v2.BlockHash\x12/\n\x10signature_weight\x18\x02 \x01(\x0b\x32\x15.concordium.v2.Amount\x12;\n\x13\x61ggregate_signature\x18\x03 \x01(\x0b\x32\x1e.concordium.v2.QuorumSignature\x12\x32\n\x0bsignatories\x18\x04 \x03(\x0b\x32\x1d.concordium.v2.FinalizerIndex"\x8b\x01\n\x0eQuorumMessages\x12\x35\n\x0fquorum_messages\x18\x01 \x03(\x0b\x32\x1c.concordium.v2.QuorumMessage\x12\x42\n\x15\x61ggregated_signatures\x18\x02 \x03(\x0b\x32#.concordium.v2.AggregatedSignatures"i\n\x1c\x43onsensusDetailedStatusQuery\x12\x37\n\rgenesis_index\x18\x01 \x01(\x0b\x32\x1b.concordium.v2.GenesisIndexH\x00\x88\x01\x01\x42\x10\n\x0e_genesis_index"\xef\x07\n\x17\x43onsensusDetailedStatus\x12/\n\rgenesis_block\x18\x01 \x01(\x0b\x32\x18.concordium.v2.BlockHash\x12\x45\n\x17persistent_round_status\x18\x02 \x01(\x0b\x32$.concordium.v2.PersistentRoundStatus\x12\x30\n\x0cround_status\x18\x03 \x01(\x0b\x32\x1a.concordium.v2.RoundStatus\x12\'\n\x1fnon_finalized_transaction_count\x18\x04 \x01(\x04\x12\'\n\x1ftransaction_table_purge_counter\x18\x05 \x01(\x03\x12\x35\n\x0b\x62lock_table\x18\x06 \x01(\x0b\x32 .concordium.v2.BlockTableSummary\x12-\n\x08\x62ranches\x18\x07 \x03(\x0b\x32\x1b.concordium.v2.BranchBlocks\x12@\n\x15round_existing_blocks\x18\x08 \x03(\x0b\x32!.concordium.v2.RoundExistingBlock\x12:\n\x12round_existing_qcs\x18\t \x03(\x0b\x32\x1e.concordium.v2.RoundExistingQC\x12@\n\x14genesis_block_height\x18\n \x01(\x0b\x32".concordium.v2.AbsoluteBlockHeight\x12\x36\n\x14last_finalized_block\x18\x0b \x01(\x0b\x32\x18.concordium.v2.BlockHash\x12?\n\x1blast_finalized_block_height\x18\x0c \x01(\x0b\x32\x1a.concordium.v2.BlockHeight\x12K\n\x19latest_finalization_entry\x18\r \x01(\x0b\x32#.concordium.v2.RawFinalizationEntryH\x00\x88\x01\x01\x12\x30\n\x0c\x65poch_bakers\x18\x0e \x01(\x0b\x32\x1a.concordium.v2.EpochBakers\x12=\n\x10timeout_messages\x18\x0f \x01(\x0b\x32\x1e.concordium.v2.TimeoutMessagesH\x01\x88\x01\x01\x12\x35\n\x0eterminal_block\x18\x10 \x01(\x0b\x32\x18.concordium.v2.BlockHashH\x02\x88\x01\x01\x42\x1c\n\x1a_latest_finalization_entryB\x13\n\x11_timeout_messagesB\x11\n\x0f_terminal_block"w\n\x0e\x41\x63\x63ountPending\x12\x32\n\raccount_index\x18\x01 \x01(\x0b\x32\x1b.concordium.v2.AccountIndex\x12\x31\n\x0f\x66irst_timestamp\x18\x02 \x01(\x0b\x32\x18.concordium.v2.Timestamp*j\n\nOpenStatus\x12\x1c\n\x18OPEN_STATUS_OPEN_FOR_ALL\x10\x00\x12\x1e\n\x1aOPEN_STATUS_CLOSED_FOR_NEW\x10\x01\x12\x1e\n\x1aOPEN_STATUS_CLOSED_FOR_ALL\x10\x02*!\n\x0f\x43ontractVersion\x12\x06\n\x02V0\x10\x00\x12\x06\n\x02V1\x10\x01*I\n\x0e\x43redentialType\x12\x1b\n\x17\x43REDENTIAL_TYPE_INITIAL\x10\x00\x12\x1a\n\x16\x43REDENTIAL_TYPE_NORMAL\x10\x01*\x93\x05\n\nUpdateType\x12\x13\n\x0fUPDATE_PROTOCOL\x10\x00\x12\x1e\n\x1aUPDATE_ELECTION_DIFFICULTY\x10\x01\x12\x1a\n\x16UPDATE_EURO_PER_ENERGY\x10\x02\x12\x1d\n\x19UPDATE_MICRO_CCD_PER_EURO\x10\x03\x12\x1d\n\x19UPDATE_FOUNDATION_ACCOUNT\x10\x04\x12\x1c\n\x18UPDATE_MINT_DISTRIBUTION\x10\x05\x12\'\n#UPDATE_TRANSACTION_FEE_DISTRIBUTION\x10\x06\x12\x16\n\x12UPDATE_GAS_REWARDS\x10\x07\x12\x1a\n\x16UPDATE_POOL_PARAMETERS\x10\x08\x12\x19\n\x15\x41\x44\x44_ANONYMITY_REVOKER\x10\t\x12\x19\n\x15\x41\x44\x44_IDENTITY_PROVIDER\x10\n\x12\x14\n\x10UPDATE_ROOT_KEYS\x10\x0b\x12\x16\n\x12UPDATE_LEVEL1_KEYS\x10\x0c\x12\x16\n\x12UPDATE_LEVEL2_KEYS\x10\r\x12\x1e\n\x1aUPDATE_COOLDOWN_PARAMETERS\x10\x0e\x12\x1a\n\x16UPDATE_TIME_PARAMETERS\x10\x0f\x12\x1d\n\x19UPDATE_TIMEOUT_PARAMETERS\x10\x10\x12\x19\n\x15UPDATE_MIN_BLOCK_TIME\x10\x11\x12\x1d\n\x19UPDATE_BLOCK_ENERGY_LIMIT\x10\x12\x12,\n(UPDATE_FINALIZATION_COMMITTEE_PARAMETERS\x10\x13\x12%\n!UPDATE_VALIDATOR_SCORE_PARAMETERS\x10\x14\x12\x15\n\x11UPDATE_CREATE_PLT\x10\x15*\xa0\x04\n\x0fTransactionType\x12\x11\n\rDEPLOY_MODULE\x10\x00\x12\x11\n\rINIT_CONTRACT\x10\x01\x12\n\n\x06UPDATE\x10\x02\x12\x0c\n\x08TRANSFER\x10\x03\x12\r\n\tADD_BAKER\x10\x04\x12\x10\n\x0cREMOVE_BAKER\x10\x05\x12\x16\n\x12UPDATE_BAKER_STAKE\x10\x06\x12!\n\x1dUPDATE_BAKER_RESTAKE_EARNINGS\x10\x07\x12\x15\n\x11UPDATE_BAKER_KEYS\x10\x08\x12\x1a\n\x16UPDATE_CREDENTIAL_KEYS\x10\t\x12\x1d\n\x19\x45NCRYPTED_AMOUNT_TRANSFER\x10\n\x12\x19\n\x15TRANSFER_TO_ENCRYPTED\x10\x0b\x12\x16\n\x12TRANSFER_TO_PUBLIC\x10\x0c\x12\x1a\n\x16TRANSFER_WITH_SCHEDULE\x10\r\x12\x16\n\x12UPDATE_CREDENTIALS\x10\x0e\x12\x11\n\rREGISTER_DATA\x10\x0f\x12\x16\n\x12TRANSFER_WITH_MEMO\x10\x10\x12\'\n#ENCRYPTED_AMOUNT_TRANSFER_WITH_MEMO\x10\x11\x12#\n\x1fTRANSFER_WITH_SCHEDULE_AND_MEMO\x10\x12\x12\x13\n\x0f\x43ONFIGURE_BAKER\x10\x13\x12\x18\n\x14\x43ONFIGURE_DELEGATION\x10\x14\x12\x10\n\x0cTOKEN_UPDATE\x10\x15*\xe9\x01\n\x0fProtocolVersion\x12\x16\n\x12PROTOCOL_VERSION_1\x10\x00\x12\x16\n\x12PROTOCOL_VERSION_2\x10\x01\x12\x16\n\x12PROTOCOL_VERSION_3\x10\x02\x12\x16\n\x12PROTOCOL_VERSION_4\x10\x03\x12\x16\n\x12PROTOCOL_VERSION_5\x10\x04\x12\x16\n\x12PROTOCOL_VERSION_6\x10\x05\x12\x16\n\x12PROTOCOL_VERSION_7\x10\x06\x12\x16\n\x12PROTOCOL_VERSION_8\x10\x07\x12\x16\n\x12PROTOCOL_VERSION_9\x10\x08\x42\x35\n\x16\x63om.concordium.grpc.v2P\x01Z\x04./pb\xaa\x02\x12\x43oncordium.Grpc.V2b\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "types_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    _globals["DESCRIPTOR"]._options = None
    _globals["DESCRIPTOR"]._serialized_options = (
        b"\n\026com.concordium.grpc.v2P\001Z\004./pb\252\002\022Concordium.Grpc.V2"
    )
    _globals["_CREDENTIALPUBLICKEYS_KEYSENTRY"]._options = None
    _globals["_CREDENTIALPUBLICKEYS_KEYSENTRY"]._serialized_options = b"8\001"
    _globals["_POLICY_ATTRIBUTESENTRY"]._options = None
    _globals["_POLICY_ATTRIBUTESENTRY"]._serialized_options = b"8\001"
    _globals["_CREDENTIALCOMMITMENTS_ATTRIBUTESENTRY"]._options = None
    _globals["_CREDENTIALCOMMITMENTS_ATTRIBUTESENTRY"]._serialized_options = b"8\001"
    _globals["_NORMALCREDENTIALVALUES_ARDATAENTRY"]._options = None
    _globals["_NORMALCREDENTIALVALUES_ARDATAENTRY"]._serialized_options = b"8\001"
    _globals["_ACCOUNTINFO_CREDSENTRY"]._options = None
    _globals["_ACCOUNTINFO_CREDSENTRY"]._serialized_options = b"8\001"
    _globals["_SIGNATUREMAP_SIGNATURESENTRY"]._options = None
    _globals["_SIGNATUREMAP_SIGNATURESENTRY"]._serialized_options = b"8\001"
    _globals["_ACCOUNTSIGNATUREMAP_SIGNATURESENTRY"]._options = None
    _globals["_ACCOUNTSIGNATUREMAP_SIGNATURESENTRY"]._serialized_options = b"8\001"
    _globals["_ACCOUNTTRANSACTIONSIGNATURE_SIGNATURESENTRY"]._options = None
    _globals["_ACCOUNTTRANSACTIONSIGNATURE_SIGNATURESENTRY"]._serialized_options = (
        b"8\001"
    )
    _globals["_OPENSTATUS"]._serialized_start = 67109
    _globals["_OPENSTATUS"]._serialized_end = 67215
    _globals["_CONTRACTVERSION"]._serialized_start = 67217
    _globals["_CONTRACTVERSION"]._serialized_end = 67250
    _globals["_CREDENTIALTYPE"]._serialized_start = 67252
    _globals["_CREDENTIALTYPE"]._serialized_end = 67325
    _globals["_UPDATETYPE"]._serialized_start = 67328
    _globals["_UPDATETYPE"]._serialized_end = 67987
    _globals["_TRANSACTIONTYPE"]._serialized_start = 67990
    _globals["_TRANSACTIONTYPE"]._serialized_end = 68534
    _globals["_PROTOCOLVERSION"]._serialized_start = 68537
    _globals["_PROTOCOLVERSION"]._serialized_end = 68770
    _globals["_EMPTY"]._serialized_start = 73
    _globals["_EMPTY"]._serialized_end = 80
    _globals["_BLOCKHASH"]._serialized_start = 82
    _globals["_BLOCKHASH"]._serialized_end = 108
    _globals["_SHA256HASH"]._serialized_start = 110
    _globals["_SHA256HASH"]._serialized_end = 137
    _globals["_TRANSACTIONHASH"]._serialized_start = 139
    _globals["_TRANSACTIONHASH"]._serialized_end = 171
    _globals["_STATEHASH"]._serialized_start = 173
    _globals["_STATEHASH"]._serialized_end = 199
    _globals["_ABSOLUTEBLOCKHEIGHT"]._serialized_start = 201
    _globals["_ABSOLUTEBLOCKHEIGHT"]._serialized_end = 237
    _globals["_BLOCKHEIGHT"]._serialized_start = 239
    _globals["_BLOCKHEIGHT"]._serialized_end = 267
    _globals["_BAKERID"]._serialized_start = 269
    _globals["_BAKERID"]._serialized_end = 293
    _globals["_ACCOUNTINDEX"]._serialized_start = 295
    _globals["_ACCOUNTINDEX"]._serialized_end = 324
    _globals["_MODULEREF"]._serialized_start = 326
    _globals["_MODULEREF"]._serialized_end = 352
    _globals["_VERSIONEDMODULESOURCE"]._serialized_start = 355
    _globals["_VERSIONEDMODULESOURCE"]._serialized_end = 588
    _globals["_VERSIONEDMODULESOURCE_MODULESOURCEV0"]._serialized_start = 514
    _globals["_VERSIONEDMODULESOURCE_MODULESOURCEV0"]._serialized_end = 545
    _globals["_VERSIONEDMODULESOURCE_MODULESOURCEV1"]._serialized_start = 547
    _globals["_VERSIONEDMODULESOURCE_MODULESOURCEV1"]._serialized_end = 578
    _globals["_TIMESTAMP"]._serialized_start = 590
    _globals["_TIMESTAMP"]._serialized_end = 616
    _globals["_RELEASE"]._serialized_start = 619
    _globals["_RELEASE"]._serialized_end = 766
    _globals["_NEWRELEASE"]._serialized_start = 768
    _globals["_NEWRELEASE"]._serialized_end = 864
    _globals["_RELEASESCHEDULE"]._serialized_start = 866
    _globals["_RELEASESCHEDULE"]._serialized_end = 964
    _globals["_ENCRYPTEDAMOUNT"]._serialized_start = 966
    _globals["_ENCRYPTEDAMOUNT"]._serialized_end = 998
    _globals["_ENCRYPTEDBALANCE"]._serialized_start = 1001
    _globals["_ENCRYPTEDBALANCE"]._serialized_end = 1285
    _globals["_DELEGATIONTARGET"]._serialized_start = 1287
    _globals["_DELEGATIONTARGET"]._serialized_end = 1397
    _globals["_BAKERELECTIONVERIFYKEY"]._serialized_start = 1399
    _globals["_BAKERELECTIONVERIFYKEY"]._serialized_end = 1438
    _globals["_BAKERSIGNATUREVERIFYKEY"]._serialized_start = 1440
    _globals["_BAKERSIGNATUREVERIFYKEY"]._serialized_end = 1480
    _globals["_BAKERAGGREGATIONVERIFYKEY"]._serialized_start = 1482
    _globals["_BAKERAGGREGATIONVERIFYKEY"]._serialized_end = 1524
    _globals["_BAKERINFO"]._serialized_start = 1527
    _globals["_BAKERINFO"]._serialized_end = 1771
    _globals["_STAKEPENDINGCHANGE"]._serialized_start = 1774
    _globals["_STAKEPENDINGCHANGE"]._serialized_end = 2010
    _globals["_STAKEPENDINGCHANGE_REDUCE"]._serialized_start = 1900
    _globals["_STAKEPENDINGCHANGE_REDUCE"]._serialized_end = 2000
    _globals["_AMOUNTFRACTION"]._serialized_start = 2012
    _globals["_AMOUNTFRACTION"]._serialized_end = 2064
    _globals["_COMMISSIONRATES"]._serialized_start = 2067
    _globals["_COMMISSIONRATES"]._serialized_end = 2236
    _globals["_BAKERPOOLINFO"]._serialized_start = 2239
    _globals["_BAKERPOOLINFO"]._serialized_end = 2373
    _globals["_ACCOUNTSTAKINGINFO"]._serialized_start = 2376
    _globals["_ACCOUNTSTAKINGINFO"]._serialized_end = 3055
    _globals["_ACCOUNTSTAKINGINFO_BAKER"]._serialized_start = 2523
    _globals["_ACCOUNTSTAKINGINFO_BAKER"]._serialized_end = 2821
    _globals["_ACCOUNTSTAKINGINFO_DELEGATOR"]._serialized_start = 2824
    _globals["_ACCOUNTSTAKINGINFO_DELEGATOR"]._serialized_end = 3039
    _globals["_SEQUENCENUMBER"]._serialized_start = 3057
    _globals["_SEQUENCENUMBER"]._serialized_end = 3088
    _globals["_UPDATESEQUENCENUMBER"]._serialized_start = 3090
    _globals["_UPDATESEQUENCENUMBER"]._serialized_end = 3127
    _globals["_AMOUNT"]._serialized_start = 3129
    _globals["_AMOUNT"]._serialized_end = 3152
    _globals["_CREDENTIALINDEX"]._serialized_start = 3154
    _globals["_CREDENTIALINDEX"]._serialized_end = 3186
    _globals["_SIGNATURETHRESHOLD"]._serialized_start = 3188
    _globals["_SIGNATURETHRESHOLD"]._serialized_end = 3223
    _globals["_ACCOUNTTHRESHOLD"]._serialized_start = 3225
    _globals["_ACCOUNTTHRESHOLD"]._serialized_end = 3258
    _globals["_ENCRYPTIONKEY"]._serialized_start = 3260
    _globals["_ENCRYPTIONKEY"]._serialized_end = 3290
    _globals["_ADDRESS"]._serialized_start = 3292
    _globals["_ADDRESS"]._serialized_end = 3411
    _globals["_ACCOUNTVERIFYKEY"]._serialized_start = 3413
    _globals["_ACCOUNTVERIFYKEY"]._serialized_end = 3461
    _globals["_CREDENTIALPUBLICKEYS"]._serialized_start = 3464
    _globals["_CREDENTIALPUBLICKEYS"]._serialized_end = 3679
    _globals["_CREDENTIALPUBLICKEYS_KEYSENTRY"]._serialized_start = 3603
    _globals["_CREDENTIALPUBLICKEYS_KEYSENTRY"]._serialized_end = 3679
    _globals["_CREDENTIALREGISTRATIONID"]._serialized_start = 3681
    _globals["_CREDENTIALREGISTRATIONID"]._serialized_end = 3722
    _globals["_IDENTITYPROVIDERIDENTITY"]._serialized_start = 3724
    _globals["_IDENTITYPROVIDERIDENTITY"]._serialized_end = 3765
    _globals["_YEARMONTH"]._serialized_start = 3767
    _globals["_YEARMONTH"]._serialized_end = 3807
    _globals["_POLICY"]._serialized_start = 3810
    _globals["_POLICY"]._serialized_end = 4018
    _globals["_POLICY_ATTRIBUTESENTRY"]._serialized_start = 3969
    _globals["_POLICY_ATTRIBUTESENTRY"]._serialized_end = 4018
    _globals["_INITIALCREDENTIALVALUES"]._serialized_start = 4021
    _globals["_INITIALCREDENTIALVALUES"]._serialized_end = 4250
    _globals["_CHAINARDATA"]._serialized_start = 4252
    _globals["_CHAINARDATA"]._serialized_end = 4296
    _globals["_ARTHRESHOLD"]._serialized_start = 4298
    _globals["_ARTHRESHOLD"]._serialized_end = 4326
    _globals["_COMMITMENT"]._serialized_start = 4328
    _globals["_COMMITMENT"]._serialized_end = 4355
    _globals["_CREDENTIALCOMMITMENTS"]._serialized_start = 4358
    _globals["_CREDENTIALCOMMITMENTS"]._serialized_end = 4733
    _globals["_CREDENTIALCOMMITMENTS_ATTRIBUTESENTRY"]._serialized_start = 4657
    _globals["_CREDENTIALCOMMITMENTS_ATTRIBUTESENTRY"]._serialized_end = 4733
    _globals["_NORMALCREDENTIALVALUES"]._serialized_start = 4736
    _globals["_NORMALCREDENTIALVALUES"]._serialized_end = 5216
    _globals["_NORMALCREDENTIALVALUES_ARDATAENTRY"]._serialized_start = 5143
    _globals["_NORMALCREDENTIALVALUES_ARDATAENTRY"]._serialized_end = 5216
    _globals["_ACCOUNTCREDENTIAL"]._serialized_start = 5219
    _globals["_ACCOUNTCREDENTIAL"]._serialized_end = 5375
    _globals["_COOLDOWN"]._serialized_start = 5378
    _globals["_COOLDOWN"]._serialized_end = 5599
    _globals["_COOLDOWN_COOLDOWNSTATUS"]._serialized_start = 5529
    _globals["_COOLDOWN_COOLDOWNSTATUS"]._serialized_end = 5599
    _globals["_TOKENINFO"]._serialized_start = 5601
    _globals["_TOKENINFO"]._serialized_end = 5710
    _globals["_ACCOUNTINFO"]._serialized_start = 5713
    _globals["_ACCOUNTINFO"]._serialized_end = 6594
    _globals["_ACCOUNTINFO_TOKEN"]._serialized_start = 6384
    _globals["_ACCOUNTINFO_TOKEN"]._serialized_end = 6504
    _globals["_ACCOUNTINFO_CREDSENTRY"]._serialized_start = 6506
    _globals["_ACCOUNTINFO_CREDSENTRY"]._serialized_end = 6584
    _globals["_BLOCKHASHINPUT"]._serialized_start = 6597
    _globals["_BLOCKHASHINPUT"]._serialized_end = 7027
    _globals["_BLOCKHASHINPUT_RELATIVEHEIGHT"]._serialized_start = 6877
    _globals["_BLOCKHASHINPUT_RELATIVEHEIGHT"]._serialized_end = 7007
    _globals["_EPOCHREQUEST"]._serialized_start = 7030
    _globals["_EPOCHREQUEST"]._serialized_end = 7295
    _globals["_EPOCHREQUEST_RELATIVEEPOCH"]._serialized_start = 7168
    _globals["_EPOCHREQUEST_RELATIVEEPOCH"]._serialized_end = 7272
    _globals["_ACCOUNTIDENTIFIERINPUT"]._serialized_start = 7298
    _globals["_ACCOUNTIDENTIFIERINPUT"]._serialized_end = 7514
    _globals["_ACCOUNTINFOREQUEST"]._serialized_start = 7517
    _globals["_ACCOUNTINFOREQUEST"]._serialized_end = 7655
    _globals["_TOKENINFOREQUEST"]._serialized_start = 7657
    _globals["_TOKENINFOREQUEST"]._serialized_end = 7772
    _globals["_FINALIZEDBLOCKINFO"]._serialized_start = 7774
    _globals["_FINALIZEDBLOCKINFO"]._serialized_end = 7886
    _globals["_ANCESTORSREQUEST"]._serialized_start = 7888
    _globals["_ANCESTORSREQUEST"]._serialized_end = 7973
    _globals["_MODULESOURCEREQUEST"]._serialized_start = 7975
    _globals["_MODULESOURCEREQUEST"]._serialized_end = 8093
    _globals["_CONTRACTADDRESS"]._serialized_start = 8095
    _globals["_CONTRACTADDRESS"]._serialized_end = 8145
    _globals["_INSTANCEINFOREQUEST"]._serialized_start = 8147
    _globals["_INSTANCEINFOREQUEST"]._serialized_end = 8268
    _globals["_INSTANCEINFO"]._serialized_start = 8271
    _globals["_INSTANCEINFO"]._serialized_end = 8885
    _globals["_INSTANCEINFO_V0"]._serialized_start = 8380
    _globals["_INSTANCEINFO_V0"]._serialized_end = 8649
    _globals["_INSTANCEINFO_V1"]._serialized_start = 8652
    _globals["_INSTANCEINFO_V1"]._serialized_end = 8874
    _globals["_INSTANCESTATEKVPAIR"]._serialized_start = 8887
    _globals["_INSTANCESTATEKVPAIR"]._serialized_end = 8936
    _globals["_INSTANCESTATELOOKUPREQUEST"]._serialized_start = 8939
    _globals["_INSTANCESTATELOOKUPREQUEST"]._serialized_end = 9080
    _globals["_INSTANCESTATEVALUEATKEY"]._serialized_start = 9082
    _globals["_INSTANCESTATEVALUEATKEY"]._serialized_end = 9122
    _globals["_RECEIVENAME"]._serialized_start = 9124
    _globals["_RECEIVENAME"]._serialized_end = 9152
    _globals["_INITNAME"]._serialized_start = 9154
    _globals["_INITNAME"]._serialized_end = 9179
    _globals["_PARAMETER"]._serialized_start = 9181
    _globals["_PARAMETER"]._serialized_end = 9207
    _globals["_CONTRACTSTATEV0"]._serialized_start = 9209
    _globals["_CONTRACTSTATEV0"]._serialized_end = 9241
    _globals["_BLOCKITEMSTATUS"]._serialized_start = 9244
    _globals["_BLOCKITEMSTATUS"]._serialized_end = 9580
    _globals["_BLOCKITEMSTATUS_COMMITTED"]._serialized_start = 9431
    _globals["_BLOCKITEMSTATUS_COMMITTED"]._serialized_end = 9500
    _globals["_BLOCKITEMSTATUS_FINALIZED"]._serialized_start = 9502
    _globals["_BLOCKITEMSTATUS_FINALIZED"]._serialized_end = 9570
    _globals["_BLOCKITEMSUMMARYINBLOCK"]._serialized_start = 9582
    _globals["_BLOCKITEMSUMMARYINBLOCK"]._serialized_end = 9703
    _globals["_ENERGY"]._serialized_start = 9705
    _globals["_ENERGY"]._serialized_end = 9728
    _globals["_SLOT"]._serialized_start = 9730
    _globals["_SLOT"]._serialized_end = 9751
    _globals["_NEXTACCOUNTSEQUENCENUMBER"]._serialized_start = 9753
    _globals["_NEXTACCOUNTSEQUENCENUMBER"]._serialized_end = 9855
    _globals["_DURATION"]._serialized_start = 9857
    _globals["_DURATION"]._serialized_end = 9882
    _globals["_REJECTREASON"]._serialized_start = 9885
    _globals["_REJECTREASON"]._serialized_end = 14231
    _globals["_REJECTREASON_INVALIDINITMETHOD"]._serialized_start = 13509
    _globals["_REJECTREASON_INVALIDINITMETHOD"]._serialized_end = 13618
    _globals["_REJECTREASON_INVALIDRECEIVEMETHOD"]._serialized_start = 13620
    _globals["_REJECTREASON_INVALIDRECEIVEMETHOD"]._serialized_end = 13738
    _globals["_REJECTREASON_AMOUNTTOOLARGE"]._serialized_start = 13740
    _globals["_REJECTREASON_AMOUNTTOOLARGE"]._serialized_end = 13836
    _globals["_REJECTREASON_REJECTEDINIT"]._serialized_start = 13838
    _globals["_REJECTREASON_REJECTEDINIT"]._serialized_end = 13875
    _globals["_REJECTREASON_REJECTEDRECEIVE"]._serialized_start = 13878
    _globals["_REJECTREASON_REJECTEDRECEIVE"]._serialized_end = 14071
    _globals["_REJECTREASON_DUPLICATECREDIDS"]._serialized_start = 14073
    _globals["_REJECTREASON_DUPLICATECREDIDS"]._serialized_end = 14145
    _globals["_REJECTREASON_NONEXISTENTCREDIDS"]._serialized_start = 14147
    _globals["_REJECTREASON_NONEXISTENTCREDIDS"]._serialized_end = 14221
    _globals["_CONTRACTINITIALIZEDEVENT"]._serialized_start = 14234
    _globals["_CONTRACTINITIALIZEDEVENT"]._serialized_end = 14587
    _globals["_CONTRACTEVENT"]._serialized_start = 14589
    _globals["_CONTRACTEVENT"]._serialized_end = 14619
    _globals["_INSTANCEUPDATEDEVENT"]._serialized_start = 14622
    _globals["_INSTANCEUPDATEDEVENT"]._serialized_end = 14975
    _globals["_CONTRACTTRACEELEMENT"]._serialized_start = 14978
    _globals["_CONTRACTTRACEELEMENT"]._serialized_end = 15820
    _globals["_CONTRACTTRACEELEMENT_TRANSFERRED"]._serialized_start = 15333
    _globals["_CONTRACTTRACEELEMENT_TRANSFERRED"]._serialized_end = 15482
    _globals["_CONTRACTTRACEELEMENT_INTERRUPTED"]._serialized_start = 15484
    _globals["_CONTRACTTRACEELEMENT_INTERRUPTED"]._serialized_end = 15592
    _globals["_CONTRACTTRACEELEMENT_RESUMED"]._serialized_start = 15594
    _globals["_CONTRACTTRACEELEMENT_RESUMED"]._serialized_end = 15669
    _globals["_CONTRACTTRACEELEMENT_UPGRADED"]._serialized_start = 15672
    _globals["_CONTRACTTRACEELEMENT_UPGRADED"]._serialized_end = 15809
    _globals["_BAKERKEYSEVENT"]._serialized_start = 15823
    _globals["_BAKERKEYSEVENT"]._serialized_end = 16115
    _globals["_BAKERSTAKEUPDATEDDATA"]._serialized_start = 16117
    _globals["_BAKERSTAKEUPDATEDDATA"]._serialized_end = 16243
    _globals["_ENCRYPTEDAMOUNTREMOVEDEVENT"]._serialized_start = 16246
    _globals["_ENCRYPTEDAMOUNTREMOVEDEVENT"]._serialized_end = 16450
    _globals["_NEWENCRYPTEDAMOUNTEVENT"]._serialized_start = 16453
    _globals["_NEWENCRYPTEDAMOUNTEVENT"]._serialized_end = 16604
    _globals["_ENCRYPTEDSELFAMOUNTADDEDEVENT"]._serialized_start = 16607
    _globals["_ENCRYPTEDSELFAMOUNTADDEDEVENT"]._serialized_end = 16777
    _globals["_REGISTEREDDATA"]._serialized_start = 16779
    _globals["_REGISTEREDDATA"]._serialized_end = 16810
    _globals["_BAKEREVENT"]._serialized_start = 16813
    _globals["_BAKEREVENT"]._serialized_end = 19222
    _globals["_BAKEREVENT_BAKERADDED"]._serialized_start = 17952
    _globals["_BAKEREVENT_BAKERADDED"]._serialized_end = 18079
    _globals["_BAKEREVENT_BAKERSTAKEINCREASED"]._serialized_start = 18081
    _globals["_BAKEREVENT_BAKERSTAKEINCREASED"]._serialized_end = 18186
    _globals["_BAKEREVENT_BAKERSTAKEDECREASED"]._serialized_start = 18188
    _globals["_BAKEREVENT_BAKERSTAKEDECREASED"]._serialized_end = 18293
    _globals["_BAKEREVENT_BAKERRESTAKEEARNINGSUPDATED"]._serialized_start = 18295
    _globals["_BAKEREVENT_BAKERRESTAKEEARNINGSUPDATED"]._serialized_end = 18392
    _globals["_BAKEREVENT_BAKERSETOPENSTATUS"]._serialized_start = 18394
    _globals["_BAKEREVENT_BAKERSETOPENSTATUS"]._serialized_end = 18504
    _globals["_BAKEREVENT_BAKERSETMETADATAURL"]._serialized_start = 18506
    _globals["_BAKEREVENT_BAKERSETMETADATAURL"]._serialized_end = 18582
    _globals["_BAKEREVENT_BAKERSETTRANSACTIONFEECOMMISSION"]._serialized_start = 18585
    _globals["_BAKEREVENT_BAKERSETTRANSACTIONFEECOMMISSION"]._serialized_end = 18728
    _globals["_BAKEREVENT_BAKERSETBAKINGREWARDCOMMISSION"]._serialized_start = 18731
    _globals["_BAKEREVENT_BAKERSETBAKINGREWARDCOMMISSION"]._serialized_end = 18870
    _globals["_BAKEREVENT_BAKERSETFINALIZATIONREWARDCOMMISSION"]._serialized_start = (
        18873
    )
    _globals["_BAKEREVENT_BAKERSETFINALIZATIONREWARDCOMMISSION"]._serialized_end = 19024
    _globals["_BAKEREVENT_DELEGATIONREMOVED"]._serialized_start = 19026
    _globals["_BAKEREVENT_DELEGATIONREMOVED"]._serialized_end = 19095
    _globals["_BAKEREVENT_BAKERSUSPENDED"]._serialized_start = 19097
    _globals["_BAKEREVENT_BAKERSUSPENDED"]._serialized_end = 19155
    _globals["_BAKEREVENT_BAKERRESUMED"]._serialized_start = 19157
    _globals["_BAKEREVENT_BAKERRESUMED"]._serialized_end = 19213
    _globals["_DELEGATORID"]._serialized_start = 19224
    _globals["_DELEGATORID"]._serialized_end = 19278
    _globals["_DELEGATIONEVENT"]._serialized_start = 19281
    _globals["_DELEGATIONEVENT"]._serialized_end = 20441
    _globals["_DELEGATIONEVENT_DELEGATIONSTAKEINCREASED"]._serialized_start = 19884
    _globals["_DELEGATIONEVENT_DELEGATIONSTAKEINCREASED"]._serialized_end = 20002
    _globals["_DELEGATIONEVENT_DELEGATIONSTAKEDECREASED"]._serialized_start = 20004
    _globals["_DELEGATIONEVENT_DELEGATIONSTAKEDECREASED"]._serialized_end = 20122
    _globals["_DELEGATIONEVENT_DELEGATIONSETRESTAKEEARNINGS"]._serialized_start = 20124
    _globals["_DELEGATIONEVENT_DELEGATIONSETRESTAKEEARNINGS"]._serialized_end = 20230
    _globals["_DELEGATIONEVENT_DELEGATIONSETDELEGATIONTARGET"]._serialized_start = 20233
    _globals["_DELEGATIONEVENT_DELEGATIONSETDELEGATIONTARGET"]._serialized_end = 20374
    _globals["_DELEGATIONEVENT_BAKERREMOVED"]._serialized_start = 20376
    _globals["_DELEGATIONEVENT_BAKERREMOVED"]._serialized_end = 20432
    _globals["_ACCOUNTTRANSACTIONEFFECTS"]._serialized_start = 20444
    _globals["_ACCOUNTTRANSACTIONEFFECTS"]._serialized_end = 23374
    _globals["_ACCOUNTTRANSACTIONEFFECTS_NONE"]._serialized_start = 22065
    _globals["_ACCOUNTTRANSACTIONEFFECTS_NONE"]._serialized_end = 22207
    _globals["_ACCOUNTTRANSACTIONEFFECTS_CONTRACTUPDATEISSUED"]._serialized_start = (
        22209
    )
    _globals["_ACCOUNTTRANSACTIONEFFECTS_CONTRACTUPDATEISSUED"]._serialized_end = 22285
    _globals["_ACCOUNTTRANSACTIONEFFECTS_ACCOUNTTRANSFER"]._serialized_start = 22288
    _globals["_ACCOUNTTRANSACTIONEFFECTS_ACCOUNTTRANSFER"]._serialized_end = 22442
    _globals["_ACCOUNTTRANSACTIONEFFECTS_BAKERSTAKEUPDATED"]._serialized_start = 22444
    _globals["_ACCOUNTTRANSACTIONEFFECTS_BAKERSTAKEUPDATED"]._serialized_end = 22533
    _globals[
        "_ACCOUNTTRANSACTIONEFFECTS_ENCRYPTEDAMOUNTTRANSFERRED"
    ]._serialized_start = 22536
    _globals[
        "_ACCOUNTTRANSACTIONEFFECTS_ENCRYPTEDAMOUNTTRANSFERRED"
    ]._serialized_end = 22729
    _globals["_ACCOUNTTRANSACTIONEFFECTS_TRANSFERREDTOPUBLIC"]._serialized_start = 22731
    _globals["_ACCOUNTTRANSACTIONEFFECTS_TRANSFERREDTOPUBLIC"]._serialized_end = 22852
    _globals["_ACCOUNTTRANSACTIONEFFECTS_TRANSFERREDWITHSCHEDULE"]._serialized_start = (
        22855
    )
    _globals["_ACCOUNTTRANSACTIONEFFECTS_TRANSFERREDWITHSCHEDULE"]._serialized_end = (
        23021
    )
    _globals["_ACCOUNTTRANSACTIONEFFECTS_CREDENTIALSUPDATED"]._serialized_start = 23024
    _globals["_ACCOUNTTRANSACTIONEFFECTS_CREDENTIALSUPDATED"]._serialized_end = 23230
    _globals["_ACCOUNTTRANSACTIONEFFECTS_BAKERCONFIGURED"]._serialized_start = 23232
    _globals["_ACCOUNTTRANSACTIONEFFECTS_BAKERCONFIGURED"]._serialized_end = 23292
    _globals["_ACCOUNTTRANSACTIONEFFECTS_DELEGATIONCONFIGURED"]._serialized_start = (
        23294
    )
    _globals["_ACCOUNTTRANSACTIONEFFECTS_DELEGATIONCONFIGURED"]._serialized_end = 23364
    _globals["_ELECTIONDIFFICULTY"]._serialized_start = 23376
    _globals["_ELECTIONDIFFICULTY"]._serialized_end = 23442
    _globals["_TIMEOUTPARAMETERS"]._serialized_start = 23445
    _globals["_TIMEOUTPARAMETERS"]._serialized_end = 23607
    _globals["_FINALIZATIONCOMMITTEEPARAMETERS"]._serialized_start = 23610
    _globals["_FINALIZATIONCOMMITTEEPARAMETERS"]._serialized_end = 23774
    _globals["_VALIDATORSCOREPARAMETERS"]._serialized_start = 23776
    _globals["_VALIDATORSCOREPARAMETERS"]._serialized_end = 23833
    _globals["_CONSENSUSPARAMETERSV1"]._serialized_start = 23836
    _globals["_CONSENSUSPARAMETERSV1"]._serialized_end = 24021
    _globals["_EXCHANGERATE"]._serialized_start = 24023
    _globals["_EXCHANGERATE"]._serialized_end = 24074
    _globals["_RATIO"]._serialized_start = 24076
    _globals["_RATIO"]._serialized_end = 24123
    _globals["_UPDATEPUBLICKEY"]._serialized_start = 24125
    _globals["_UPDATEPUBLICKEY"]._serialized_end = 24157
    _globals["_UPDATEKEYSTHRESHOLD"]._serialized_start = 24159
    _globals["_UPDATEKEYSTHRESHOLD"]._serialized_end = 24195
    _globals["_UPDATEKEYSINDEX"]._serialized_start = 24197
    _globals["_UPDATEKEYSINDEX"]._serialized_end = 24229
    _globals["_HIGHERLEVELKEYS"]._serialized_start = 24231
    _globals["_HIGHERLEVELKEYS"]._serialized_end = 24349
    _globals["_ACCESSSTRUCTURE"]._serialized_start = 24352
    _globals["_ACCESSSTRUCTURE"]._serialized_end = 24491
    _globals["_AUTHORIZATIONSV0"]._serialized_start = 24494
    _globals["_AUTHORIZATIONSV0"]._serialized_end = 25322
    _globals["_AUTHORIZATIONSV1"]._serialized_start = 25325
    _globals["_AUTHORIZATIONSV1"]._serialized_end = 25576
    _globals["_DESCRIPTION"]._serialized_start = 25578
    _globals["_DESCRIPTION"]._serialized_end = 25639
    _globals["_ARINFO"]._serialized_start = 25642
    _globals["_ARINFO"]._serialized_end = 25865
    _globals["_ARINFO_ARIDENTITY"]._serialized_start = 25808
    _globals["_ARINFO_ARIDENTITY"]._serialized_end = 25835
    _globals["_ARINFO_ARPUBLICKEY"]._serialized_start = 25837
    _globals["_ARINFO_ARPUBLICKEY"]._serialized_end = 25865
    _globals["_IPIDENTITY"]._serialized_start = 25867
    _globals["_IPIDENTITY"]._serialized_end = 25894
    _globals["_IPINFO"]._serialized_start = 25897
    _globals["_IPINFO"]._serialized_end = 26179
    _globals["_IPINFO_IPVERIFYKEY"]._serialized_start = 26118
    _globals["_IPINFO_IPVERIFYKEY"]._serialized_end = 26146
    _globals["_IPINFO_IPCDIVERIFYKEY"]._serialized_start = 26148
    _globals["_IPINFO_IPCDIVERIFYKEY"]._serialized_end = 26179
    _globals["_DURATIONSECONDS"]._serialized_start = 26181
    _globals["_DURATIONSECONDS"]._serialized_end = 26213
    _globals["_INCLUSIVERANGEAMOUNTFRACTION"]._serialized_start = 26215
    _globals["_INCLUSIVERANGEAMOUNTFRACTION"]._serialized_end = 26334
    _globals["_COMMISSIONRANGES"]._serialized_start = 26337
    _globals["_COMMISSIONRANGES"]._serialized_end = 26549
    _globals["_CAPITALBOUND"]._serialized_start = 26551
    _globals["_CAPITALBOUND"]._serialized_end = 26611
    _globals["_LEVERAGEFACTOR"]._serialized_start = 26613
    _globals["_LEVERAGEFACTOR"]._serialized_end = 26666
    _globals["_EPOCH"]._serialized_start = 26668
    _globals["_EPOCH"]._serialized_end = 26690
    _globals["_ROUND"]._serialized_start = 26692
    _globals["_ROUND"]._serialized_end = 26714
    _globals["_REWARDPERIODLENGTH"]._serialized_start = 26716
    _globals["_REWARDPERIODLENGTH"]._serialized_end = 26773
    _globals["_MINTRATE"]._serialized_start = 26775
    _globals["_MINTRATE"]._serialized_end = 26821
    _globals["_COOLDOWNPARAMETERSCPV1"]._serialized_start = 26824
    _globals["_COOLDOWNPARAMETERSCPV1"]._serialized_end = 26969
    _globals["_POOLPARAMETERSCPV1"]._serialized_start = 26972
    _globals["_POOLPARAMETERSCPV1"]._serialized_end = 27423
    _globals["_TIMEPARAMETERSCPV1"]._serialized_start = 27426
    _globals["_TIMEPARAMETERSCPV1"]._serialized_end = 27561
    _globals["_MINTDISTRIBUTIONCPV1"]._serialized_start = 27564
    _globals["_MINTDISTRIBUTIONCPV1"]._serialized_end = 27700
    _globals["_PROTOCOLUPDATE"]._serialized_start = 27703
    _globals["_PROTOCOLUPDATE"]._serialized_end = 27856
    _globals["_MINTDISTRIBUTIONCPV0"]._serialized_start = 27859
    _globals["_MINTDISTRIBUTIONCPV0"]._serialized_end = 28043
    _globals["_TRANSACTIONFEEDISTRIBUTION"]._serialized_start = 28045
    _globals["_TRANSACTIONFEEDISTRIBUTION"]._serialized_end = 28171
    _globals["_GASREWARDS"]._serialized_start = 28174
    _globals["_GASREWARDS"]._serialized_end = 28401
    _globals["_GASREWARDSCPV2"]._serialized_start = 28404
    _globals["_GASREWARDSCPV2"]._serialized_end = 28576
    _globals["_BAKERSTAKETHRESHOLD"]._serialized_start = 28578
    _globals["_BAKERSTAKETHRESHOLD"]._serialized_end = 28653
    _globals["_ROOTUPDATE"]._serialized_start = 28656
    _globals["_ROOTUPDATE"]._serialized_end = 28940
    _globals["_LEVEL1UPDATE"]._serialized_start = 28943
    _globals["_LEVEL1UPDATE"]._serialized_end = 29169
    _globals["_UPDATEPAYLOAD"]._serialized_start = 29172
    _globals["_UPDATEPAYLOAD"]._serialized_end = 30866
    _globals["_ACCOUNTTRANSACTIONDETAILS"]._serialized_start = 30869
    _globals["_ACCOUNTTRANSACTIONDETAILS"]._serialized_end = 31039
    _globals["_ACCOUNTCREATIONDETAILS"]._serialized_start = 31042
    _globals["_ACCOUNTCREATIONDETAILS"]._serialized_end = 31227
    _globals["_TRANSACTIONTIME"]._serialized_start = 31229
    _globals["_TRANSACTIONTIME"]._serialized_end = 31261
    _globals["_UPDATEDETAILS"]._serialized_start = 31263
    _globals["_UPDATEDETAILS"]._serialized_end = 31381
    _globals["_BLOCKITEMSUMMARY"]._serialized_start = 31384
    _globals["_BLOCKITEMSUMMARY"]._serialized_end = 31858
    _globals["_BLOCKITEMSUMMARY_TRANSACTIONINDEX"]._serialized_start = 31814
    _globals["_BLOCKITEMSUMMARY_TRANSACTIONINDEX"]._serialized_end = 31847
    _globals["_GENESISINDEX"]._serialized_start = 31860
    _globals["_GENESISINDEX"]._serialized_end = 31889
    _globals["_CONSENSUSINFO"]._serialized_start = 31892
    _globals["_CONSENSUSINFO"]._serialized_end = 33883
    _globals["_ARRIVEDBLOCKINFO"]._serialized_start = 33885
    _globals["_ARRIVEDBLOCKINFO"]._serialized_end = 33995
    _globals["_CRYPTOGRAPHICPARAMETERS"]._serialized_start = 33997
    _globals["_CRYPTOGRAPHICPARAMETERS"]._serialized_end = 34111
    _globals["_BLOCKINFO"]._serialized_start = 34114
    _globals["_BLOCKINFO"]._serialized_end = 35022
    _globals["_POOLINFOREQUEST"]._serialized_start = 35024
    _globals["_POOLINFOREQUEST"]._serialized_end = 35131
    _globals["_POOLPENDINGCHANGE"]._serialized_start = 35134
    _globals["_POOLPENDINGCHANGE"]._serialized_end = 35456
    _globals["_POOLPENDINGCHANGE_REDUCE"]._serialized_start = 35273
    _globals["_POOLPENDINGCHANGE_REDUCE"]._serialized_end = 35386
    _globals["_POOLPENDINGCHANGE_REMOVE"]._serialized_start = 35388
    _globals["_POOLPENDINGCHANGE_REMOVE"]._serialized_end = 35446
    _globals["_POOLCURRENTPAYDAYINFO"]._serialized_start = 35459
    _globals["_POOLCURRENTPAYDAYINFO"]._serialized_end = 35933
    _globals["_POOLINFORESPONSE"]._serialized_start = 35936
    _globals["_POOLINFORESPONSE"]._serialized_end = 36633
    _globals["_PASSIVEDELEGATIONINFO"]._serialized_start = 36636
    _globals["_PASSIVEDELEGATIONINFO"]._serialized_end = 36958
    _globals["_BLOCKSATHEIGHTREQUEST"]._serialized_start = 36961
    _globals["_BLOCKSATHEIGHTREQUEST"]._serialized_end = 37328
    _globals["_BLOCKSATHEIGHTREQUEST_ABSOLUTE"]._serialized_start = 37120
    _globals["_BLOCKSATHEIGHTREQUEST_ABSOLUTE"]._serialized_end = 37182
    _globals["_BLOCKSATHEIGHTREQUEST_RELATIVE"]._serialized_start = 37184
    _globals["_BLOCKSATHEIGHTREQUEST_RELATIVE"]._serialized_end = 37308
    _globals["_BLOCKSATHEIGHTRESPONSE"]._serialized_start = 37330
    _globals["_BLOCKSATHEIGHTRESPONSE"]._serialized_end = 37396
    _globals["_TOKENOMICSINFO"]._serialized_start = 37399
    _globals["_TOKENOMICSINFO"]._serialized_end = 38395
    _globals["_TOKENOMICSINFO_V0"]._serialized_start = 37514
    _globals["_TOKENOMICSINFO_V0"]._serialized_end = 37834
    _globals["_TOKENOMICSINFO_V1"]._serialized_start = 37837
    _globals["_TOKENOMICSINFO_V1"]._serialized_end = 38381
    _globals["_INVOKEINSTANCEREQUEST"]._serialized_start = 38398
    _globals["_INVOKEINSTANCEREQUEST"]._serialized_end = 38751
    _globals["_INVOKEINSTANCERESPONSE"]._serialized_start = 38754
    _globals["_INVOKEINSTANCERESPONSE"]._serialized_end = 39219
    _globals["_INVOKEINSTANCERESPONSE_FAILURE"]._serialized_start = 38913
    _globals["_INVOKEINSTANCERESPONSE_FAILURE"]._serialized_end = 39055
    _globals["_INVOKEINSTANCERESPONSE_SUCCESS"]._serialized_start = 39058
    _globals["_INVOKEINSTANCERESPONSE_SUCCESS"]._serialized_end = 39209
    _globals["_GETPOOLDELEGATORSREQUEST"]._serialized_start = 39221
    _globals["_GETPOOLDELEGATORSREQUEST"]._serialized_end = 39337
    _globals["_DELEGATORINFO"]._serialized_start = 39340
    _globals["_DELEGATORINFO"]._serialized_end = 39524
    _globals["_DELEGATORREWARDPERIODINFO"]._serialized_start = 39526
    _globals["_DELEGATORREWARDPERIODINFO"]._serialized_end = 39639
    _globals["_BRANCH"]._serialized_start = 39641
    _globals["_BRANCH"]._serialized_end = 39736
    _globals["_LEADERSHIPELECTIONNONCE"]._serialized_start = 39738
    _globals["_LEADERSHIPELECTIONNONCE"]._serialized_end = 39778
    _globals["_ELECTIONINFO"]._serialized_start = 39781
    _globals["_ELECTIONINFO"]._serialized_end = 40135
    _globals["_ELECTIONINFO_BAKER"]._serialized_start = 39994
    _globals["_ELECTIONINFO_BAKER"]._serialized_end = 40111
    _globals["_BLOCKSPECIALEVENT"]._serialized_start = 40138
    _globals["_BLOCKSPECIALEVENT"]._serialized_end = 43219
    _globals["_BLOCKSPECIALEVENT_ACCOUNTAMOUNTS"]._serialized_start = 40979
    _globals["_BLOCKSPECIALEVENT_ACCOUNTAMOUNTS"]._serialized_end = 41163
    _globals["_BLOCKSPECIALEVENT_ACCOUNTAMOUNTS_ENTRY"]._serialized_start = 41069
    _globals["_BLOCKSPECIALEVENT_ACCOUNTAMOUNTS_ENTRY"]._serialized_end = 41163
    _globals["_BLOCKSPECIALEVENT_BAKINGREWARDS"]._serialized_start = 41166
    _globals["_BLOCKSPECIALEVENT_BAKINGREWARDS"]._serialized_end = 41295
    _globals["_BLOCKSPECIALEVENT_MINT"]._serialized_start = 41298
    _globals["_BLOCKSPECIALEVENT_MINT"]._serialized_end = 41536
    _globals["_BLOCKSPECIALEVENT_FINALIZATIONREWARDS"]._serialized_start = 41539
    _globals["_BLOCKSPECIALEVENT_FINALIZATIONREWARDS"]._serialized_end = 41681
    _globals["_BLOCKSPECIALEVENT_BLOCKREWARD"]._serialized_start = 41684
    _globals["_BLOCKSPECIALEVENT_BLOCKREWARD"]._serialized_end = 42042
    _globals["_BLOCKSPECIALEVENT_PAYDAYFOUNDATIONREWARD"]._serialized_start = 42045
    _globals["_BLOCKSPECIALEVENT_PAYDAYFOUNDATIONREWARD"]._serialized_end = 42179
    _globals["_BLOCKSPECIALEVENT_PAYDAYACCOUNTREWARD"]._serialized_start = 42182
    _globals["_BLOCKSPECIALEVENT_PAYDAYACCOUNTREWARD"]._serialized_end = 42397
    _globals["_BLOCKSPECIALEVENT_BLOCKACCRUEREWARD"]._serialized_start = 42400
    _globals["_BLOCKSPECIALEVENT_BLOCKACCRUEREWARD"]._serialized_end = 42745
    _globals["_BLOCKSPECIALEVENT_PAYDAYPOOLREWARD"]._serialized_start = 42748
    _globals["_BLOCKSPECIALEVENT_PAYDAYPOOLREWARD"]._serialized_end = 42976
    _globals["_BLOCKSPECIALEVENT_VALIDATORSUSPENDED"]._serialized_start = 42978
    _globals["_BLOCKSPECIALEVENT_VALIDATORSUSPENDED"]._serialized_end = 43088
    _globals["_BLOCKSPECIALEVENT_VALIDATORPRIMEDFORSUSPENSION"]._serialized_start = (
        43090
    )
    _globals["_BLOCKSPECIALEVENT_VALIDATORPRIMEDFORSUSPENSION"]._serialized_end = 43210
    _globals["_PENDINGUPDATE"]._serialized_start = 43222
    _globals["_PENDINGUPDATE"]._serialized_end = 44886
    _globals["_NEXTUPDATESEQUENCENUMBERS"]._serialized_start = 44889
    _globals["_NEXTUPDATESEQUENCENUMBERS"]._serialized_end = 46204
    _globals["_IPADDRESS"]._serialized_start = 46206
    _globals["_IPADDRESS"]._serialized_end = 46232
    _globals["_PORT"]._serialized_start = 46234
    _globals["_PORT"]._serialized_end = 46255
    _globals["_IPSOCKETADDRESS"]._serialized_start = 46257
    _globals["_IPSOCKETADDRESS"]._serialized_end = 46347
    _globals["_PEERID"]._serialized_start = 46349
    _globals["_PEERID"]._serialized_end = 46372
    _globals["_BANNEDPEER"]._serialized_start = 46374
    _globals["_BANNEDPEER"]._serialized_end = 46432
    _globals["_BANNEDPEERS"]._serialized_start = 46434
    _globals["_BANNEDPEERS"]._serialized_end = 46489
    _globals["_PEERTOBAN"]._serialized_start = 46491
    _globals["_PEERTOBAN"]._serialized_end = 46548
    _globals["_DUMPREQUEST"]._serialized_start = 46550
    _globals["_DUMPREQUEST"]._serialized_end = 46590
    _globals["_PEERSINFO"]._serialized_start = 46593
    _globals["_PEERSINFO"]._serialized_end = 47103
    _globals["_PEERSINFO_PEER"]._serialized_start = 46653
    _globals["_PEERSINFO_PEER"]._serialized_end = 47103
    _globals["_PEERSINFO_PEER_NETWORKSTATS"]._serialized_start = 46946
    _globals["_PEERSINFO_PEER_NETWORKSTATS"]._serialized_end = 47025
    _globals["_PEERSINFO_PEER_CATCHUPSTATUS"]._serialized_start = 47027
    _globals["_PEERSINFO_PEER_CATCHUPSTATUS"]._serialized_end = 47085
    _globals["_NODEINFO"]._serialized_start = 47106
    _globals["_NODEINFO"]._serialized_end = 48289
    _globals["_NODEINFO_NETWORKINFO"]._serialized_start = 47384
    _globals["_NODEINFO_NETWORKINFO"]._serialized_end = 47532
    _globals["_NODEINFO_BAKERCONSENSUSINFO"]._serialized_start = 47535
    _globals["_NODEINFO_BAKERCONSENSUSINFO"]._serialized_end = 48101
    _globals[
        "_NODEINFO_BAKERCONSENSUSINFO_ACTIVEBAKERCOMMITTEEINFO"
    ]._serialized_start = 47922
    _globals[
        "_NODEINFO_BAKERCONSENSUSINFO_ACTIVEBAKERCOMMITTEEINFO"
    ]._serialized_end = 47948
    _globals[
        "_NODEINFO_BAKERCONSENSUSINFO_ACTIVEFINALIZERCOMMITTEEINFO"
    ]._serialized_start = 47950
    _globals[
        "_NODEINFO_BAKERCONSENSUSINFO_ACTIVEFINALIZERCOMMITTEEINFO"
    ]._serialized_end = 47980
    _globals["_NODEINFO_BAKERCONSENSUSINFO_PASSIVECOMMITTEEINFO"]._serialized_start = (
        47982
    )
    _globals["_NODEINFO_BAKERCONSENSUSINFO_PASSIVECOMMITTEEINFO"]._serialized_end = (
        48091
    )
    _globals["_NODEINFO_NODE"]._serialized_start = 48104
    _globals["_NODEINFO_NODE"]._serialized_end = 48278
    _globals["_SENDBLOCKITEMREQUEST"]._serialized_start = 48292
    _globals["_SENDBLOCKITEMREQUEST"]._serialized_end = 48528
    _globals["_CREDENTIALDEPLOYMENT"]._serialized_start = 48530
    _globals["_CREDENTIALDEPLOYMENT"]._serialized_end = 48642
    _globals["_SIGNATURE"]._serialized_start = 48644
    _globals["_SIGNATURE"]._serialized_end = 48670
    _globals["_SIGNATUREMAP"]._serialized_start = 48673
    _globals["_SIGNATUREMAP"]._serialized_end = 48829
    _globals["_SIGNATUREMAP_SIGNATURESENTRY"]._serialized_start = 48754
    _globals["_SIGNATUREMAP_SIGNATURESENTRY"]._serialized_end = 48829
    _globals["_ACCOUNTSIGNATUREMAP"]._serialized_start = 48832
    _globals["_ACCOUNTSIGNATUREMAP"]._serialized_end = 49002
    _globals["_ACCOUNTSIGNATUREMAP_SIGNATURESENTRY"]._serialized_start = 48754
    _globals["_ACCOUNTSIGNATUREMAP_SIGNATURESENTRY"]._serialized_end = 48829
    _globals["_ACCOUNTTRANSACTIONSIGNATURE"]._serialized_start = 49005
    _globals["_ACCOUNTTRANSACTIONSIGNATURE"]._serialized_end = 49201
    _globals["_ACCOUNTTRANSACTIONSIGNATURE_SIGNATURESENTRY"]._serialized_start = 49116
    _globals["_ACCOUNTTRANSACTIONSIGNATURE_SIGNATURESENTRY"]._serialized_end = 49201
    _globals["_ACCOUNTTRANSACTIONHEADER"]._serialized_start = 49204
    _globals["_ACCOUNTTRANSACTIONHEADER"]._serialized_end = 49427
    _globals["_INITCONTRACTPAYLOAD"]._serialized_start = 49430
    _globals["_INITCONTRACTPAYLOAD"]._serialized_end = 49625
    _globals["_UPDATECONTRACTPAYLOAD"]._serialized_start = 49628
    _globals["_UPDATECONTRACTPAYLOAD"]._serialized_end = 49834
    _globals["_TRANSFERPAYLOAD"]._serialized_start = 49836
    _globals["_TRANSFERPAYLOAD"]._serialized_end = 49941
    _globals["_TRANSFERWITHMEMOPAYLOAD"]._serialized_start = 49944
    _globals["_TRANSFERWITHMEMOPAYLOAD"]._serialized_end = 50092
    _globals["_ACCOUNTTRANSACTIONPAYLOAD"]._serialized_start = 50095
    _globals["_ACCOUNTTRANSACTIONPAYLOAD"]._serialized_end = 50523
    _globals["_PREACCOUNTTRANSACTION"]._serialized_start = 50526
    _globals["_PREACCOUNTTRANSACTION"]._serialized_end = 50665
    _globals["_ACCOUNTTRANSACTION"]._serialized_start = 50668
    _globals["_ACCOUNTTRANSACTION"]._serialized_end = 50867
    _globals["_UPDATEINSTRUCTIONHEADER"]._serialized_start = 50870
    _globals["_UPDATEINSTRUCTIONHEADER"]._serialized_end = 51062
    _globals["_UPDATEINSTRUCTIONPAYLOAD"]._serialized_start = 51064
    _globals["_UPDATEINSTRUCTIONPAYLOAD"]._serialized_end = 51124
    _globals["_UPDATEINSTRUCTION"]._serialized_start = 51127
    _globals["_UPDATEINSTRUCTION"]._serialized_end = 51309
    _globals["_ACCOUNTTRANSACTIONSIGNHASH"]._serialized_start = 51311
    _globals["_ACCOUNTTRANSACTIONSIGNHASH"]._serialized_end = 51354
    _globals["_CREDENTIALSPERBLOCKLIMIT"]._serialized_start = 51356
    _globals["_CREDENTIALSPERBLOCKLIMIT"]._serialized_end = 51397
    _globals["_CHAINPARAMETERSV0"]._serialized_start = 51400
    _globals["_CHAINPARAMETERSV0"]._serialized_end = 52191
    _globals["_CHAINPARAMETERSV1"]._serialized_start = 52194
    _globals["_CHAINPARAMETERSV1"]._serialized_end = 53059
    _globals["_CHAINPARAMETERSV2"]._serialized_start = 53062
    _globals["_CHAINPARAMETERSV2"]._serialized_end = 54026
    _globals["_CHAINPARAMETERSV3"]._serialized_start = 54029
    _globals["_CHAINPARAMETERSV3"]._serialized_end = 55070
    _globals["_CHAINPARAMETERS"]._serialized_start = 55073
    _globals["_CHAINPARAMETERS"]._serialized_end = 55296
    _globals["_FINALIZATIONSUMMARYPARTY"]._serialized_start = 55298
    _globals["_FINALIZATIONSUMMARYPARTY"]._serialized_end = 55395
    _globals["_FINALIZATIONINDEX"]._serialized_start = 55397
    _globals["_FINALIZATIONINDEX"]._serialized_end = 55431
    _globals["_FINALIZATIONSUMMARY"]._serialized_start = 55434
    _globals["_FINALIZATIONSUMMARY"]._serialized_end = 55649
    _globals["_BLOCKFINALIZATIONSUMMARY"]._serialized_start = 55652
    _globals["_BLOCKFINALIZATIONSUMMARY"]._serialized_end = 55781
    _globals["_BLOCKITEM"]._serialized_start = 55784
    _globals["_BLOCKITEM"]._serialized_end = 56055
    _globals["_BAKERREWARDPERIODINFO"]._serialized_start = 56058
    _globals["_BAKERREWARDPERIODINFO"]._serialized_end = 56347
    _globals["_QUORUMSIGNATURE"]._serialized_start = 56349
    _globals["_QUORUMSIGNATURE"]._serialized_end = 56381
    _globals["_QUORUMCERTIFICATE"]._serialized_start = 56384
    _globals["_QUORUMCERTIFICATE"]._serialized_end = 56629
    _globals["_FINALIZERROUND"]._serialized_start = 56631
    _globals["_FINALIZERROUND"]._serialized_end = 56728
    _globals["_TIMEOUTSIGNATURE"]._serialized_start = 56730
    _globals["_TIMEOUTSIGNATURE"]._serialized_end = 56763
    _globals["_TIMEOUTCERTIFICATE"]._serialized_start = 56766
    _globals["_TIMEOUTCERTIFICATE"]._serialized_end = 57051
    _globals["_SUCCESSORPROOF"]._serialized_start = 57053
    _globals["_SUCCESSORPROOF"]._serialized_end = 57084
    _globals["_EPOCHFINALIZATIONENTRY"]._serialized_start = 57087
    _globals["_EPOCHFINALIZATIONENTRY"]._serialized_end = 57279
    _globals["_BLOCKCERTIFICATES"]._serialized_start = 57282
    _globals["_BLOCKCERTIFICATES"]._serialized_end = 57591
    _globals["_WINNINGBAKER"]._serialized_start = 57593
    _globals["_WINNINGBAKER"]._serialized_end = 57701
    _globals["_DRYRUNREQUEST"]._serialized_start = 57704
    _globals["_DRYRUNREQUEST"]._serialized_end = 57909
    _globals["_DRYRUNSTATEQUERY"]._serialized_start = 57912
    _globals["_DRYRUNSTATEQUERY"]._serialized_end = 58131
    _globals["_DRYRUNINVOKEINSTANCE"]._serialized_start = 58134
    _globals["_DRYRUNINVOKEINSTANCE"]._serialized_end = 58435
    _globals["_DRYRUNSTATEOPERATION"]._serialized_start = 58438
    _globals["_DRYRUNSTATEOPERATION"]._serialized_end = 58648
    _globals["_DRYRUNMINTTOACCOUNT"]._serialized_start = 58650
    _globals["_DRYRUNMINTTOACCOUNT"]._serialized_end = 58758
    _globals["_DRYRUNTRANSACTION"]._serialized_start = 58761
    _globals["_DRYRUNTRANSACTION"]._serialized_end = 58984
    _globals["_DRYRUNSIGNATURE"]._serialized_start = 58986
    _globals["_DRYRUNSIGNATURE"]._serialized_end = 59036
    _globals["_DRYRUNRESPONSE"]._serialized_start = 59039
    _globals["_DRYRUNRESPONSE"]._serialized_end = 59225
    _globals["_DRYRUNERRORRESPONSE"]._serialized_start = 59228
    _globals["_DRYRUNERRORRESPONSE"]._serialized_end = 60365
    _globals["_DRYRUNERRORRESPONSE_NOSTATE"]._serialized_start = 59886
    _globals["_DRYRUNERRORRESPONSE_NOSTATE"]._serialized_end = 59895
    _globals["_DRYRUNERRORRESPONSE_BLOCKNOTFOUND"]._serialized_start = 59897
    _globals["_DRYRUNERRORRESPONSE_BLOCKNOTFOUND"]._serialized_end = 59912
    _globals["_DRYRUNERRORRESPONSE_ACCOUNTNOTFOUND"]._serialized_start = 59914
    _globals["_DRYRUNERRORRESPONSE_ACCOUNTNOTFOUND"]._serialized_end = 59931
    _globals["_DRYRUNERRORRESPONSE_INSTANCENOTFOUND"]._serialized_start = 59933
    _globals["_DRYRUNERRORRESPONSE_INSTANCENOTFOUND"]._serialized_end = 59951
    _globals["_DRYRUNERRORRESPONSE_AMOUNTOVERLIMIT"]._serialized_start = 59953
    _globals["_DRYRUNERRORRESPONSE_AMOUNTOVERLIMIT"]._serialized_end = 60015
    _globals["_DRYRUNERRORRESPONSE_BALANCEINSUFFICIENT"]._serialized_start = 60017
    _globals["_DRYRUNERRORRESPONSE_BALANCEINSUFFICIENT"]._serialized_end = 60135
    _globals["_DRYRUNERRORRESPONSE_ENERGYINSUFFICIENT"]._serialized_start = 60137
    _globals["_DRYRUNERRORRESPONSE_ENERGYINSUFFICIENT"]._serialized_end = 60205
    _globals["_DRYRUNERRORRESPONSE_INVOKEFAILURE"]._serialized_start = 60208
    _globals["_DRYRUNERRORRESPONSE_INVOKEFAILURE"]._serialized_end = 60356
    _globals["_DRYRUNSUCCESSRESPONSE"]._serialized_start = 60368
    _globals["_DRYRUNSUCCESSRESPONSE"]._serialized_end = 61467
    _globals["_DRYRUNSUCCESSRESPONSE_BLOCKSTATELOADED"]._serialized_start = 60914
    _globals["_DRYRUNSUCCESSRESPONSE_BLOCKSTATELOADED"]._serialized_end = 61089
    _globals["_DRYRUNSUCCESSRESPONSE_TIMESTAMPSET"]._serialized_start = 61091
    _globals["_DRYRUNSUCCESSRESPONSE_TIMESTAMPSET"]._serialized_end = 61105
    _globals["_DRYRUNSUCCESSRESPONSE_MINTEDTOACCOUNT"]._serialized_start = 61107
    _globals["_DRYRUNSUCCESSRESPONSE_MINTEDTOACCOUNT"]._serialized_end = 61124
    _globals["_DRYRUNSUCCESSRESPONSE_TRANSACTIONEXECUTED"]._serialized_start = 61127
    _globals["_DRYRUNSUCCESSRESPONSE_TRANSACTIONEXECUTED"]._serialized_end = 61295
    _globals["_DRYRUNSUCCESSRESPONSE_INVOKESUCCESS"]._serialized_start = 61298
    _globals["_DRYRUNSUCCESSRESPONSE_INVOKESUCCESS"]._serialized_end = 61455
    _globals["_FINALIZERINDEX"]._serialized_start = 61469
    _globals["_FINALIZERINDEX"]._serialized_end = 61500
    _globals["_QUORUMMESSAGE"]._serialized_start = 61503
    _globals["_QUORUMMESSAGE"]._serialized_end = 61734
    _globals["_RAWQUORUMCERTIFICATE"]._serialized_start = 61737
    _globals["_RAWQUORUMCERTIFICATE"]._serialized_end = 61992
    _globals["_BLOCKSIGNATURE"]._serialized_start = 61994
    _globals["_BLOCKSIGNATURE"]._serialized_end = 62025
    _globals["_TIMEOUTMESSAGE"]._serialized_start = 62028
    _globals["_TIMEOUTMESSAGE"]._serialized_end = 62343
    _globals["_RAWFINALIZERROUND"]._serialized_start = 62345
    _globals["_RAWFINALIZERROUND"]._serialized_end = 62452
    _globals["_RAWTIMEOUTCERTIFICATE"]._serialized_start = 62455
    _globals["_RAWTIMEOUTCERTIFICATE"]._serialized_end = 62749
    _globals["_PERSISTENTROUNDSTATUS"]._serialized_start = 62752
    _globals["_PERSISTENTROUNDSTATUS"]._serialized_end = 63116
    _globals["_ROUNDTIMEOUT"]._serialized_start = 63119
    _globals["_ROUNDTIMEOUT"]._serialized_end = 63265
    _globals["_RAWFINALIZATIONENTRY"]._serialized_start = 63268
    _globals["_RAWFINALIZATIONENTRY"]._serialized_end = 63464
    _globals["_ROUNDSTATUS"]._serialized_start = 63467
    _globals["_ROUNDSTATUS"]._serialized_end = 63930
    _globals["_BLOCKTABLESUMMARY"]._serialized_start = 63932
    _globals["_BLOCKTABLESUMMARY"]._serialized_end = 64029
    _globals["_BRANCHBLOCKS"]._serialized_start = 64031
    _globals["_BRANCHBLOCKS"]._serialized_end = 64104
    _globals["_ROUNDEXISTINGBLOCK"]._serialized_start = 64107
    _globals["_ROUNDEXISTINGBLOCK"]._serialized_end = 64244
    _globals["_ROUNDEXISTINGQC"]._serialized_start = 64246
    _globals["_ROUNDEXISTINGQC"]._serialized_end = 64337
    _globals["_FULLBAKERINFO"]._serialized_start = 64340
    _globals["_FULLBAKERINFO"]._serialized_end = 64653
    _globals["_FINALIZATIONCOMMITTEEHASH"]._serialized_start = 64655
    _globals["_FINALIZATIONCOMMITTEEHASH"]._serialized_end = 64697
    _globals["_BAKERSANDFINALIZERS"]._serialized_start = 64700
    _globals["_BAKERSANDFINALIZERS"]._serialized_end = 64994
    _globals["_EPOCHBAKERS"]._serialized_start = 64997
    _globals["_EPOCHBAKERS"]._serialized_end = 65306
    _globals["_TIMEOUTMESSAGES"]._serialized_start = 65309
    _globals["_TIMEOUTMESSAGES"]._serialized_end = 65492
    _globals["_AGGREGATEDSIGNATURES"]._serialized_start = 65495
    _globals["_AGGREGATEDSIGNATURES"]._serialized_end = 65727
    _globals["_QUORUMMESSAGES"]._serialized_start = 65730
    _globals["_QUORUMMESSAGES"]._serialized_end = 65869
    _globals["_CONSENSUSDETAILEDSTATUSQUERY"]._serialized_start = 65871
    _globals["_CONSENSUSDETAILEDSTATUSQUERY"]._serialized_end = 65976
    _globals["_CONSENSUSDETAILEDSTATUS"]._serialized_start = 65979
    _globals["_CONSENSUSDETAILEDSTATUS"]._serialized_end = 66986
    _globals["_ACCOUNTPENDING"]._serialized_start = 66988
    _globals["_ACCOUNTPENDING"]._serialized_end = 67107
# @@protoc_insertion_point(module_scope)
